@@ -224,10 +224,10 @@ OXOperationHover.fillParticipants = function(Hover) {
 		}
 	}
 	internalCache.getObjects(tmp_participants,function(data) {
-		var tmp_node=newnode("tr",null,null,[
-			newnode("td",{ width: "25px" },{className : "notclickable"},[
-			]),
-			newnode("td",{},{ className : "contenttextnocolor notclickable"},[])
+		var tmp_node=newnode("tr", null, null, [
+			newnode("td", { width: "25px", whiteSpace: "nowrap" }, { className: "notclickable" }, []),
+			newnode("td", { width: "35%", whiteSpace: "nowrap", paddingLeft: "5px" }, { className: "contenttextnocolor notclickable"},[]),
+			newnode("td", 0, { className: "notclickable" }, [ newnode("div", { overflow: "hidden", whiteSpace: "nowrap", paddingLeft: "7px"}, { className : "contenttextnocolor" }, []) ])
 		]);
 		var tmp_node2=newnode("tr",null,null,[
 			newnode("td",{ width: "25px" },{className : "notclickable"},[
@@ -235,7 +235,7 @@ OXOperationHover.fillParticipants = function(Hover) {
 			newnode("td",{ width: "25px" },{className : "clickable"},[
 				newnode("img",{},{ src: getFullImgSrc("img/plus.gif") },[])
 			]),
-			newnode("td",{},{ className : "contenttextnocolor notclickable"},[])
+			newnode("td",0,{ className : "contenttextnocolor notclickable"},[])
 		]);
 		
 		var tmp_users=new Array();
@@ -280,10 +280,10 @@ OXOperationHover.fillParticipants = function(Hover) {
 				newnode("td",{ paddingTop:"7px" },{colSpan : 2, className: "notclickable" }, [
 					addTranslated('Participants') /*i18n*/
 				]),
-				newnode("td",{ width : "30px", paddingTop:"7px" , paddingRight: "10px" },{ title : _("Change confirmation") , className: "clickable"}, [
+				newnode("td",{ width : "30px", paddingTop:"7px" , paddingRight: "10px" },{ colSpan: 2, title : _("Change confirmation") , className: "clickable"}, [
 					newnode("img",{},{ src : getFullImgSrc("img/menu/global_confirmation_change.gif") })
 				])
-			])		
+			])	
 		);
 		Hover.confirmdialogshown=false;
 		addDOMEvent(node.getElementsByTagName("td")[1],"click",function() {
@@ -315,6 +315,7 @@ OXOperationHover.fillParticipants = function(Hover) {
 			if(i==0) {
 				tmpn1.getElementsByTagName("td")[0].style.paddingTop="10px";
 				tmpn1.getElementsByTagName("td")[1].style.paddingTop="10px";
+				tmpn1.getElementsByTagName("td")[2].style.paddingTop="10px";
 			}
 			tmpn1.getElementsByTagName("td")[0].appendChild(newnode("img",null,{src: getFullImgSrc("img/calendar/user.gif") },[]))
 			tmpn1.getElementsByTagName("td")[1].appendChild(document.createTextNode(tmp_users[i].display_name));
@@ -333,6 +334,7 @@ OXOperationHover.fillParticipants = function(Hover) {
 			if(tmp_users[i].message) {
 				tmpn1.title=tmp_users[i].message;
 			}
+			tmpn1.getElementsByTagName("td")[2].firstChild.appendChild(document.createTextNode(tmp_users[i].message || ""));
 			node.appendChild(tmpn1);
 		}
 		if(participants.length==0) {
@@ -393,20 +395,41 @@ OXOperationHover.fillParticipants = function(Hover) {
 						}
 					}
 				});
-				var count=0;
-				var tmpstring=_("No Members");
-				for (var i in cb) {
-					if(count==0) {
-						tmpstring= cb[i].display_name;
-						count++;
-					} else {
-						tmpstring+= " ; " +cb[i].display_name;
-						count++;
-					}
-				}
+				
 				var node1=mynode2.getElementsByTagName("td")[1];
 				removeChildNodes(node1);
-				node1.appendChild(document.createTextNode(tmpstring));
+				
+				var count=0;
+				var tmpstring =_("No Members");
+				for (var i in cb) {
+					if (count==0) {
+						tmpstring = cb[i].display_name;
+						count++;
+					} else {
+						tmpstring = "; " + cb[i].display_name;
+						count++;
+					}
+					var mNode = newnode("span", 0, { className: "notclickable" }, []);
+					for (var u in users) {
+						if (users[u].id == cb[i].id) {
+							switch(users[u].confirmation) {
+								case 1: 
+									mNode.className="appointmentACCEPTED";
+									break;
+								case 2: 
+									mNode.className="appointmentDECLINED";
+									break;
+								case 3: 
+									mNode.className="appointmentTENTATIVE";
+								break;
+							}
+							mNode.title = users[u].confirmmessage || "";
+							break;
+						}
+					}
+					mNode.appendChild(document.createTextNode(tmpstring))
+					node1.appendChild(mNode);
+				}
 			} })(tmpn1.getElementsByTagName("td")[1],accordionnode2,"ParticipantsGroupUsers"+i+"members"));
 		}
 		if(tmp_ressources.length) {
@@ -872,7 +895,6 @@ OXContactHover.refillContent = function(id,folder) {
 			OXContactHover.slider.selectTabById("general")
 		}
 	});	
-	
 }
 
 
@@ -941,6 +963,13 @@ OXTaskHover.getContent = function() {
 				function() { 
 					var tmpstring=OXOperationHover.getParticipantsString(OXTaskHover);
 					OXTaskHover.accordion.showContent(tmpstring);
+					// re-position of old group/participant state if switching back to this tab
+					for (var i in OXTaskHover.references.allGroupsParticipants) {
+		        		var group = OXTaskHover.references.allGroupsParticipants[i];
+		        		if (group.active) {
+		        			OXTaskHover.accordion.showExtraContent(i);
+		        		}		        		
+		        	}
 				}
 			)
 	);
@@ -1188,7 +1217,14 @@ OXInfostoreHover.getContent = function() {
 	tabs.addTab(
 			new Tab("versions", "Versions" /*i18n*/,
 				function() { 
-					OXInfostoreHover.accordion.showContent(OXInfostoreHover.getVersionsString(OXInfostoreHover));
+					OXInfostoreHover.accordion.showContent(OXInfostoreHover.getVersionsString(OXInfostoreHover));					
+					// re-position of old version comment state if switching back to this tab
+					for (var i in OXInfostoreHover.references.allVersionComments) {
+		        		var ver = OXInfostoreHover.references.allVersionComments[i];
+		        		if (ver.active) {
+		        			OXInfostoreHover.accordion.showExtraContent(i);
+		        		}		        		
+		        	}
 				}
 			)
 	);
@@ -1590,6 +1626,13 @@ OXAppointmentHover.getContent = function() {
 				function() { 
 			 		var tmpstring=OXOperationHover.getParticipantsString(OXAppointmentHover);
 			 		OXAppointmentHover.accordion.showContent(tmpstring);
+			 		// re-position of old group/participant state if switching back to this tab
+					for (var i in OXAppointmentHover.references.allGroupsParticipants) {
+		        		var group = OXAppointmentHover.references.allGroupsParticipants[i];
+		        		if (group.active) {
+		        			OXAppointmentHover.accordion.showExtraContent(i);
+		        		}		        		
+		        	}
 				}
 			)
 	);
@@ -1640,14 +1683,29 @@ OXAppointmentHover.fillText = function(type,text,titletext,clear) {
 	if(titletext) { OXAppointmentHover.references[type].title=titletext; }
 }
 
-OXAppointmentHover.refillContent = function(id,folder,recurrence_position) {
+OXAppointmentHover.refillContent = function(id, folder, recurrence_position) {
+	// can't use the oxcache here as there are bugs on the backend right now ... 
+	// e.g. field 104 is always null :-|
+	/*
+	var collection={};
+    collection.objects = [ OXCalendarMapping.createKeyFromObject( { module: "calendar", folder_id: folder, id: id, recurrence_position: (recurrence_position || 0) } )];
+    collection.columns = null;
+    OXAppointmentHover.oxCacheRequest = OXCache.newRequest(null, "calendar", collection, null,
+	    function(daten) {
+	        if (daten.objects[0]) {	        	
+				OXAppointmentHover.actualobject = daten.objects[0];
+				OXAppointmentHover.drawContent(OXAppointmentHover.actualobject);				
+	        }           
+	    }, true
+    );
+    */
 	var reqstr=AjaxRoot + "/calendar?action=get&session=" + session +"&id="+ id + "&folder="+folder;
 	if(recurrence_position) { reqstr+="&recurrence_position="+recurrence_position; }
 	(new JSON()).get(reqstr,null,function(object) {
-		object=object.data;
-		OXAppointmentHover.actualobject=object;
-		OXAppointmentHover.drawContent(object);		
+		OXAppointmentHover.actualobject = object.data;
+		OXAppointmentHover.drawContent(OXAppointmentHover.actualobject);
 	});
+	
 }
 
 OXAppointmentHover.refillContentByObject = function(object) {
@@ -1700,7 +1758,12 @@ OXAppointmentHover.drawContent = function(object) {
 			try {
 				var created_by = response[OXAppointmentHover.actualobject.created_by].display_name || "";
 				var created_on = formatDate(OXAppointmentHover.actualobject.creation_date, "datetime") || "";
-				var txt = format(_("Created on %s by %s"), [created_on, created_by]);
+				var txt = "";
+				if (!OXAppointmentHover.actualobject.creation_date) {
+					txt = format(_("Created by %s"), [created_by]);
+				} else {
+					txt = format(_("Created on %s by %s"), [created_on, created_by]);
+				}
 				OXAppointmentHover.fillText("created_by", txt, txt, true);	
 			} catch(n) {}
 		});
