@@ -58,8 +58,8 @@ MoveCopy.prototype = {
                        action    : "update", 
                        module    : tmpKey.module, 
                        id        : tmpKey.id,
-                       folder    : tmpKey.folder_id, 
-                       timestamp : tmpTime,
+                       folder    : tmpKey.folder_id,
+                       timestamp : tmpTime,                       
                        data      : { folder_id: newfolder }
                     });
                     this.finalObjects.push(tmpObj_Hashed);
@@ -72,14 +72,22 @@ MoveCopy.prototype = {
                         	newServerError(reply[i]);
                         }
                     }
-                    mapping.deleteObjectsInternal(Self.finalObjects);
+                    mapping.deleteObjectsInternal(Self.finalObjects);                    
                     mapping.createObjectsInternal(
                         [{ folder_id : selectedfolderid }]);
                     switch (Self.currentModule) {
                         case "mail":
-                            if (currentpath[1] == "detail")
-                                triggerEvent("OX_Switch_View", menulastviews["mail"] || configGetKey("gui.mail.view"));
-                            if (oUnreadCounterStorage) oUnreadCounterStorage.update();
+                            // do we have to update folder unread counter!?
+                            if (oUnreadCounterStorage) {
+                            	// iterate through moved objects, updating only if any message was unread before!
+                            	for (var i in Self.currentObjects) {
+                            		var flag = Self.currentObjects[i].flags;
+                            		if (typeof(flag) != "undefined" && flag <= 16) {
+                            			oUnreadCounterStorage.update();
+                            			break;
+                            		}
+                            	}                            	
+                            }
                             break;
                         default:
                             break;
@@ -129,6 +137,8 @@ MoveCopy.prototype = {
                             } else {
                                 setTimeout(function() { storageCache.update(); }, 0);
                             }
+                            // notify via event
+                            triggerEvent("OX_After_MoveCopy_Appointment");
                             break;
                     }
                 }
@@ -237,10 +247,19 @@ MoveCopy.prototype = {
             });
 	},
 	updateTimestamp: function() {
-		if(currentpath2[0] == "mail" && currentpath2[1]=="detail")
+		if(currentpath2[0] == "mail" && currentpath2[1]=="detail") {
+		    // mail/detail: from global var
 			this.timestamp = mailFetchTimestamp;
-		else
+		}
+		else if (currentfullpath == "calendar/team/day") {
+		    // we have no better data (free-busy return zero)
+		    // workaround: now plus 1 hour
+		    this.timestamp = (new Date()).getTime() + 1000 * 60 * 60;
+		}
+		else {
+		    // default action: use cache timestamp
 			this.timestamp = storageCache.current.timestamp;
+		}
 	}
 }
 
