@@ -22,10 +22,8 @@ function attachmentDialog(sDialogNum, fkt_On_OK)
 	this.popup = $('attachPopupTemplate');
 	this.popup.id = this.template_id + '_' + this.dialog_num;
 	this.dialog_num = sDialogNum;
-	this.att_server_rem = new Array();;
-	
+	this.att_server_rem = new Array();	
 	this.callOnOK = fkt_On_OK;
-	
 	this.form_name = 'attFile_' + this.dialog_num;
 	this.form =  document.attFile;
 	this.form.name = this.form_name;
@@ -35,8 +33,8 @@ function attachmentDialog(sDialogNum, fkt_On_OK)
 	//this.sel_files_area.id = this.files_area_id;
 	this.live_grid_container = $("sel_files_area");
 	this.file_storage = new Storage(0, [], "", 0, 0,  null, function(x){ return x[0];});
-		
 	this.file_input_count = 0; 
+	this.attachmentsChanged = false;
 	
 	var Self = this;
 	register("OX_Attachment_Dialog_Cancel", function(){Self.closePopup();});
@@ -62,7 +60,7 @@ function attachmentDialog(sDialogNum, fkt_On_OK)
 attachmentDialog.prototype = {
 	attach_changed:function ()
 	{
-		return (this.att_server_rem.length > 0 || this.file_input_count > 0);
+		return (this.att_server_rem.length > 0 || this.file_input_count > 0 || this.attachmentsChanged);
 	},
 	do_post: function (obj,fn_exec_afterupload,sActionParam,sTargetParam,fn_error_exec_afterupload)
 	{
@@ -77,8 +75,8 @@ attachmentDialog.prototype = {
 
 			var sAction = AjaxRoot + "/attachment?action=detach" + "&session="+session + "&attached=" 
 						+ this.att_server_rem[0].item_id + "&module=" 
-								+ this.att_server_rem[0].module + "&folder=" + (this.att_server_rem[0].folder || this.att_server_rem[0].folder_id);												
-			this.att_server_rem = new Array();								
+								+ this.att_server_rem[0].module + "&folder=" + (this.att_server_rem[0].folder || this.att_server_rem[0].folder_id);												 
+			this.att_server_rem = new Array();	
 			var attJson = new JSON();
 			var Self = this;
 			function cb_deleted(arg)
@@ -136,6 +134,7 @@ attachmentDialog.prototype = {
 					this.form['json_'+nCount].value = sObj;
 			}
 		}
+		this.attachmentsChanged = true;
 		this.form.submit();
 	},
 	createFileInput: function()
@@ -472,7 +471,7 @@ function attachmentGrid(sContainerId,nId,nFolder,sModule,oDialog)
 	this.remAttachedFile  = function() {
 		if(Self.selectedRtfFlag) return;		
 		function cbyes() {
-			Self.remove(Self.selectedId,function() {
+			Self.remove(Self.liveGrid.selection.getSelected(), function() {
 				Self.updateGrid(Self.selection_dialog.file_name_list);
 			});										
 		}
@@ -551,48 +550,25 @@ updateGrid:function (data)
 	this.enableGrid();
 
 },
-remove:function (id,fn_opt_after_remove)
-{
-	if(typeof(id) == 'string')
-		var aSplited = id.split('_');
-	else
-	{
-		var aSplited = new Array();
-		aSplited[0] = id;
-	}		
-	if(aSplited[1])
-	{
-		//remove from grid
-		
-		//remove from dialog
-		var aFileToDel = new Array();
-		aFileToDel[0] = id;
-		this.selection_dialog.removeFiles(aFileToDel);
-		if(fn_opt_after_remove)
-		{
-			fn_opt_after_remove();
-		}
-		this.numberOfAttachments--;		
-		triggerEvent("OX_Attachments_Changed_InGrid",this.numberOfAttachments);
-	}
-	else
-	{
-		var Self = this;
-		Self.selection_dialog.att_server_rem.push({attid:id,item_id:this.nItemId,module:this.module,
-																						folder:this.folder || this.folder_id});
-
-		var aData = new Array();
-		delete Self.attachmentStorage.data.data[id];
-		for (var indx in Self.attachmentStorage.data.data)
-		{			
-			aData.push(Self.attachmentStorage.data.data[indx]);
-		}
-		this.attachmentStorage = new Storage(0, []);
-		Self.attachmentStorage.append(aData);
-		Self.liveGrid.enable(Self.attachmentStorage);
-		this.numberOfAttachments--;		
-		triggerEvent("OX_Attachments_Changed_InGrid",this.numberOfAttachments);
-	}
+remove:function (ids, callback) {
+    var local = [], remote = [];
+    for (var i = 0; i < ids.length; i++) {
+        var id = ids[i];
+        if (typeof id == "string" && id.indexOf("_") >= 0) {
+            local.push(id);
+        } else {
+            remote.push(id);
+            this.selection_dialog.att_server_rem.push({
+                attid: id, item_id: this.nItemId, module: this.module,
+                folder: this.folder || this.folder_id
+            });
+        }    
+    }
+    if (local.length) this.selection_dialog.removeFiles(local);
+    if (remote.length) this.attachmentStorage.removeIDs(remote);
+    this.numberOfAttachments -= ids.length;        
+    triggerEvent("OX_Attachments_Changed_InGrid",this.numberOfAttachments);
+    if (callback) callback();
 },
 enableGrid:function ()
 {
