@@ -25,6 +25,13 @@ function AutoComplete(oText, oDiv, nMaxSize, minChars, timeout) {
 	this.searchPattern = new Object();
 	this.cancelRequest = false;
 	
+	/* to work with teamview (i.e. other use cases than new mail) */
+	this.autoAdjustHeight = true;
+	this.showDisplayNamesOnly = false;
+	this.showSystemUsersOnly = false;
+	this.includeResources = false;
+	this.nameIndex = {};
+	
 	/*-- private variables --*/
 	this.tt;
 	this.cache = new AutoCompleteCache();
@@ -73,8 +80,8 @@ AutoComplete.prototype.onTextChange = function(evt) {
 			break;
 		default:
 			setTimeout(function() {
-					var st = getCurrStr(parent.AutoComplete.oText.value, parent.AutoComplete.oText);					
-					if (st && trimStr(st).length >= parent.AutoComplete.minChars) {
+					var st = getCurrStr(parent.AutoComplete.oText.value, parent.AutoComplete.oText);
+					if (getSearchPatternLength(st) >= parent.AutoComplete.minChars) {
 						parent.AutoComplete.search(trimStr(st));
 					} else {
 						parent.AutoComplete.clear();
@@ -86,9 +93,8 @@ AutoComplete.prototype.onTextChange = function(evt) {
 }
 
 AutoComplete.prototype.onDivMouseDown = function() {
-	var st = this.AutoComplete.oText.scrollTop;
-	this.AutoComplete.oText.value = replaceCurrStr(this.AutoComplete.oText.value, this.AutoComplete.oText,this.getAttribute("oval"));
-	setSelRange(this.AutoComplete.oText, this.AutoComplete.oText.value.length, this.AutoComplete.oText.value.length, st);
+    var st = this.AutoComplete.oText.scrollTop;
+    this.AutoComplete.onSelect(this, st);
 	this.AutoComplete.clear();
 	return true;
 }
@@ -134,17 +140,23 @@ AutoComplete.prototype.keyEnter = function () {
 	var elem = document.getElementById("ac_" + this.currSelected);
 	if (elem) {
 		var st = this.oText.scrollTop;
-		this.oText.value=replaceCurrStr(this.oText.value, this.oText,elem.getAttribute("oval"));
-		setSelRange(this.oText, this.oText.value.length, this.oText.value.length, st);		
+		this.onSelect(elem, st);
 		_rb = false;
 	}
 	this.clear();
 	return _rb;
 }
 
+AutoComplete.prototype.onSelect = function (elem, st) {
+    this.oText.value=replaceCurrStr(this.oText.value, this.oText, elem.getAttribute("oval"));
+    setSelRange(this.oText, this.oText.value.length, this.oText.value.length, st);
+}
+
 AutoComplete.prototype.clear = function () {
 	removeChildNodes(this.oDiv);
-	this.oDiv.style.height = "";
+	if (this.autoAdjustHeight) {
+	    this.oDiv.style.height = "";
+	}
 	this.oDiv.style.visibility = "hidden";	
 	this.currSelected = 0;
 	this.currEntries = 0;
@@ -153,8 +165,10 @@ AutoComplete.prototype.clear = function () {
 
 AutoComplete.prototype.enableDiv = function() {
 	// positioning the div and enable it
-	this.oDiv.style.top = (getAbsolutePositionTop(this.oText) + this.oText.offsetHeight) + "px";
-	this.oDiv.style.left = getAbsolutePositionLeft(this.oText) + "px";		
+    var oTop = getAbsolutePositionTop(this.oText) + this.oText.offsetHeight;
+    var oLeft = getAbsolutePositionLeft(this.oText);
+	this.oDiv.style.top = oTop + "px";
+	this.oDiv.style.left =  oLeft + "px";
 	this.oDiv.scrollTop = "0";
 	this.oDiv.style.visibility = "visible";
     this.visible = true;
@@ -202,8 +216,9 @@ AutoComplete.prototype.onchange = function(txt) {
 			}
 		}
 		//this.oDiv.style.height = "20em";
-		if (this.oDiv.offsetHeight > 160)
+		if (this.autoAdjustHeight && this.oDiv.offsetHeight > 160) {
 			this.oDiv.style.height = "160px";
+		}
 		this.enableDiv();
 	} else {
 		this.clear();
@@ -211,18 +226,14 @@ AutoComplete.prototype.onchange = function(txt) {
 }
 
 AutoComplete.prototype.search = function(str) {
-	var parent = this;		
-	
-	// remove any quoted strings
-	if (str.match(/\"/g))
-		str.replace(/\"/g, "");
+	var parent = this;
 	
 	// already in cache?
 	if (this.cache.contains(trimStr(str)))
 	   return;
 	
 	for (var e in this.searchPattern) {
-		var sp = new RegExp("^" + e);
+		var sp = new RegExp("^" + escapeRegExp(e));
 		if (sp && str.match(sp)) {
 			this.onchange(str);
 			return;
@@ -244,63 +255,146 @@ AutoComplete.prototype.search = function(str) {
 		
 	// set new timer with given timout
 	this.tt = window.setTimeout(function() {	   
-	   if (parent.cancelRequest) return; // request aborted, so leave	
-		parent.enableDiv();
-		
-		// fire-up search
-        var pattern = str + "*";		
+    if (parent.cancelRequest) return; // request aborted, so leave	
+	parent.enableDiv();
+	
+	// fire-up search
+	var pattern = str;
+	if (pattern.charAt(pattern.length - 1) != "*") pattern += "*";
+    
+    corewindow.oMainFolderTree.checkGAL(function(GAL) {
         
         // in which folder should be searched for autocomplete
-		var allFolder = [6, configGetKey("folder.contacts")];
-		if (configGetKey("modules.mail.contactCollectFolder")){
-        	allFolder.push(configGetKey("modules.mail.contactCollectFolder"));
+        var allFolder = GAL ? [6] : [];
+        allFolder.push(configGetKey("folder.contacts"));
+        if (configGetKey("modules.mail.contactCollectFolder")) {
+            allFolder.push(configGetKey("modules.mail.contactCollectFolder"));
+        }
+        
+        // default folder
+        var defaultSearchFolder = configGetKey("folder.contacts") || 6;
+        
+        // create multiple request
+        var multiple = [{
+            // search contacts
+            "action": "search",
+            "module": "contacts",
+            "columns": "1,500,555,556,557,524,602,592,20,524",
+            "sort": "609",
+            "data": {
+		        display_name: pattern, email1: pattern,
+		        email2: pattern, email3: pattern, last_name: pattern,
+		        first_name: pattern, folder: allFolder, orSearch: true,
+		        emailAutoComplete: true
+        	}
+        }];
+        // search for resource?
+        if (parent.includeResources) {
+        	multiple.push({
+	            "action": "search",
+	            "module": "resource",
+	            "data": {
+	        		"pattern": pattern,
+	        		"folder": defaultSearchFolder
+	        	}
+	        });
         }
-		
-		var dao = { display_name: pattern, email1: pattern, 
-					email2: pattern, email3: pattern, last_name: pattern,
-					first_name: pattern, folder: allFolder, orSearch: true, 
-					emailAutoComplete: true };
-		
-		// hack to hide the global address book
-		// use this with care! will be removed with upcomming releases!
-		if (new Boolean(configGetKey("modules.contacts.hideGlobalAddressBook")) == true &&
-			configGetKey("modules.infostore.module") == false) {
-			dao.folder = allFolder.splice(1);
-			delete(dao.emailAutoComplete);
-		}		
 
-		new JSON().put(AjaxRoot + "/contacts?session=" + session + 
-			"&action=search&columns=1,500,555,556,557,524,602,592&sort=609",
-			dao, null,
-			function(cb) {
-				if (cb && cb.data) {					
-					for (var i = 0; i < cb.data.length; i++) {
-						var pn = cb.data[i][1] || ""; // address prefix	
-						// is it a distribution list?
-						if (cb.data[i][6] && cb.data[i][7]) {
-							var addresses = [];
-							for (var ib in cb.data[i][7]) {
-								addresses.push(quotePersonalAddr(cb.data[i][7][ib].display_name) + " <" + cb.data[i][7][ib].mail + ">");
-							}
-							parent.cache.add(pn, addresses);
-						} else {
-							var em1 = cb.data[i][2]; // email1
-							if (em1) parent.cache.add(quotePersonalAddr(pn) + " <" + em1 + ">", [ quotePersonalAddr(pn) + " <" + em1 + ">" ]);
-							var em2 = cb.data[i][3]; // email2
-							if (em2) parent.cache.add(quotePersonalAddr(pn) + " <" + em2 + ">", [ quotePersonalAddr(pn) + " <" + em2 + ">" ]);
-							var em3 = cb.data[i][4]; // email3
-							if (em3) parent.cache.add(quotePersonalAddr(pn) + " <" + em3 + ">", [ quotePersonalAddr(pn) + " <" + em3 + ">" ]);
-						}
-					}
-					if (!parent.searchPattern[str]) {
-						parent.searchPattern[str] = str;
-					}
-					parent.onchange(str);
-				} else {
-				   parent.clear();
-				}
-			});
-		} , this.timeout);
+        (new JSON()).put(AjaxRoot + "/multiple?session=" + session, multiple, null,
+            function(cb) {
+        		// no response?
+        		if (!cb || !cb.length) {
+        			parent.clear();
+        			return;
+        		}
+
+        		// process contacts
+        		if (cb.length > 0) {
+	        		var response = cb[0];
+	                for (var i = 0; i < response.data.length; i++) {
+	                	var data = response.data[i];
+	                    // system users only? (folder_id=6)
+	                    if (parent.showSystemUsersOnly && data[8] != 6) continue;
+	                    // address prefix
+	                    var pn = data[1] || "";
+	                    // fill name cache (format: folder.id)
+	                    var name = quotePersonalAddr(pn);
+	                    var objectData = {
+	                            type: 1, // user
+	                            id: data[9], // internal user id
+	                            folder: data[8],
+	                            display_name: name
+	                    };
+	                    // names only?
+	                    if (parent.showDisplayNamesOnly) {
+	                        // add
+	                        var mailAddresses = [];
+	                        if (data[2]) mailAddresses.push("<"+data[2]+">");
+	                        if (data[3]) mailAddresses.push("<"+data[3]+">");
+	                        if (data[4]) mailAddresses.push("<"+data[4]+">");
+	                        var key = name + " " + mailAddresses.join(", ");
+	                        parent.cache.add(key, [key]);
+	                        parent.nameIndex[key] = objectData;
+	                    }
+	                    // distribution list?
+	                    else if (data[6] && data[7]) {
+	                        var addresses = [];
+	                        for (var ib in data[7]) {
+	                            addresses.push(quotePersonalAddr(
+	                                data[7][ib].display_name) +
+	                                " <" + data[7][ib].mail + ">");
+	                        }
+	                        parent.cache.add(pn, addresses);
+	                    }
+	                    // normal users
+	                    else {
+	                        var em1 = data[2]; // email1
+	                        if (em1) {
+	                            var key = quotePersonalAddr(pn) + " <" + em1 + ">";
+	                            parent.cache.add(key, [key]);
+	                            parent.nameIndex[key] = objectData;
+	                        }
+	                        var em2 = data[3]; // email2
+	                        if (em2) {
+	                            var key = quotePersonalAddr(pn) + " <" + em2 + ">";
+	                            parent.cache.add(key, [key]);
+	                            parent.nameIndex[key] = objectData;
+	                        }
+	                        var em3 = data[4]; // email3
+	                        if (em3) {
+	                            var key = quotePersonalAddr(pn) + " <" + em3 + ">";
+	                            parent.cache.add(key, [key]);
+	                            parent.nameIndex[key] = objectData;
+	                        }
+	                    }
+	                }
+        		}
+
+                // process resources
+                if (cb.length > 1) {
+                	var response = cb[1];
+                	for (var i = 0; i < response.data.length; i++) {
+	                	var data = response.data[i];
+	                	var objectData = {
+	                            type: 3, // resource
+	                            id: data.id,
+	                            folder: 0,
+	                            display_name: data.display_name
+	                    };
+	                	var key = data.display_name + " <" + data.mailaddress + ">";
+                        parent.cache.add(key, [key]);
+                        parent.nameIndex[key] = objectData;
+                	}
+                }
+                
+                // add search pattern
+                if (!parent.searchPattern[str]) {
+                    parent.searchPattern[str] = str;
+                }
+                parent.onchange(str);
+            });
+        } , this.timeout);
+    });
 }
 
 function quotePersonalAddr(addr) {	
@@ -323,7 +417,12 @@ AutoCompleteCache.prototype.add = function(key, addresses) {
 
 AutoCompleteCache.prototype.getResults = function(str, outStr) {
 	for (var i in this.aStr) {
-		var re = new RegExp(str, "i");
+	    // quote string for regex but fix wilcards
+	    // this reflects what the server does: the search pattern must start
+	    // at the begin or after whitespaces or "<" (email addresses)
+	    // additionally, display names might be quoted
+	    var resultRegex = "(^\"?|.*(\\s|<))"+escapeRegExp(str).replace(/\\\*/g, '.*').replace(/\\\?/g, '.');
+		var re = new RegExp(resultRegex, "i");
 		var obj = {};
 		obj[i] = this.aStr[i];
 		if (i.match(re)) outStr.push(obj);
@@ -346,7 +445,7 @@ AutoCompleteCache.prototype.contains = function(str) {
  */
 var tmp_span = newnode("span", { margin:0 }, { className:"font-style-headline" }, [document.createTextNode("\xa0")]);
 function getParsedNode (str, oStr, oDiv) {
-	var regexp = new RegExp(str, "gi");	
+	var regexp = new RegExp(escapeRegExp(str), "gi");
 	var mpos, lIndex = 0;
 	while (str != "" && (mpos = regexp.exec(oStr))) {		
 		// everything before
@@ -380,6 +479,11 @@ function getCurrStr(str, obj) {
 	return null;
 }
 
+function getSearchPatternLength(str) {
+    // remove wildcards and whitespaces and return the number of characters
+    return (str || "").replace(/[*?\s]/g, '').length;
+}
+
 function replaceCurrStr(oldstr,obj,newstr) {	
 	var caretStart = getCaretStart(obj);
 	var io = splitMails(oldstr);
