@@ -23,6 +23,7 @@ var calendarFolderPath;
 /*********************************************************************************************************************/
 var selectedAppointment=new Object();
 var calendarSelection = new Selection();
+var lastSelectedAppointment=null;
 
 calendar_serializeid = function(x) {
 	return x.folder + "." + x.id + "." + (x.recurrence_position || 0) 
@@ -76,7 +77,8 @@ function register_Calendar() {
 			if (calendarhovers["daywwcustom"] && configGetKey("gui.effects.hover.calendar")) {
 				calendarhovers["daywwcustom"].enable();
 				calendarhovers["daywwcustom2"].enable(); 
-			}			
+			}
+			register("OX_Print", calendar_printDay);
 		 }, 
 		 function() {
 		 	if (calendarhovers["daywwcustom"]) { 
@@ -87,7 +89,8 @@ function register_Calendar() {
  			register("OX_Create_Object",default_calendar_create_object);
  			cwwdisable();
  			calendarFolderPath.clear();
-		 	unregister("OX_Add_Flag", calendarAddTag);	
+		 	unregister("OX_Add_Flag", calendarAddTag);
+		 	unregister("OX_Print", calendar_printDay);
 		 },
 		function() { 
 			hideNode("calendarWorkweek"); 
@@ -119,8 +122,10 @@ function register_Calendar() {
 				calendarhovers["daywwcustom2"].enable(); 
 			}
 			register("OX_Add_Flag", calendarAddTag);
+			register("OX_Print", calendar_printWorkweek);
 		}, 
 		function() {
+		    unregister("OX_Print", calendar_printWorkweek);
  			if (calendarhovers["daywwcustom"]) { 
  				calendarhovers["daywwcustom"].disable(); 
  				calendarhovers["daywwcustom2"].disable(); 
@@ -220,8 +225,10 @@ function register_Calendar() {
 			unregister("OX_Create_Object",default_calendar_create_object);
 			register("OX_Create_Object",default_calendar_workweek_create_object);		
 		  	loadMonthView();
+		  	register("OX_Print", calendar_printMonth);
 		 }, 
 		 function() {
+            unregister("OX_Print", calendar_printMonth);
 		 	if (calendarhovers["month"]) { 
 		 		calendarhovers["month"].disable(); 
 		 	}
@@ -254,8 +261,10 @@ function register_Calendar() {
 			register("OX_Create_Object",default_calendar_workweek_create_object);		
 			objWeekCalendarTool.init();
 			register("OX_Add_Flag", calendarAddTag);
+			register("OX_Print", calendar_printWeek);
 		 }, 
 		 function() {
+            unregister("OX_Print", calendar_printWeek);
 		 	if(calendarhovers["week"]) { 
 		 		calendarhovers["week"].disable(); 
 		 	}
@@ -274,45 +283,118 @@ function register_Calendar() {
 		}
 	);
 	
-	function calendarteamdayrefresh() {
-		displayNameDayView();
-		ctd_startContent();	
+	var calendarTeamViewChangeTeamPopup = null;
+	// store team view specific settings in ui config
+	var storeTeamViewSettings = function(param) {
+		var grid = getCalendarGrid("teamview");
+		if (typeof(grid) != undefined) {
+			configSetKey("gui.calendar.team.zoom", grid.zoom);
+		}
 	}
 	
-	registerView("calendar/team/day",
-		function() { 
-			showNode("calendarTeamDay");
-			if(ctd_participants == null)
-				team_initContent();
-			$("calendarTeamDay").style.display=""; 
-		}, 
-		function() { 
-			filldefaultteam();
-			ctd_startContent()			
-			register("OX_Refresh", calendarteamdayrefresh);			
-			register("OX_Add_Flag", calendarAddTag);
-			if (configGetKey("gui.effects.hover.calendar") && calendarhovers["teamday"]) {
-				calendarhovers["teamday"].enable();
-			}
-		}, 
-		function() {
-		    ctd_leaveContent();	
-			unregister("OX_Refresh", calendarteamdayrefresh);
-		    unregister("OX_Add_Flag", calendarAddTag);
-		    if (calendarhovers["teamday"]) {
-				calendarhovers["teamday"].disable();
-			}
-		},
-		function() { 
-			hideNode("calendarTeamDay");
-			$("calendarTeamDay").style.display="none";
-		},
-		function() {
-			displayNameDayView();
-			ctd_startContent();	
-		}
-	);
+	/*
+	 * TeamView
+	 */
+	var teamView_show = function(intervalLength, zoom, view) {
+	    return function() {
+    	    showNode("calendarTeamDay");
+            var grid = getCalendarGrid("teamview");
+//            if (configContainsKey("gui.calendar.team.zoom")) {
+//                grid.zoom = configGetKey("gui.calendar.team.zoom");
+//            }
+            grid.zoom = zoom;
+            grid.setGridIntervalLength(intervalLength);
+            grid.setParentDOMNode($("teamViewCalendarGrid"));
+            grid.setSelectionChangedEvent("SubSelected");
+            grid.setTeamMemberChangedEvent("OX_Teammember_Changed");
+            grid.setZoomLevelChangedEvent("OX_Zoom_Level_Changed");
+            // is month?
+            if (view == "MONTH") {
+                grid.setGridIntervalToWeek(null, intervalLength);
+            }
+            grid.validateOrUpdate();
+            register("OX_Zoom_Level_Changed", storeTeamViewSettings);
+            calendarGridHandlers.registerAll();
+	    };
+	};
 	
+	var teamView_enter = function() {
+	 // update current team
+        var grid = getCalendarGrid("teamview");
+        grid.importTeam();
+        // create menu pulldown (if not exists)
+        if (!calendarTeamViewChangeTeamPopup) {
+            calendarTeamViewChangeTeamPopup = new PulldownMenu($("menu_calendar_teammember_change"));
+            calendarTeamViewChangeTeamPopup.onShow = function() {
+                this.removeAllItems();
+                var teams = configGetKey("gui.calendar.teams");
+                if (teams) for (var i = 0; i < teams.length; i++) {
+                    this.addItem(new MenuItem(teams[i].name, (function(i) {
+                        return function() {
+                            var grid = getCalendarGrid("teamview");
+                            // delay for better gui responsiveness
+                            setTimeout(function() {
+                                grid.loadTeamByIndex(i);
+                            }, 10);
+                        };
+                    })(i)));
+                }
+            };
+        }
+        if (configGetKey("gui.effects.hover.calendar") && calendarhovers["teamday"]) {
+            calendarhovers["teamday"].enable();
+        }
+    };
+    
+    var teamView_leave = function() {
+        if (calendarhovers["teamday"]) {
+            calendarhovers["teamday"].disable();
+        }
+    };
+    
+    var teamView_hide = function() {
+        hideNode("calendarTeamDay");
+        $("calendarTeamDay").style.display = "none";
+        unregister("OX_Zoom_Level_Changed", storeTeamViewSettings);
+        calendarGridHandlers.unregisterAll();
+    };
+	
+	registerView("calendar/team/day",
+	        teamView_show(1, 200, "DAY"),
+	        teamView_enter,
+	        teamView_leave,
+	        teamView_hide,
+	        null
+	        );
+	
+	registerView("calendar/team/week",
+            teamView_show(7, 100, "WEEK"),
+            teamView_enter,
+            teamView_leave,
+            teamView_hide,
+            null
+            );
+	
+	registerView("calendar/team/month",
+	        teamView_show(28, 75, "MONTH"),
+            teamView_enter,
+            teamView_leave,
+            teamView_hide,
+            null
+	        );
+
+    registerView("calendar/team/custom",
+            function() {
+                // config not available now
+                var days = configGetKey("gui.calendar.custom.countdays");
+                teamView_show(days, 100)();
+            },
+            teamView_enter,
+            teamView_leave,
+            teamView_hide,
+            null
+            );
+
 	function calendarteamweekrefresh() {
 		displayNameDayView();
 		loadTeamWeek();
@@ -321,12 +403,15 @@ function register_Calendar() {
 	registerView("calendar/team/workweek",
 		function() { 
 			showNode("calendarTeamWeek");
-			if(ctd_participants == null)
-			{
+			if(ctd_participants == null) {
 				$("calendarTeamWeek").style.display=""; 
 				team_initContent();
 			}}, 
 		function() { 
+			// register
+			register("OX_Calendar_Teammember_Add", team_changeTeammembers);
+			register("OX_Calendar_Teammember_Remove", team_removeTeammembers);
+			register("OX_Selected_Member", team_storeSelectedMember);
 			register("OX_Refresh", calendarteamweekrefresh);
 			filldefaultteam();
 			displayNameDayView();
@@ -342,7 +427,11 @@ function register_Calendar() {
 			}
 		 },
 		function() { 
+			// register
 			unregister("OX_Refresh", calendarteamweekrefresh);
+			unregister("OX_Calendar_Teammember_Add", team_changeTeammembers);
+			unregister("OX_Calendar_Teammember_Remove", team_removeTeammembers);
+			unregister("OX_Selected_Member", team_storeSelectedMember);
 			hideNode("calendarTeamWeek");
 			$("calendarTeamWeek").style.display="none";
 		},
@@ -402,10 +491,10 @@ function register_Calendar() {
 		 }, 
 		 null,
 		 null,
-		 function() { 
-		 	initLiveGridCalendar("workweek");
+		 function() { 		 	
 		 	calendarFolderPath.drawDOMNode("calendaroflistview", activefolder);
-		 	displayNameDayView(); 
+		 	displayNameDayView();
+		 	initLiveGridCalendar("workweek");
 		 }
 	);
 	registerView("calendar/list/month",
@@ -464,35 +553,41 @@ function register_Calendar() {
 		 null
 	);
 	registerView("calendar/detail",
+	    // SHOW
 		function() { 
 			showNode("calendarAppointmentDetail");
-			$("calendarAppointmentDetail").style.display=""; }, 
+			$("calendarAppointmentDetail").style.display="";
+	    },
+		// ENTER
 		function() { 
 			register("OX_Refresh",reloadAppDetailView);
 			register("OX_AcceptDeny_Changed",reloadAppDetailView);
 			register("OX_Confirmation_Change",caldetail_change_Confirm);
-			if(selectedAppointment.length && selectedAppointment.length == 1) {
-				selectedAppointment = selectedAppointment[0];
+			register("OX_Add_Flag", calendarAddTag);
+			// added "lastSelectedAppointment" so that this also works with the
+			// team view. This view (correctly) clears its selection when leaving
+			// the view. so: last selected appointment or normal selection?
+			var selectedApp = selectedAppointment || lastSelectedAppointment;
+			// flatten array
+			if(selectedApp.length) selectedApp = selectedApp[0];
+			// id?
+			if(selectedApp.id) {
+			    // restore selectedAppointment, since the next function uses global magic
+			    selectedAppointment = selectedApp;
+				detailAppointmentOnload();
 			}
-			if(selectedAppointment.id)
-			{
-				detailAppointmentOnload();									
-			}			
-			
-			if(typeof selectedAppointment == 'undefined' || selectedAppointment == '')
-			{
+			if(typeof selectedAppointment == 'undefined' || selectedAppointment == '') {
 				triggerEvent("OX_New_Error", 4, _("No Appointment selected."));
 			}
-			register("OX_Add_Flag", calendarAddTag);	
-		 }, 
-		 function() {
-		 	//LEAVE
-			unregister("OX_Refresh",reloadAppDetailView);
-			unregister("OX_AcceptDeny_Changed",reloadAppDetailView);
-			unregister("OX_Confirmation_Change",caldetail_change_Confirm);
-			unregister("OX_Add_Flag", calendarAddTag);
-			objAppDetailParticipants = null;
-		 },
+        },
+        // LEAVE
+        function() {
+        	unregister("OX_Refresh",reloadAppDetailView);
+        	unregister("OX_AcceptDeny_Changed",reloadAppDetailView);
+        	unregister("OX_Confirmation_Change",caldetail_change_Confirm);
+        	unregister("OX_Add_Flag", calendarAddTag);
+        	objAppDetailParticipants = null;
+        },
 		function() { 			
 			hideNode("calendarAppointmentDetail");
 			$("calendarAppointmentDetail").style.display="none";
@@ -607,6 +702,61 @@ function calendar_printList() {
 	globalprint.printLiveGrid(calendarGrid);
 }
 
+//Templates
+register("OX_Configuration_Loaded", 
+	function() {
+		// just enable template printing if bundle is installed and enabled
+		if (configContainsKey("modules.calendar.printing") && 
+				configGetKey("modules.calendar.printing") == true) {
+            registerPrintView("calendar/calendar/day");
+			registerPrintView("calendar/calendar/workweek");
+			registerPrintView("calendar/calendar/week");
+			registerPrintView("calendar/calendar/month");
+		}
+	}
+)
+
+function calendar_printDay() {
+    var start = Date.UTC(activeYear, activeMonth, activeDay);
+    calendar_print("cp_dayview_table.tmpl", start, start + 864e5); // ms/day
+}
+
+function calendar_printWorkweek() {
+    var date = new Date(Date.UTC(activeYear, activeMonth, activeDay));
+    var start = getDayInSameWeek(date, startofweek) * 864e5; // ms/day
+    var numdays = configGetKey("gui.calendar.workweek.countdays");
+    calendar_print("cp_weekview_table.tmpl", start,
+                   start + numdays * 864e5, numdays); // ms/day
+}
+
+function calendar_printWeek() {
+    var date = new Date(Date.UTC(activeYear, activeMonth, activeDay));
+    var start = getDayInSameWeek(date, weekStart) * 864e5; // ms/day
+    calendar_print("cp_weekview_table.tmpl", start, start + 6048e5); // ms/week
+}
+
+function calendar_printMonth() {
+    calendar_print("cp_monthview_table.tmpl",
+        Date.UTC(activeYear, activeMonth, 1),
+        Date.UTC(activeYear, activeMonth + 1, 1));
+}
+
+function calendar_print(template, start, end, numdays) {
+    ox.JSON.get(AjaxRoot + "/printCalendar?start=" + start + "&end=" + end +
+        "&template=" + template +
+        (calendar_getAllFoldersAttribute() ? "" : "&folder=" + activefolder) +
+        "&work_day_start_time=" + getWWStartTime() +
+        "&work_day_end_time=" + getWWEndTime() +
+        (numdays ? "&work_week_day_amount=" + numdays : "") +
+        "&session=" + session, function(reply) {
+            var w = newWindow("newInfoItemHidden.html",
+                "location=no,menubar=no,resizable=yes, scrollbars=yes,status=no,toolbar=no");
+            w.document.open();
+            w.document.write(reply);
+            w.document.close();
+        }, null, true);
+}
+
 function default_calendar_create_object(module,folder) {
 	if (module=="calendar") {
 		var d=new Date();
@@ -620,13 +770,13 @@ function default_calendar_create_object(module,folder) {
 		if(mymin % myinterval) {
 			mymin=mymin - (mymin % myinterval)+ myinterval;
 		}
-		d.setUTCMinutes(mymin);		
+		d.setUTCMinutes(mymin);
 		calendar_createNewAppointment(d, folder, false, 
 				(currentpath2.join("/").match(/^calendar\/team\//) ? ctd_tv_members : null));	
 	}
 }
 
-function calendar_createNewAppointment(startdate,infolder,wholeday,oFromMail) {	
+function calendar_createNewAppointment(startdate,infolder,wholeday,oFromMail,endDate) {	
 	var checkfolder;
 	var wholeday=wholeday;
 	var folder_id_tocheck  = (infolder)?infolder:((activefolder)?activefolder:config.folder.calendar);
@@ -649,15 +799,19 @@ function calendar_createNewAppointment(startdate,infolder,wholeday,oFromMail) {
 			} else {
 				var userId = configGetKey('identifier');
 			}
-			if(!wholeDay){
-				var windowRef = newWindow("newAppointment.html#modul=new&folder_id="+infolder+"&view="+currentCalendarView+"&start_date="+startdate.getTime()+"&folderOwner="+userId, getWindowOptions());
-				if(oFromMail)
-				{
-					windowRef.sFromModule = oFromMail.module;										
-					windowRef.oFromMail = oFromMail.data;
-				}				
-			} else {
-				newWindow("newAppointment.html#modul=new&folder_id="+infolder+"&view="+currentCalendarView+"&start_date="+startdate.getTime()+"&full_time="+wholeDay+"&folderOwner="+userId, getWindowOptions());
+			// end date given?
+            endDate = endDate ? endDate.getTime() : "";
+            var uri = "newAppointment.html#modul=new&folder_id="+infolder+"&view="+currentCalendarView+"&start_date="+startdate.getTime()+"&end_date="+endDate+"&folderOwner="+userId;
+            // is all day?
+			if (wholeDay){
+			    uri += "&full_time="+wholeDay;
+			}
+			// open window
+			var windowRef = newWindow(uri, getWindowOptions());
+			if (oFromMail) {
+			    // to add participants for example
+				windowRef.sFromModule = oFromMail.module;
+				windowRef.oFromMail = oFromMail.data;
 			}				
 		}
 	}
@@ -973,12 +1127,24 @@ function openAppointmentPopup(e) {
 	}
 	if (e) { stopEvent(e) };
 }
+
 function deleteAppointment(){
+    
+    // the team view has its own handling of deleting appointments
+    if (activemodule == "calendar" && currentpath2[1] == "team") {
+        calendarGrid_deleteSelectedAppointments();
+        return;
+    }
+
+    // get latest timestamp
+    // start with "now"
 	var timestamplocal = new Date().getTime()
 	if (activemodule == "calendar") {
 		if (currentpath2[1] == "list" && calendarGrid.storage.timestamp) {
+		    // get storage timestamp
 			timestamplocal = calendarGrid.storage.timestamp;
 		} else if (lastUpdateOfCalendarTimestamp) {
+		    // get global timestamp
 			timestamplocal = lastUpdateOfCalendarTimestamp;
 		}
 	}
@@ -1003,6 +1169,7 @@ function deleteAppointment(){
 	
 	var fn_afterDelete_Appoitment = function(cb) {
 		triggerEvent("OX_Refresh_Mini_Calendar");
+		triggerEvent("OX_After_Delete_Appointment");
 		for(var i=0; i<cb.length;i++){
 			if(cb[i] && cb[i].error){
 				newServerError(cb[i],4);	
@@ -1084,4 +1251,31 @@ function ignoreConflict(){
 	$("appointmentConflictWindow").style.display = "none";
 }
 
+var cal_numOfObj = null; // last shown number of objects in head line
+/**
+ * change the number of objects in the folder shown in the headline of each view
+ * @param num {Integer} the number to shown in the head line
+ */
+function calendar_HeaderUpdate(num) {
+	if (cal_numOfObj == num) return; // nothing changed so nothing to render
+	cal_numOfObj = num;
+	calendarFolderPath.additionalNode=document.createTextNode(" (" + cal_numOfObj + ")");
+	var view = "calendarofworkweekview";
+	switch (currentpath2.join("/")) {
+		case "calendar/calendar/month": 
+			view = "calendarofmonthview"; 
+			break;
+		case "calendar/calendar/week":
+			view = "calendarofweekview";
+			break;
+		case "calendar/list/day":
+		case "calendar/list/workweek":
+		case "calendar/list/month":
+		case "calendar/list/week":
+			view = "calendaroflistview";
+			break;
+	}
+	calendarFolderPath.drawDOMNode(view, activefolder);
+}
+
 fileloaded();
\ No newline at end of file
