@@ -31,176 +31,182 @@ function initCalenderLiveGridOnLoad() {
 		calendarGrid = null;
 	}
 	
-	calendarGrid = new LiveGrid([
-		{	
-			text: "&#160;",
-			sortable: false,
-			width: "16px",
-			style: {padding: 0},
-			set: function(div, text) {
-				if (div.firstChild)
-					div.firstChild.src = text > 0 ? getFullImgSrc("img/calendar/calendar_series.gif") : getFullImgSrc("img/calendar/calendar16x16.gif");
-				else
-					div.appendChild(newnode("img", 0,
-						{src: text > 0 ? getFullImgSrc("img/calendar/calendar_series.gif") : getFullImgSrc("img/calendar/calendar16x16.gif"), alt: "Serie"}));
-			},
-			clear: function(div) {
-				if (div.firstChild)
-					div.firstChild.src = getFullImgSrc("img/dummy.gif");
-				else
-					div.appendChild(newnode("img", 0,
-						{src: getFullImgSrc("img/dummy.gif"), alt: "Serie", width: "16", height: "16"}));
-			},
-			index:5
-		}, {	
-			text: "&#160;",
-			sortable: false,
-			width: "16px",
-			style: {padding: 0},
-			set: function(div, text) {
-				if(text[12] && text[12].length > 1) {
-					var imgSrc = getFullImgSrc("img/calendar/group.gif");
-				} else {
-					var imgSrc = getFullImgSrc("img/dummy.gif");
-				}
-				if (div.firstChild) {
-					div.firstChild.src = !text[6] ? imgSrc : getFullImgSrc("img/private_flag.gif");
-					div.firstChild.alt = !text[6] ? "G" : "P";
-				} else {
-					div.appendChild(newnode("img", 0,
-						{
-							src: !text[6] ? imgSrc : getFullImgSrc("img/private_flag.gif"),
-							alt: !text[6] ? "G" : "P",
-							width: "16", 
-							height: "16"							
-						}));
-				}
-			},
-			clear: function(div) {
-				if (div.firstChild)
-					div.firstChild.src = getFullImgSrc("img/dummy.gif");
-				else
-					div.appendChild(newnode("img", 0,
-						{src: getFullImgSrc("img/dummy.gif"), alt: "G", width: "16", height: "16"}));
-			}
-		}, {
-            i18n: "description", /*i18n context*/
-			text: "Title", /*i18n*/
-			sortable: true,
-			id: 200,
-			set: LiveGrid.defaultSet,
-			clear: LiveGrid.makeClear(""),
-			index:7
-		}, {
-			text: "Start", /*i18n*/
-			sortable: true,
-			i18n: true,
-			id: 201,
-			width: "14%",
-			set: function(div, data) {
-                if (!div.firstChild) {
-                    div.appendChild(document.createTextNode(" "));
-                }
-                if (data) {
-                    var dateToShow = data[8];
-                    if (data[13] == true) {
-                        div.firstChild.data=formatDate(dateToShow, "date");
+    temporary.lists.calendar = temporary.MakeList({
+        updated: function() { calendarGrid.recreate(); },
+        columns: [
+            {   
+                text: "&#160;",
+                sortable: false,
+                width: "16px",
+                style: {padding: 0},
+                set: function(div, text) {
+                    if (div.firstChild)
+                        div.firstChild.src = text > 0 ? getFullImgSrc("img/calendar/calendar_series.gif") : getFullImgSrc("img/calendar/calendar16x16.gif");
+                    else
+                        div.appendChild(newnode("img", 0,
+                            {src: text > 0 ? getFullImgSrc("img/calendar/calendar_series.gif") : getFullImgSrc("img/calendar/calendar16x16.gif"), alt: "Serie"}));
+                },
+                clear: function(div) {
+                    if (div.firstChild)
+                        div.firstChild.src = getFullImgSrc("img/dummy.gif");
+                    else
+                        div.appendChild(newnode("img", 0,
+                            {src: getFullImgSrc("img/dummy.gif"), alt: "Serie", width: "16", height: "16"}));
+                },
+                index:5
+            }, {    
+                text: "&#160;",
+                sortable: false,
+                width: "16px",
+                style: {padding: 0},
+                set: function(div, text) {
+                    if(text[12] && text[12].length > 1) {
+                        var imgSrc = getFullImgSrc("img/calendar/group.gif");
                     } else {
-                        div.firstChild.data=formatDate(dateToShow, "datetime");
-                    }           
-                } else {
-                    div.firstChild.data=""; 
-                }               
-            },
-			clear: LiveGrid.makeClear("")
-		}, {
-			text: "End", /*i18n*/
-			sortable: true,
-			i18n: true,
-            id: 202,
-			width: "14%",
-			set: function(div, data) {
-				if (!div.firstChild) {
-					div.appendChild(document.createTextNode(" "));
-				}
-				if (data) {
-					var dateToShow = data[9];
-					/*
-					 * if it's a full day appointment it's minus one day
-					 */
-					if (data[13] == true) {
-						dateToShow -= 864e5; /* ms/day */
-						div.firstChild.data=formatDate(dateToShow, "date");
-					} else {
-						div.firstChild.data=formatDate(dateToShow, "datetime");
-					}			
-				} else {
-				    div.firstChild.data="";	
-				}				
-			},
-			clear: LiveGrid.makeClear("")
-		}, {
-			text: "Location", /*i18n*/
-			sortable: true,
-			i18n: true,
-			id: 400,
-			width: "10%",
-			set: LiveGrid.defaultSet,
-			clear: LiveGrid.makeClear(""),
-			index:10
-		}, {
-			text: "Folder", /*i18n*/
-			sortable: false,
-			i18n: true,
-			id: 20,
-			width: "14%",
-			set: function(div,text) {
-					if(text > 0){
-						oMainFolderTree.get_folder_path(text, function(path){
-							var tmp = path.split("/");
-							if(tmp.length == 1){
-								if(div.firstChild)
-									div.firstChild.data = tmp[tmp.length-1];
-								else
-									div.appendChild(document.createTextNode(tmp[tmp.length-1]));
-							}
-							else {
-								if(div.firstChild)
-									div.firstChild.data = tmp[tmp.length-2];
-								else
-									div.appendChild(document.createTextNode(tmp[tmp.length-2]));
-							}
-						});
-					} else {
-						if(div.firstChild)
-							div.firstChild.data = " ";
-						else
-							div.appendChild(document.createTextNode(" "));
-					}
-			},
-			clear: LiveGrid.makeClear(""),
-			index:1
-		}, {
-			text: "Flag", /*i18n*/
-			sortable: true,
-			i18n: true,
-			id: 102,
-			width: "4em",
-			set: function(div,text) {
-				if (div.firstChild)
-					div.firstChild.src = getFullImgSrc("img/menu/tag_" + (text||0) + ".gif");
-				else
-					div.appendChild(newnode("img", 0, {src: getFullImgSrc("img/menu/tag_" + (text||0) + ".gif"), alt: "tag"}));
-			},
-			clear: function(div) {
-				if (div.firstChild)
-					div.firstChild.src = getFullImgSrc("img/dummy.gif");
-				else
-					div.appendChild(newnode("img", 0, {src: getFullImgSrc("img/dummy.gif"), alt: "tag", width: "16", height: "16"}));
-			},
-			index:11
-		}
-	], calendarSelection, "calendar");
+                        var imgSrc = getFullImgSrc("img/dummy.gif");
+                    }
+                    if (div.firstChild) {
+                        div.firstChild.src = !text[6] ? imgSrc : getFullImgSrc("img/private_flag.gif");
+                        div.firstChild.alt = !text[6] ? "G" : "P";
+                    } else {
+                        div.appendChild(newnode("img", 0,
+                            {
+                                src: !text[6] ? imgSrc : getFullImgSrc("img/private_flag.gif"),
+                                alt: !text[6] ? "G" : "P",
+                                width: "16", 
+                                height: "16"                            
+                            }));
+                    }
+                },
+                clear: function(div) {
+                    if (div.firstChild)
+                        div.firstChild.src = getFullImgSrc("img/dummy.gif");
+                    else
+                        div.appendChild(newnode("img", 0,
+                            {src: getFullImgSrc("img/dummy.gif"), alt: "G", width: "16", height: "16"}));
+                }
+            }, {
+                i18n: "description", /*i18n context*/
+                text: "Title", /*i18n*/
+                sortable: true,
+                id: 200,
+                set: LiveGrid.defaultSet,
+                clear: LiveGrid.makeClear(""),
+                index:7
+            }, {
+                text: "Start", /*i18n*/
+                sortable: true,
+                i18n: true,
+                id: 201,
+                width: "14%",
+                set: function(div, data) {
+                    if (!div.firstChild) {
+                        div.appendChild(document.createTextNode(" "));
+                    }
+                    if (data) {
+                        var dateToShow = data[8];
+                        if (data[13] == true) {
+                            div.firstChild.data=formatDate(dateToShow, "date");
+                        } else {
+                            div.firstChild.data=formatDate(dateToShow, "datetime");
+                        }           
+                    } else {
+                        div.firstChild.data=""; 
+                    }               
+                },
+                clear: LiveGrid.makeClear("")
+            }, {
+                text: "End", /*i18n*/
+                sortable: true,
+                i18n: true,
+                id: 202,
+                width: "14%",
+                set: function(div, data) {
+                    if (!div.firstChild) {
+                        div.appendChild(document.createTextNode(" "));
+                    }
+                    if (data) {
+                        var dateToShow = data[9];
+                        /*
+                         * if it's a full day appointment it's minus one day
+                         */
+                        if (data[13] == true) {
+                            dateToShow -= 864e5; /* ms/day */
+                            div.firstChild.data=formatDate(dateToShow, "date");
+                        } else {
+                            div.firstChild.data=formatDate(dateToShow, "datetime");
+                        }           
+                    } else {
+                        div.firstChild.data=""; 
+                    }               
+                },
+                clear: LiveGrid.makeClear("")
+            }, {
+                text: "Location", /*i18n*/
+                sortable: true,
+                i18n: true,
+                id: 400,
+                width: "10%",
+                set: LiveGrid.defaultSet,
+                clear: LiveGrid.makeClear(""),
+                index:10
+            }, {
+                text: "Folder", /*i18n*/
+                sortable: false,
+                i18n: true,
+                id: 20,
+                width: "14%",
+                set: function(div,text) {
+                        if(text > 0){
+                            oMainFolderTree.get_folder_path(text, function(path){
+                                var tmp = path.split("/");
+                                if(tmp.length == 1){
+                                    if(div.firstChild)
+                                        div.firstChild.data = tmp[tmp.length-1];
+                                    else
+                                        div.appendChild(document.createTextNode(tmp[tmp.length-1]));
+                                }
+                                else {
+                                    if(div.firstChild)
+                                        div.firstChild.data = tmp[tmp.length-2];
+                                    else
+                                        div.appendChild(document.createTextNode(tmp[tmp.length-2]));
+                                }
+                            });
+                        } else {
+                            if(div.firstChild)
+                                div.firstChild.data = " ";
+                            else
+                                div.appendChild(document.createTextNode(" "));
+                        }
+                },
+                clear: LiveGrid.makeClear(""),
+                index:1
+            }, {
+                text: "Flag", /*i18n*/
+                sortable: true,
+                i18n: true,
+                id: 102,
+                width: "4em",
+                set: function(div,text) {
+                    if (div.firstChild)
+                        div.firstChild.src = getFullImgSrc("img/menu/tag_" + (text||0) + ".gif");
+                    else
+                        div.appendChild(newnode("img", 0, {src: getFullImgSrc("img/menu/tag_" + (text||0) + ".gif"), alt: "tag"}));
+                },
+                clear: function(div) {
+                    if (div.firstChild)
+                        div.firstChild.src = getFullImgSrc("img/dummy.gif");
+                    else
+                        div.appendChild(newnode("img", 0, {src: getFullImgSrc("img/dummy.gif"), alt: "tag", width: "16", height: "16"}));
+                },
+                index:11
+            }
+        ]
+    });
+	
+	calendarGrid = new LiveGrid(temporary.lists.calendar.columns,
+        calendarSelection, "calendar");
 	calendarGrid.contextmenu = globalContextMenus.calendar;
 	
     calendarGrid.sort = function(id, order) {
@@ -244,6 +250,8 @@ function initCalenderLiveGridOnLoad() {
 		OXAppointmentHover.refillContent(id.id,id.folder,id.recurrence_position);					
 	});
 	hover.setSize(OXAppointmentHover.contentobject.node);
+		
+	calendarGrid.events.register("Changed", function(data) { calendar_HeaderUpdate(data.ids.length); });
 }
 var cwwcurrentmonday
 function initLiveGridCalendar(range) {
@@ -446,7 +454,8 @@ function updateHeaderListView() {
 		case "workweek":
 			$("calendarlistheaderdiv").style.visibility = "visible";		
 			var oCalendarTool = new calendarTool(activeMonth,activeYear);
-			$("calendarlistheader").firstChild.data = _("CW") + " " + oCalendarTool.getKW(activeYear,activeMonth,activeDay) + " " + activeYear;
+			$("calendarlistheader").firstChild.data = _("CW") + " " + 
+					formatDateTime("w yyyy", new Date(getKeyDayOfWeek(new Date(Date.UTC(activeYear,activeMonth,activeDay))) * 864e5));
 			break;
 		case "month":
 			$("calendarlistheaderdiv").style.visibility = "visible";		
@@ -465,7 +474,7 @@ function disableCalendarGrid(){
 	unregister("OX_Add_Flag", calendarAddTag);
 }
 var currentCalendarTagProgress = false;
-function calendarAddTag(tag) {
+function calendarAddTag(tag, editSingleSeriesOnly) {
 	if(currentCalendarTagProgress) return;
 	currentCalendarTagProgress = true;
 	var tmpselected;
@@ -473,8 +482,9 @@ function calendarAddTag(tag) {
 		lastUpdateOfCalendarTimestamp = storageCache.current.timestamp;
 	}
 	function edit_whole_series() {
+	    // process appointments in order to remove the recurrence position
 		for(var i=0;i<tmpselected.length;i++) {
-			tmpselected[i] = { id : tmpselected[i].id, folder : tmpselected[i].folder };
+			tmpselected[i] = { id: tmpselected[i].id, folder: tmpselected[i].folder };
 		}
 		setTag(tag, tmpselected, lastUpdateOfCalendarTimestamp, finalSetTag);
 	}
@@ -486,6 +496,7 @@ function calendarAddTag(tag) {
 	} else { 
 		tmpselected=[selectedAppointment];
 	}
+	var editSingleSeriesOnly = !!editSingleSeriesOnly;
 	var isseries=false;
 	for(var x=0;x<tmpselected.length;x++) {
 		if(tmpselected[x].recurrence_position>0 && tmpselected[x].recurrence_id &&
@@ -494,7 +505,7 @@ function calendarAddTag(tag) {
 			break;
 		}
 	}
-	if(isseries) {
+	if(isseries && !editSingleSeriesOnly) {
 		if(tmpselected.length>1) {
 			newConfirm(_("Edit Appointment"),_("Do you want to edit the whole series or single series appointments? Please note when changing a serial appointment, exceptions to the series are reset."),AlertPopup.SERIESBUTTON,null,null,null,null,edit_whole_series,edit_single_series);			
 		} else {
@@ -510,6 +521,8 @@ function calendarAddTag(tag) {
 			reloadAppDetailView();
 		else
 			updateCalendarViewCbSetTag(timestamp);
+		// notify
+		triggerEvent("OX_After_Update_Appointment");
 	}
 }
 var tmpStorage;
