@@ -36,9 +36,12 @@ function fn_minicalendar_action() {
 	activeDay=oMiniCalendar.selectedDate;
 	activeMonth=oMiniCalendar.selectedMonth;
 	activeYear=oMiniCalendar.selectedYear;
+	
+	// notify
+	triggerEvent("OX_Mini_Calendar_Date_Picked", activeYear, activeMonth, activeDay);
 
 	if(currentpath[0] == "calendar") {
-		if (currentpath[2] == "month"){
+		if (currentpath[2] == "month") {
 	        loadMonthView();
 		} 	
 		triggerEvent("OX_Switch_View",currentpath.join("/"));			
