@@ -26,7 +26,7 @@ var currentAppointmentDetailTab = 'appointment';
 var aPrintDetailApp = new Array();
 function caldetail_change_Confirm() {
 	var calconfirm=new AcceptDeny(true);
-	calconfirm.showConfirmation(new AcceptDenyObject("calendar",completedetailappointment));
+	calconfirm.showConfirmation([new AcceptDenyObject("calendar",completedetailappointment)]);
 }
 /********************************** Tab Appointment *****************************************************************/
 register("OX_Calendar_Switch_Detail",function(param) { menuswitchCalendarDetail(param) });
@@ -470,7 +470,7 @@ AppDetailParticipants.prototype = {
 		setTimeout(
 			function(){
 				if(objAppDetailParticipants && objAppDetailParticipants.idResourceArr) {
-					internalCache.getRessources(objAppDetailParticipants.idResourceArr,transit_a_d_fnSetResourceColumn)
+					internalCache.getResources(objAppDetailParticipants.idResourceArr,transit_a_d_fnSetResourceColumn)
 				}
 			}, 0
 		);
