@@ -61,14 +61,18 @@ function cAnimMiniCalendar(actionFunction, oDOMHeader) {
 			} else if (aInf[1] == 2) {
 				oDate.setMonth(oDate.getMonth()-1);
 			}
-			oDate.setDate(nDate);			
-			function fn() {				
+			oDate.setDate(nDate);
+			function fn() {
+			    
+			    // notify via event
+			    triggerEvent("OX_Mini_Calendar_Date_Picked", oDate.getUTCFullYear(), oDate.getUTCMonth(), oDate.getUTCDate());
+			    
 				if((currentpath2[0] == "calendar") && 
 							(currentpath2[1] == "calendar") &&
 									(currentpath2[2] == "week")) {
 					objWeekCalendarTool.init(oDate.getFullYear(),oDate.getMonth(),oDate.getDate());
 					objWeekCalendarTool.setKW();			
-				} else {
+				} else if (currentpath2[1] != "team") {
 					triggerEvent('OX_Switch_View','calendar/calendar/week');		
 					objWeekCalendarTool.init(oDate.getFullYear(),oDate.getMonth(),oDate.getDate());
 					objWeekCalendarTool.setKW();
@@ -218,6 +222,10 @@ cAnimMiniCalendar.prototype = {
 	    activeDay=today.getUTCDate();
         activeMonth=today.getUTCMonth();
         activeYear=today.getUTCFullYear();
+        
+        // notify via event
+        triggerEvent("OX_Mini_Calendar_Date_Picked", activeYear, activeMonth, activeDay);
+        
         if (currentpath2[0] == "calendar") {
         	switch(currentpath2[2]) {
         		case "week":
@@ -332,7 +340,7 @@ function cMini3XCalendar(actionFunction,oDOMHeader)
 			{
 				oDate.setMonth(oDate.getMonth()-1);
 			}
-			oDate.setDate(nDate);			
+			oDate.setDate(nDate);		
 			function fn()
 			{				
 				if((currentpath2[0] == "calendar") && 
@@ -904,10 +912,11 @@ cMiniCalendar.prototype = {
 	            activeDay=1;
 	            activeMonth=Self.currentMonth;
 	            activeYear=Self.currentYear;
+	            
 	            Self.setSelectedByDate(activeYear, activeMonth, activeDay);
 	            if (currentpath2[0] == "calendar") {
-	                loadMonthView();
-	                triggerEvent("OX_Switch_View","calendar/calendar/month");
+                    loadMonthView();
+                    triggerEvent("OX_Switch_View","calendar/calendar/month");
 	            } else if (configContainsKey("folder.calendar")) {
 	                setActiveFolder(configGetKey("folder.calendar"), function () {
 	                    triggerEvent("OX_Switch_View","calendar/calendar/month"); 
