@@ -89,10 +89,9 @@ function resizeWeekSections() {
 				}				
 			}				
 		}
-		var aSplittId = oCurrentNode.id.split("_");
-		if(aSplittId[0] == "weekmonth" || true)
-		{
-			if((height)>0)
+		var aSplittId = oCurrentNode.id ? oCurrentNode.id.split("_") : [];
+		if(aSplittId[0] == "weekmonth" || true) {
+			if((height)>0 && oCurrentNode.style)
 				oCurrentNode.style.height = (height) + "px";
 		}
 	}
@@ -876,9 +875,10 @@ monthView.prototype = {
 				monthViewCreated = true;				
 				Self.timestamp = storage.timestamp;
 				lastUpdateOfCalendarTimestamp  = Self.storage.timestamp;
+				calendar_HeaderUpdate(Self.storage.ids.length);
 			};
 				
-			Self.storage.events.register("Changed", Self.redraw);
+			Self.storage.events.register("Changed", Self.redraw);			
 
 			storage.newIterate(storage.ids, emptyFunction, function(x,y) {
 				Self.buildAppointments(x,y);	
