@@ -48,8 +48,8 @@ var configGetKey = corewindow.configGetKey;
 var configSetKey = corewindow.configSetKey;
 var savePending = false;
 var folderOwner = null;
-var sFromModule;
-var oFromMail;
+//var sFromModule;
+//var oFromMail;
 var externalParticipants = null;
 
 //register("Loaded",initAppointment);
@@ -240,9 +240,8 @@ function newAppointmentOnload(){
 	
 	config = corewindow.config;
 	var themeStyle = corewindow.oxThemeStyle || { name: "Default", path: "default" };		
-	loadCSSFileForNewWindow("themes/"+themeStyle.path+"/css/global.css");
+	removeCSSFilesForNewWindow(themeStyle.path);
 	loadCSSFileForNewWindow("themes/"+themeStyle.path+"/css/popup.css");
-	loadCSSFileForNewWindow("themes/"+themeStyle.path+"/css/bgimages.css");
 	loadCSSFileForNewWindow("themes/"+themeStyle.path+"/css/calendar.css");
 	
 	window.setTimeout(function() {
@@ -779,6 +778,9 @@ function fillFields(){
         }
 	
         var extPart = {};
+        // use clone to clean up the data provided by the core window
+        var oFromMail = window.oFromMail = clone(window.oFromMail, corewindow);
+        var sFromModule = window.sFromModule = clone(window.sFromModule, corewindow);
         // adding mail information
 		if (oFromMail != undefined && sFromModule == "mail") {
 			url['title'] = oFromMail[0].subject;
@@ -819,14 +821,14 @@ function fillFields(){
 		}
 		// adding participants
 		if (oFromMail && sFromModule == "contacts") {			
-			for (var i = 0; i< oFromMail.length; i++) {				
+			for (var i = 0; i< oFromMail.length; i++) {
 				if (oFromMail[i][1] == 6 || oFromMail[i][7] != undefined) {
 					// these are internal users
 					calenObj['participants'].push({id: oFromMail[i][4], type: oFromMail[i][7] || 1});
-					calenObj['users'].push({id: oFromMail[i][4], type:1});
+					calenObj['users'].push({id: oFromMail[i][4], type: oFromMail[i][7] || 1});
 				} else {
 					// external users
-					extPart[oFromMail[i][3]] = oFromMail[i][2];                    
+					extPart[oFromMail[i][3]] = oFromMail[i][2];
 				}
             }				
 		}
@@ -971,15 +973,14 @@ function setFields(object) {
 	if(globalseries != null)
 		globalseries.setParameters(calenObj);
 	
-	// enable final participant object
-	newAppointment.participants.initalFillBigGrid(calenObj);
-    participantsLoaded = true;
-    setTimeout(function() { 
-    	setNumberOfParticipants(); 
-    }, 250);
-	
-    // disable loading screen
-    $("loading_data_bg").style.display="none";
+	// enable final participant object (and wait for callback)
+	newAppointment.participants.initalFillBigGrid(calenObj, function() {
+	    participantsLoaded = true;
+	    // set participants tab
+	    setNumberOfParticipants();
+	    // disable loading screen
+	    $("loading_data_bg").style.display="none";
+	});
 }
 
 function createComboxes(){
@@ -1058,6 +1059,10 @@ function fn_afterUpload(errorUpdate) {
 		if (!errorUpdate) window.setTimeout("window.close()", 0);
 	}
 	
+	if (newAppointment.attachmentDialog.attach_changed()) {
+        corewindow.triggerEvent("OX_Quota_Update");
+    }
+	
 	// is the current view of the opener of type calendar?
 	// if not we just close this window
 	if (!corewindow || corewindow.currentpath[0] != "calendar")  {
@@ -1069,7 +1074,8 @@ function fn_afterUpload(errorUpdate) {
 		if (corewindow.currentpath[1] == "detail") {
 			corewindow.reloadAppDetailView(fn_close, clickedItem);							
 		} else if (corewindow.currentpath.join("/") == "calendar/team/day") {
-			corewindow.ctd_startContent();
+		    // trigger event
+		    corewindow.triggerEvent("OX_After_New_Appointment");
 			setTimeout(fn_close, 0);
 		} else if (corewindow.currentpath.join("/") == "calendar/team/workweek") {
 			corewindow.loadTeamWeek()
@@ -1181,20 +1187,25 @@ function writeNewAppointment() {
 				}
 				if(globalseries != null)
 					ap_object=globalseries.getParameters(ap_object);
-				json.put(AjaxRoot + "/calendar?action=new&session=" + session, ap_object, null, function(cb){
-					if(cb && cb.data && cb.data.id) {							
+				
+				// create new appointment
+				json.put(AjaxRoot + "/calendar?action=new&session=" + session, ap_object, null, function(cb) {
+				    // success?
+					if(cb && cb.data && cb.data.id) {
+					    
+					    // create dummy divs that are helpful for QA tests
 						var myCreatedAppDiv = document.createElement("div");
 						myCreatedAppDiv.id = "newAppointmentId"; //for QA
 						myCreatedAppDiv.style.display = "none";
 						myCreatedAppDiv.innerHTML = cb.data.id;
 						$('body').appendChild(myCreatedAppDiv);
-						
+
 						var myCreatedAppDivFolder = document.createElement("div");
 						myCreatedAppDivFolder.id = "newAppointmentFolder"; //for QA
 						myCreatedAppDivFolder.style.display = "none";
 						myCreatedAppDivFolder.innerHTML = ap_object.folder_id;
 						$('body').appendChild(myCreatedAppDivFolder);
-		
+
 						if (newAppointment.attachmentDialog.attach_changed()) 
 						{
 							setBeforeUnload(true);
