@@ -300,8 +300,8 @@ WeekCalendarTool.prototype = {
 						removeDDPreviewDivs );//removeDDPreviewDivs				
 			})(inWeekDay)
 		}
-		$('weekviewheader').firstChild.nodeValue = _("CW") /*i18n*/ 
-										+ " " + this.currentKW + " " + this.yearUTC;
+		$('weekviewheader').firstChild.nodeValue = _("CW") + " " + 
+				formatDateTime("w yyyy", new Date(getKeyDayOfWeek(new Date(Date.UTC(activeYear,activeMonth,activeDay))) * 864e5));
 		
 	},
 	goToNextWeek: function(nDirection) {		
@@ -341,18 +341,16 @@ WeekCalendarTool.prototype = {
 		for (var t = 1; t< 8; t++)
 		 		$("imageList"+t).style.display = "none";
 		allcalendarWeekObjects = {};
-		this.weekAppointments = new Array()
+		this.weekAppointments = new Array();
 		for(var i=0; i<7;i++) {
 			removeChildNodes($('weekDayContent'+i));
-			var fullTimeDIV = newnode('div');
-			fullTimeDIV.className = 'containerFullTimeWeek';
-			$('weekDayContent'+i).appendChild(fullTimeDIV);
-		}		
+		}
 	},
 	updateView: function() {
 		this.clearContentFields();
 		this.iterateStorage();
 		lastUpdateOfCalendarTimestamp = storageCache.current.timestamp;
+		calendar_HeaderUpdate(weekStorage.ids.length);
 	},
 	showAllAppointments: function(mybool) {
 		this.showallappointments=mybool;
@@ -421,9 +419,11 @@ WeekCalendarTool.prototype = {
 		object["indxxx"]  = index;
 	},
 	sortAppointments: function() {
-		this.weekAppointments.sort(function(a,b){
-			return (a[4] == b[4]) ? (a[3] < b[3]) ? -1 : 1 : (a[4] < b[4]) ? -1 : 1;
-		});
+		this.weekAppointments.sort(
+			function(a, b){
+				return (a[9] || a[4] < b[4] ? -1 : 1); 
+			}
+		);
 		for(var i=0; i<this.weekAppointments.length;i++) {
 			this.generateCalendarObjects(this.weekAppointments[i]["indxxx"],this.weekAppointments[i]);
 		}
@@ -459,51 +459,31 @@ WeekCalendarTool.prototype = {
 		}		
 		
 		var textDiv;
-		if(!object.full_time) {	
-			shownDiv.appendChild(document.createTextNode(" "));
-			var datDIV = newnode('div');
-			datDIV.className = 'appInWeekView borderDefault background-color-content border-color-design';
-			textDiv = newnode('div');
-			textDiv.className = "showAppointmentTextWeek mozSelected";
-			
-			textDiv.appendChild(document.createTextNode(textToView));
-			datDIV.appendChild(shownDiv);	
-			datDIV.appendChild(textDiv);
-			
-			if (divIconParticipant.firstChild) datDIV.appendChild(divIconParticipant);
-			if (divIconPrivate.firstChild) datDIV.appendChild(divIconPrivate);
-			if (divIconTag.firstChild) datDIV.appendChild(divIconTag);
-			
-			if(object.recurrence_type > 0) {
-				var image=document.createElement("img");
-				image.setAttribute("src",getFullImgSrc("img/calendar/calendar_series.gif"));
-				var seqDiv = newnode('div', {}, { className: "showAppointmentSeqWeek"});
-				seqDiv.className = "showAppointmentSeqWeek";	
-				seqDiv.appendChild(image);
-				datDIV.appendChild(seqDiv);	
-			}
-		} else {	
-			shownDiv.appendChild(document.createTextNode(" "));
-			var datDIV = newnode('div');
+		shownDiv.appendChild(document.createTextNode(" "));
+		var datDIV = newnode('div');
+		if (object.full_time) {
 			datDIV.className = 'textFullTimeWeek wholeDayBackground border-color-design borderDefault';
-			textDiv = newnode("div", {flt:"left", width: "80%"}, null, [document.createTextNode(textToView)])
-			textDiv.className="mozSelected"
-			datDIV.appendChild(shownDiv);	
-			datDIV.appendChild(textDiv);
-
-            if (divIconParticipant.firstChild) datDIV.appendChild(divIconParticipant);
-            if (divIconPrivate.firstChild) datDIV.appendChild(divIconPrivate);
-            if (divIconTag.firstChild) datDIV.appendChild(divIconTag);
-
-			if(object.recurrence_type > 0) {
-				var image=document.createElement("img");
-				image.setAttribute("src",getFullImgSrc("img/calendar/calendar_series.gif"));
-				var seqDiv = newnode('div');
-				seqDiv.className = "showAppointmentSeqWeek";	
-				seqDiv.appendChild(image);
-				datDIV.appendChild(seqDiv);	
-			}
-			datDIV.style.height = 1.9 + "em";
+		} else {
+			datDIV.className = 'appInWeekView borderDefault background-color-content border-color-design';
+		}
+		textDiv = newnode('div');
+		textDiv.className = "showAppointmentTextWeek mozSelected";
+		
+		textDiv.appendChild(document.createTextNode(textToView));
+		datDIV.appendChild(shownDiv);	
+		datDIV.appendChild(textDiv);
+		
+		if (divIconParticipant.firstChild) datDIV.appendChild(divIconParticipant);
+		if (divIconPrivate.firstChild) datDIV.appendChild(divIconPrivate);
+		if (divIconTag.firstChild) datDIV.appendChild(divIconTag);
+		
+		if (object.recurrence_type > 0) {
+			var image=document.createElement("img");
+			image.setAttribute("src",getFullImgSrc("img/calendar/calendar_series.gif"));
+			var seqDiv = newnode('div', {}, { className: "showAppointmentSeqWeek"});
+			seqDiv.className = "showAppointmentSeqWeek";	
+			seqDiv.appendChild(image);
+			datDIV.appendChild(seqDiv);	
 		}
 		
 		return datDIV;						
@@ -558,8 +538,11 @@ WeekCalendarTool.prototype = {
 		var timeWeekpart1 = formatDate(appointmentDate, "time");
 		var timeWeekpart2 = formatDate(appointmentDateEnd, "time");
 		
-		if (!title) title="";
-		var textToView =  timeWeekpart1 + " - " + timeWeekpart2 + "  " + title;
+		if (!title) title = "";		
+		var textToView = timeWeekpart1 + " - " + timeWeekpart2 + "  " + title;
+		if (full_time) {
+			textToView = title; 
+		}
 		var divId = "weekDayContent" + appointmentDate.getUTCDay();
 		
 		this.aAppointmentAssoc[divAppId] = this.object;
@@ -618,10 +601,19 @@ WeekCalendarTool.prototype = {
 		var titlesMultidays = [];
 		if (days > 1) {
 			var timeA = formatDate(new Date(Date.UTC(1970,1,1,0,0,0)), "time");
-			var timeB = formatDate(new Date(Date.UTC(1970,1,1,23,59,59)), "time");
+			var timeB = formatDate(new Date(Date.UTC(1970,1,1,23,59,59)), "time");			
 			textToView = titlesMultidays[0] = timeWeekpart1 + " - " + timeB + "  " + title;
+			if (full_time) {
+				textToView = titlesMultidays[0] = title;
+			}
 			titlesMultidays[1] = timeA + " - " + timeB + "  " + title;
+			if (full_time) {
+				titlesMultidays[1] = title; 
+			}
 			titlesMultidays[2] = timeA + " - " + timeWeekpart2 + "  " + title;
+			if (full_time) {
+				titlesMultidays[2] = title;
+			}
 		}
 
 		var Self = this;
@@ -672,91 +664,96 @@ WeekCalendarTool.prototype = {
 				$2("cww_node_dd").parentNode.removeChild($2("cww_node_dd"));
 			}
 		}
+
+		shownDiv.appendChild(document.createTextNode(" "));
+		var cName = "appInWeekView background-color-content border-color-design borderDefault";
+		if (full_time) {
+			cName = "textFullTimeWeek wholeDayBackground border-color-design borderDefault";
+		}
 		
-	    if (!full_time) {
-			shownDiv.appendChild(document.createTextNode(" "));
-			var datDIV = newnode('div',0,{className:"appInWeekView background-color-content border-color-design borderDefault"});
-			if (selectedAppointmentWeekView == divAppId) {
-				datDIV.className = removeClass(datDIV.className,"borderDefault");
-				datDIV.className += ' selectedAppMonth border-color-selection-elements';
-			}
-			datDIV.id = divAppId;
-			datDIV.oxcalobj=""+folder_id + "-" + id + "-" + nRecPosition;
-			var textDiv = newnode('div');
-			textDiv.className = "showAppointmentTextWeek";
-			
-			if (location) {
-				textToView += " - " + location;
-			}
-			
-			// setting confirmation styles
-			if (participants.length) {
-				for (var i in participants) {
-					if (participants[i].id == config.identifier) {
-						switch(participants[i].confirmation) {
-							case 0:
-								datDIV.style.opacity = ".6";
-								textDiv.style.fontStyle = "italic";
-								textToView += " (" + _("waiting") + ")";
-								break;
-							case 2:
-								textDiv.style.textDecoration = "line-through";
-								break;
-							case 3:											
-								textDiv.style.fontStyle = "italic";
-								textToView += " (" + _("tentative") + ")";
-								break;
-						}
+		var datDIV = newnode("div", 0, { className: cName });
+		if (selectedAppointmentWeekView == divAppId) {
+			datDIV.className = removeClass(datDIV.className,"borderDefault");
+			datDIV.className += ' selectedAppMonth border-color-selection-elements';
+		}
+		datDIV.id = divAppId;
+		datDIV.oxcalobj = "" + folder_id + "-" + id + "-" + nRecPosition;
+		var textDiv = newnode('div');
+		textDiv.className = "showAppointmentTextWeek";
+		
+		if (location) {
+			textToView += " - " + location;
+		}
+		
+		// setting confirmation styles
+		if (participants.length) {
+			for (var i in participants) {
+				if (participants[i].id == config.identifier) {
+					switch(participants[i].confirmation) {
+						case 0:
+							datDIV.style.opacity = ".6";
+							textDiv.style.fontStyle = "italic";
+							textToView += " (" + _("waiting") + ")";
+							break;
+						case 2:
+							textDiv.style.textDecoration = "line-through";
+							break;
+						case 3:											
+							textDiv.style.fontStyle = "italic";
+							textToView += " (" + _("tentative") + ")";
+							break;
 					}
 				}
 			}
-			
-			textDiv.appendChild(document.createTextNode(textToView));
-			datDIV.appendChild(shownDiv);	
-			datDIV.appendChild(textDiv);
-			
-			if (divIconParticipant.firstChild) {
-				datDIV.appendChild(divIconParticipant);
-			}
-            if (divIconPrivate.firstChild) {
-            	datDIV.appendChild(divIconPrivate);
-            }
-            if (divIconTag.firstChild) {
-            	datDIV.appendChild(divIconTag);
-            }
-			
-			if (recurrence_type > 0) {
-				var image=document.createElement("img");
-				image.setAttribute("src",getFullImgSrc("img/calendar/calendar_series.gif"));
-				var seqDiv = newnode('div');
-				seqDiv.className = "showAppointmentSeqWeek";	
-				seqDiv.appendChild(image);
-				datDIV.appendChild(seqDiv);	
-			}			
-						
-			registerSource(datDIV, "calendar",
-			     function () {
-			     	objMoveCopy.begin("calendar",
-			     	[ new CalendarWorkWeekObject(
-			     	       object[0], object[1], object[2], object[14], object[15], object[3], object[4], 
-			     	       object[5], null, object[7], null, object[9], object[10],
-			     	       null,null,null)
-			     	]);
-				    return objMoveCopy;
-				     
-				 }, null,null, calendardefaultdisabled, defaultdisabledremove);
-			
-		 	var oInplEdit  = new inplaceEdit(textDiv, title, 
-		 	                    function (sStr,oObj) {
-		 	                    	editAppointment(paramObj,{title:sStr});
-								});
+		}
+		
+		textDiv.appendChild(document.createTextNode(textToView));
+		datDIV.appendChild(shownDiv);	
+		datDIV.appendChild(textDiv);
+		
+		if (divIconParticipant.firstChild) {
+			datDIV.appendChild(divIconParticipant);
+		}
+        if (divIconPrivate.firstChild) {
+        	datDIV.appendChild(divIconPrivate);
+        }
+        if (divIconTag.firstChild) {
+        	datDIV.appendChild(divIconTag);
+        }
+		
+		if (recurrence_type > 0) {
+			var image=document.createElement("img");
+			image.setAttribute("src",getFullImgSrc("img/calendar/calendar_series.gif"));
+			var seqDiv = newnode('div');
+			seqDiv.className = "showAppointmentSeqWeek";	
+			seqDiv.appendChild(image);
+			datDIV.appendChild(seqDiv);	
+		}			
+					
+		registerSource(datDIV, "calendar",
+		     function () {
+		     	objMoveCopy.begin("calendar",
+		     	[ new CalendarWorkWeekObject(
+		     	       object[0], object[1], object[2], object[14], object[15], object[3], object[4], 
+		     	       object[5], null, object[7], null, object[9], object[10],
+		     	       null,null,null)
+		     	]);
+			    return objMoveCopy;
+			     
+			 }, null,null, calendardefaultdisabled, defaultdisabledremove);
+		
+	 	var oInplEdit  = new inplaceEdit(textDiv, title, 
+	 	                    function (sStr,oObj) {
+	 	                    	editAppointment(paramObj,{title:sStr});
+							});
 
-			//fixed bug with auto selection													
-			if (calendarSelection) {
-				calendarSelection.reset();
-			}
-				
-			addDOMEvent(datDIV, "click", function(e) {
+		//fixed bug with auto selection													
+		if (calendarSelection) {
+			calendarSelection.reset();
+		}
+			
+		addDOMEvent(datDIV, "click", 
+			function(e) {
 				var SelObj = calendarSelection.getID();
 				if (SelObj && SelObj.id == paramObj.id &&
 							SelObj.folder == paramObj.folder_id &&
@@ -766,253 +763,110 @@ WeekCalendarTool.prototype = {
 					}
 					oInplEdit.on();
 				} else {					
-						setSelectionWeekView(selectedAppointmentWeek);
-						selectAppointmentWeekView(divAppId,1);
+					setSelectionWeekView(selectedAppointmentWeek);
+					selectAppointmentWeekView(divAppId, (full_time ? 2 : 1));
 				}
 				stopEvent(e);
-	
-			});	
-            addDOMEvent(datDIV, "contextmenu", function(e) {            	
-                stopEvent(e);
-                globalContextMenus.calendar.display(e.clientX, e.clientY,
-                                                    calendarSelection);
-            });
+			}
+		);
+        addDOMEvent(datDIV, "contextmenu", 
+        	function(e) {            	
+        		stopEvent(e);
+            	globalContextMenus.calendar.display(e.clientX, e.clientY, calendarSelection);
+        	}
+        );
+		addDOMEvent(datDIV, "mousedown", 
+			function(e) {
+				setSelectionWeekView(selectedAppointmentWeek);
+				selectAppointmentWeekView(divAppId, (full_time ? 2 : 1));
+												
+			}
+		);									
+		addDOMEvent(datDIV, "dblclick", 
+			function(e) {
+				setActivatedWeekView(selectedAppointmentWeek, e);
+				selectAppointmentWeekView(divAppId, (full_time ? 2 : 1));
+			}
+		);
+		
+		/*
+		 * draw the first appointment
+		 */																		
+		if (!fulltimeStartBefore) {
+			$(divId).appendChild(datDIV);
+			addTMPId(datDIV);
+		}
+		
+		/*
+		 * if appointment lasts longer then 1 day draw the rest
+		 */
+		for (var i=1; i<days; i++) {
+			var ccweek_template_app_time = datDIV.cloneNode(true);
+			if (i+1 == days) {
+				ccweek_template_app_time.childNodes[1].firstChild.nodeValue = titlesMultidays[2];
+			} else {
+				ccweek_template_app_time.childNodes[1].firstChild.nodeValue = titlesMultidays[1];
+			}
 
-			addDOMEvent(datDIV, "mousedown", function(e) {
-														setSelectionWeekView(selectedAppointmentWeek);
-														selectAppointmentWeekView(divAppId,1);
-													});									
-			addDOMEvent(datDIV, "dblclick", function(e) {
-														setActivatedWeekView(selectedAppointmentWeek, e);
-														selectAppointmentWeekView(divAppId,1);
-														});
-			/*
-			 * draw the first appointment
-			 */																		
+			var	paramObj = { id:Self.object[0],folder:Self.object[1], folder_id: Self.object[1],
+											recurrence_position:(Self.object[7]) ? Self.object[7] : 0 };
 			if (!fulltimeStartBefore) {
-				$(divId).appendChild(datDIV);
-				addTMPId(datDIV);
+				start_date += oneday;
 			}
 			
-			/*
-			 * if appointment lasts longer then 1 day draw the rest
-			 */
-			for (i=1;i<days;i++) {
-				var ccweek_template_app_time = datDIV.cloneNode(true);
-				if (i+1 == days) {
-					ccweek_template_app_time.childNodes[1].firstChild.nodeValue = titlesMultidays[2];
-				} else {
-					ccweek_template_app_time.childNodes[1].firstChild.nodeValue = titlesMultidays[1];
-				}
+			var newId = new Date(start_date).getUTCDay();
+			divId = "weekDayContent" + newId;
 
-				var	paramObj = {id:Self.object[0],folder:Self.object[1], folder_id:Self.object[1],
-												recurrence_position:(Self.object[7])?Self.object[7]:0};
-				if(!fulltimeStartBefore) {
-					start_date += oneday;
-				}
-				var newId = new Date(start_date).getUTCDay();
-				divId = "weekDayContent" + newId;
-				ccweek_template_app_time.id = datDIV.id + "-"+i;
-				ccweek_template_app_time.oxcalobj=""+folder_id + "-" + id + "-" + nRecPosition;
-				
-				addDOMEvent(ccweek_template_app_time, "click", function(e) {					
-					var SelObj = calendarSelection.getID();
-					if (SelObj && SelObj.id == paramObj.id &&
-					    SelObj.folder == paramObj.folder_id &&
-						SelObj.recurrence_position == paramObj.recurrence_position) {
-						if(window.event) {
-							e = window.event;
-						}
-						oInplEdit.on();
-					} else {
-						setSelectionWeekView(selectedAppointmentWeek);
-						selectAppointmentWeekView(divAppId,1);
-					}
-					stopEvent(e);
-		
-				});	
-                addDOMEvent(ccweek_template_app_time, "contextmenu", function(e) {
-                    if (!calendarSelection.get(index))
-                        calendarSelection.click(index, e);
-                    stopEvent(e);
-                    globalContextMenus.calendar.display(e.clientX, e.clientY,
-                                                        calendarSelection);
-                });
+			ccweek_template_app_time.id = datDIV.id + "-" + i;
+			ccweek_template_app_time.oxcalobj= "" + folder_id + "-" + id + "-" + nRecPosition;
 
-				addDOMEvent(ccweek_template_app_time, "mousedown", function(e) {
-													setSelectionWeekView(selectedAppointmentWeek);
-													selectAppointmentWeekView(divAppId,1);
-											});
-				addDOMEvent(ccweek_template_app_time, "dblclick", function(e) {
-															setActivatedWeekView(selectedAppointmentWeek);
-															selectAppointmentWeekView(divAppId,1);
-															});
-
-				$(divId).appendChild(ccweek_template_app_time);	
-				addTMPId(ccweek_template_app_time);
-				if(fulltimeStartBefore) {
-					start_date += oneday;
-				}
+			// remove if already exists!
+			if ($2(ccweek_template_app_time.id) && $2(ccweek_template_app_time.id).parentNode) {
+				$2(ccweek_template_app_time.id).parentNode.removeChild($2(ccweek_template_app_time.id));
 			}
 			
-		} else {
-			var ftDiv = newnode('div',0,{className:"textFullTimeWeek wholeDayBackground border-color-design borderDefault"});
-			ftDiv.className = removeClass(ftDiv.className,"border-color-selection-elements");
-			
-			if(selectedAppointmentWeekView == divAppId) {
-				ftDiv.className = removeClass(ftDiv.className,"borderDefault");
-				ftDiv.className +=  ' selectedAppMonth border-color-selection-elements';
-			}
-			ftDiv.id = divAppId;
-			ftDiv.oxcalobj=""+folder_id + "-" + id + "-" + nRecPosition;
-			ftDiv.appendChild(shownDiv);
-			addTMPId(ftDiv);
-			if (!title) { 
-				title = ""; 
-			}
-			if (location) {
-				title += " - " + location;
-			}
-			
-			var fullTextDiv = newnode("div", {flt:"left", width: "80%"}, null);
-			
-			// setting confirmation styles
-			if (participants.length) {
-				for (var i in participants) {
-					if (participants[i].id == config.identifier) {
-						switch(participants[i].confirmation) {
-							case 0:
-								fullTextDiv.style.opacity = ".6";
-								fullTextDiv.style.fontStyle = "italic";
-								title += " (" + _("waiting") + ")";
-								break;
-							case 2:
-								fullTextDiv.style.textDecoration = "line-through";
-								break;
-							case 3:											
-								fullTextDiv.style.fontStyle = "italic";
-								title += " (" + _("tentative") + ")";
-								break;
-						}
-					}
-				}
-			}
-			
-			fullTextDiv.appendChild(document.createTextNode(title));
-			ftDiv.appendChild(fullTextDiv);
-
-            if (divIconParticipant.firstChild) ftDiv.appendChild(divIconParticipant);
-            if (divIconPrivate.firstChild) ftDiv.appendChild(divIconPrivate);
-            if (divIconTag.firstChild) ftDiv.appendChild(divIconTag);
-			
-			if(recurrence_type > 0) {
-				var image=document.createElement("img");
-				image.setAttribute("src",getFullImgSrc("img/calendar/calendar_series.gif"));
-				var seqDiv = newnode('div');
-				seqDiv.className = "showAppointmentSeqWeek";	
-				seqDiv.appendChild(image);
-				ftDiv.appendChild(seqDiv);
-			}
-			
-            addDOMEvent(ftDiv, "contextmenu", function(e) {
-                if (!calendarSelection.get(index))
-                    calendarSelection.click(index, e);
-                stopEvent(e);
-                globalContextMenus.calendar.display(e.clientX, e.clientY,
-                                                    calendarSelection);
-            });
-
-			addDOMEvent(ftDiv, "mousedown", function(e) {
-														setSelectionWeekView(selectedAppointmentWeek);
-														selectAppointmentWeekView(divAppId,2);
-													});
-			addDOMEvent(ftDiv, "dblclick", function(e) {
-														setActivatedWeekView(selectedAppointmentWeek);
-														selectAppointmentWeekView(divAppId,2);
-														});
-			
-		
-			
-			for(i=0;i<days;i++) {
-					var ccweek_template_full_time =ftDiv.cloneNode(true);
-
-					var newId = new Date(start_date).getUTCDay();
-					divId = "weekDayContent" + newId;
-					
-					ccweek_template_full_time.id = ftDiv.id + "-"+i;
-					ccweek_template_full_time.oxcalobj=""+folder_id + "-" + id + "-" + nRecPosition;
-					
-					/////////////////// 					
-			
-			var divs = ccweek_template_full_time.getElementsByTagName("div");
-			var oInplEdit  = new inplaceEdit(divs[1], title, function (sStr,oObj){
-														editAppointment(paramObj,{title:sStr});
-													});
-			addDOMEvent(ccweek_template_full_time, "click", function(e) {
+			addDOMEvent(ccweek_template_app_time, "click", function(e) {					
 				var SelObj = calendarSelection.getID();
-				if(SelObj && SelObj.id == paramObj.id &&
-							SelObj.folder == paramObj.folder &&
-									SelObj.recurrence_position == paramObj.recurrence_position)
-				{
-					if(window.event)
-					{
+				if (SelObj && SelObj.id == paramObj.id &&
+				    SelObj.folder == paramObj.folder_id &&
+					SelObj.recurrence_position == paramObj.recurrence_position) {
+					if (window.event) {
 						e = window.event;
 					}
-					oInplEdit.on();		
-				}
-				else
-				{
-						setSelectionWeekView(selectedAppointmentWeek);
-						selectAppointmentWeekView(divAppId,2);
+					oInplEdit.on();
+				} else {
+					setSelectionWeekView(selectedAppointmentWeek);
+					selectAppointmentWeekView(divAppId, (full_time ? 2 : 1));
 				}
 				stopEvent(e);
-	
 			});	
-			///////////////////
-		
-			registerSource(ccweek_template_full_time,"calendar",function () {
-		 							objMoveCopy.begin("calendar",[new CalendarWorkWeekObject(object[0],object[1],
-								object[2],object[14],object[15],object[3],
-								object[4],object[5],null,object[7],null,object[9],object[10],null,null,null)]);
-									return objMoveCopy; },
-															 null,null,calendardefaultdisabled,defaultdisabledremove);
-		
-                    addDOMEvent(ccweek_template_full_time, "contextmenu", function(e) {
-                        stopEvent(e);
-                        globalContextMenus.calendar.display(e.clientX, e.clientY,
-                                                            calendarSelection);
-                    });
-					addDOMEvent(ccweek_template_full_time, "mousedown", function(e) {
-														setSelectionWeekView(selectedAppointmentWeek);
-														selectAppointmentWeekView(divAppId,2);
-													});
-					addDOMEvent(ccweek_template_full_time, "dblclick", function(e) {
-																setActivatedWeekView(selectedAppointmentWeek, e);
-																selectAppointmentWeekView(divAppId,2);
-																});		
-					
-					var idSuffix = divId.substr(divId.length - 1,1);
-					if(idSuffix == 0) idSuffix = 7;
-					
-					var appendet = false;
-					
-					for (var v = 0; v< Self.appendetFirstChilds.length; v++) {
-						if(divId == Self.appendetFirstChilds[v])
-							appendet = true;
+			
+            addDOMEvent(ccweek_template_app_time, "contextmenu", 
+	            	function(e) {
+		                if (!calendarSelection.get(index)) {
+		                    calendarSelection.click(index, e);
+		                }
+		                stopEvent(e);
+		                globalContextMenus.calendar.display(e.clientX, e.clientY, calendarSelection);
+	            	}
+            );
+			addDOMEvent(ccweek_template_app_time, "mousedown", 
+					function(e) {
+						setSelectionWeekView(selectedAppointmentWeek);
+						selectAppointmentWeekView(divAppId, (full_time ? 2 : 1));
 					}
-					
-					if(appendet) {
-						$("imageList" + idSuffix).style.display = "inline";
-						this.displayedWeekLinks.push($("imageList" + idSuffix));
-					} else {
-						this.appendetFirstChilds.push(divId);
-						$(divId).firstChild.appendChild(ccweek_template_full_time);
-						addTMPId(ccweek_template_full_time);	
+			);
+			addDOMEvent(ccweek_template_app_time, "dblclick", 
+					function(e) {
+						setActivatedWeekView(selectedAppointmentWeek);
+						selectAppointmentWeekView(divAppId, (full_time ? 2 : 1));
 					}
-
-					start_date += oneday;
-				}
-
+			);
+			$(divId).appendChild(ccweek_template_app_time);	
+			addTMPId(ccweek_template_app_time);
+			if (fulltimeStartBefore) {
+				start_date += oneday;
+			}
 		}
 	}
 }
@@ -1021,7 +875,7 @@ function setSelectionWeekView(selectedAppointmentWeek) {
 	selectedAppointment = selectedAppointmentWeek;
 	var arrId = new Array();
 	arrId.push(selectedAppointment);
-	var arrayIndex = selectedAppointmentWeek.folder+"-"+selectedAppointmentWeek.id+"-"+selectedAppointmentWeek.recurrence_position;
+	var arrayIndex = selectedAppointmentWeek.folder + "-" + selectedAppointmentWeek.id + "-" + selectedAppointmentWeek.recurrence_position;
 	calendarSelection.click(allcalendarWeekObjects[arrayIndex].index);
 	triggerEvent("Selected", arrId);
 }
@@ -1030,31 +884,41 @@ function setActivatedWeekView(selectedAppointmentWeek, evt) {
 	selectedAppointment = selectedAppointmentWeek;
 	openAppointmentPopup(evt);
 }
+
 var selectedAppointmentWeekView = '';
 var selectedAppointmentWeekViewModus = 0;
 function selectAppointmentWeekView(divAppId, app) {
-	if($2(divAppId)) {
-		$2(divAppId).className = removeClass($2(divAppId).className,"border-color-selection-elements");
-		$2(divAppId).className = removeClass($2(divAppId).className,"borderDefault");
-		$2(divAppId).className += ' selectedAppMonth border-color-selection-elements';
+	if ($2(divAppId)) {
+		$2(divAppId).className = removeClass($2(divAppId).className, "border-color-selection-elements");
+		$2(divAppId).className = removeClass($2(divAppId).className, "borderDefault");
+		$2(divAppId).className += " selectedAppMonth border-color-selection-elements";
 	}
 	
-	for(var i = 0; i<=7;i++) {
+	for (var i=0; i<=7; i++) {
 		if($2(divAppId + "-" + i)) {
-			$2(divAppId + "-" + i).className = removeClass($2(divAppId + "-" + i).className,"border-color-selection-elements");
-			$2(divAppId + "-" + i).className = removeClass($2(divAppId + "-" + i).className,"borderDefault");			
-			$2(divAppId + "-" + i).className += ' selectedAppMonth border-color-selection-elements';
+			$2(divAppId + "-" + i).className = removeClass($2(divAppId + "-" + i).className, "border-color-selection-elements");
+			$2(divAppId + "-" + i).className = removeClass($2(divAppId + "-" + i).className, "borderDefault");			
+			$2(divAppId + "-" + i).className += " selectedAppMonth border-color-selection-elements";
 		}
 	}
 	
 				
-	if(selectedAppointmentWeekView != '' && $2(selectedAppointmentWeekView) && selectedAppointmentWeekView != divAppId) {
-		$2(selectedAppointmentWeekView).className = (selectedAppointmentWeekViewModus == 1) ? 'appInWeekView background-color-content border-color-design borderDefault' : 'textFullTimeWeek wholeDayBackground border-color-design borderDefault';
+	if (selectedAppointmentWeekView != "" && $2(selectedAppointmentWeekView) && selectedAppointmentWeekView != divAppId) {
+		var cName = "textFullTimeWeek wholeDayBackground border-color-design borderDefault";
+		if (selectedAppointmentWeekViewModus == 1) {
+			cName = "appInWeekView background-color-content border-color-design borderDefault";
+		}		
+		$2(selectedAppointmentWeekView).className = cName;
 	}
-	if(selectedAppointmentWeekView != '' && selectedAppointmentWeekView != divAppId) {
-		for(var i = 0; i<=7;i++) {
-			if($2(selectedAppointmentWeekView + "-" + i)) {
-				$2(selectedAppointmentWeekView + "-" + i).className = (selectedAppointmentWeekViewModus == 1) ? 'appInWeekView background-color-content border-color-design borderDefault' : 'textFullTimeWeek wholeDayBackground border-color-design borderDefault';
+	
+	if (selectedAppointmentWeekView != "" && selectedAppointmentWeekView != divAppId) {
+		for (var i=0; i<=7; i++) {
+			if ($2(selectedAppointmentWeekView + "-" + i)) {
+				var cName = "textFullTimeWeek wholeDayBackground border-color-design borderDefault";
+				if (selectedAppointmentWeekViewModus == 1) {
+					cName = "appInWeekView background-color-content border-color-design borderDefault";
+				}
+				$2(selectedAppointmentWeekView + "-" + i).className = cName;
 			}
 		}
 	}
@@ -1063,7 +927,6 @@ function selectAppointmentWeekView(divAppId, app) {
 		selectedAppointmentWeekView = divAppId;
 		selectedAppointmentWeekViewModus = app;
 	}
-	
 }
 
 var objWeekCalendarTool = new WeekCalendarTool();
