@@ -123,8 +123,6 @@ function MatrixObject(folderid,id,recurrence_id,div_id,startpoint,endpoint) {
 	this.endpoint = endpoint || 0;
 }
 
-
-var currentKW = 0;
 var globalinterval = 0;
 var globalintervalcounts=0;
 var calendarwwfields = new Array(200, 201, 202, 203, 209, 221, 401, 402, 102, 400, 101, 220);
@@ -265,10 +263,9 @@ function getWWEndTime() {
     return tmpendtime;
 }
 
-function clearAppointments()
-{
-	if(cwwdaysfull) {
-		for(var zaehler1=0;zaehler1<cwwdaysfull.length;zaehler1++){ 
+function clearAppointments() {
+	if (cwwdaysfull) {
+		for (var zaehler1=0; zaehler1 < cwwdaysfull.length; zaehler1++){ 
 			removeChildNodes(cwwdaysfull[zaehler1].node); 
 		}
 	}
@@ -289,9 +286,10 @@ function clearAppointments()
 	if(calendarSelection.count != 0) {
 		calendarSelection.reset();
 	}
-//	triggerEvent("Selected",[]); bug 11583
-	for(var i=0;$2("cwwmoreappointments"+i);i++) {
-		if($2("cwwmoreappointments"+i).style.display!="none") { $2("cwwmoreappointments"+i).style.display="none" }
+	for (var i=0;$2("cwwmoreappointments"+i);i++) {
+		if ($2("cwwmoreappointments"+i).style.display!="none") { 
+			$2("cwwmoreappointments"+i).style.display="none" 
+		}
 	}
 }
 function cwwchangeView(days,view){
@@ -330,17 +328,13 @@ function updateWWView(oDateLoc) {
 	updateHeaderWW(oDateLoc);
 	getCalendarObjectsWW(cwwactualday);
 }
-function updateHeaderWW(oDateLoc)
-{
+function updateHeaderWW(oDateLoc) {
 	var oHeader = $("wwViewHeader");
-	var oCalendarTool = new calendarTool(activeMonth,activeYear);
-	var oMonday = new Date(getDayInSameWeek(new Date(Date.UTC(activeYear,activeMonth,activeDay,0,0,0)), weekStart) * 864e5 + ((7-weekStart) * 864e5));
-	
-	currentKW = oCalendarTool.getKW(activeYear,activeMonth,activeDay);
 	if(currentpath2.join("/") == "calendar/calendar/workweek") {
 		$("wwViewHeader").parentNode.parentNode.parentNode.parentNode.parentNode.style.width="200px";
 		oHeader.style.width="160px";
-		oHeader.firstChild.nodeValue = _("CW") + " " + currentKW + " " + oMonday.getUTCFullYear();		
+		oHeader.firstChild.nodeValue = _("CW") + " " + 
+				formatDateTime("w yyyy", new Date(getKeyDayOfWeek(new Date(Date.UTC(activeYear,activeMonth,activeDay))) * 864e5));		
 	} else if (currentpath2.join("/") == "calendar/calendar/day"){
 		$("wwViewHeader").parentNode.parentNode.parentNode.parentNode.parentNode.style.width="200px";
 		oHeader.style.width="160px";
@@ -358,13 +352,13 @@ function updateHeaderWW(oDateLoc)
 			oHeader.firstChild.nodeValue = formatDate(oDateLoc,"dateday");
 		}
 	}
-	oMonday= new Date(cwwactualday);
-	for(indDay=0;indDay<cwwdaysinweek;indDay++) {
-		if(currentpath2.join("/") == "calendar/calendar/workweek" || currentpath2.join("/") == "calendar/calendar/custom") {
-			
-			var sId = 'singleDay'+(indDay)+'stWw';
-			var nCurrHeader  = $2(sId);
-			if(isToday(oMonday))
+	var oMonday= new Date(cwwactualday);
+	for (indDay=0;indDay<cwwdaysinweek;indDay++) {
+		if (currentpath2.join("/") == "calendar/calendar/workweek" || currentpath2.join("/") == "calendar/calendar/custom") {
+			var sId = 'singleDay' + (indDay) + 'stWw';			
+			var nCurrHeader = $2(sId);
+			//if (!nCurrHeader) continue;
+			if (isToday(oMonday))
 				nCurrHeader.className = "font-color-default background-color-PMG-selection-elements";
 			else 
 				nCurrHeader.className = "font-color-default";
@@ -374,13 +368,13 @@ function updateHeaderWW(oDateLoc)
 			oMonday.setDate(oMonday.getDate()+1);
 
 		} else {
-			var sId = 'singleDay'+(indDay)+'stWw';
+			var sId = 'singleDay' + (indDay) + 'stWw';
 			var nCurrHeader  = $2(sId);
+			//if (!nCurrHeader) continue;
 			removeChildNodes(nCurrHeader);
 			var document1=document.createTextNode(".");
 			nCurrHeader.className += " font-color-selected";
 			nCurrHeader.appendChild(document1); 
-			//if( nCurrHeader.style.display!="none") { nCurrHeader.style.display="none"; }
 		}
 	}
 }
@@ -422,6 +416,7 @@ function cwwwupdateView()
 		function(){ 
 			redrawAppointment();
 		 });
+	calendar_HeaderUpdate(cwwstorage.ids.length);	
 }
 var cww_myboolean=true;
 
@@ -432,16 +427,18 @@ function initCalendarObjectsWW(storage) {
 	}
 	cwwstorage=storage;
 	calendarSelection.setStorage(cwwstorage);
-	if(!lastUpdateOfCalendarTimestamp || lastUpdateOfCalendarTimestamp<cwwstorage.timestamp) {
+	if (!lastUpdateOfCalendarTimestamp || lastUpdateOfCalendarTimestamp<cwwstorage.timestamp) {
 		lastUpdateOfCalendarTimestamp=cwwstorage.timestamp;
 	}
-	
 	cwwstorage.newIterate(cwwstorage.ids, emptyFunction, showCalendarObject,
 		function() {
 			redrawAppointment();
-		 });
-	storage.events.register("Changed", cwwwupdateView);
+		}
+	);
+	storage.events.register("Changed", cwwwupdateView);	
+	calendar_HeaderUpdate(cwwstorage.ids.length);
 }
+
 function showCalendarObject(index,object) {
 	// consolidate users and participants (field 220 and 221)
 	for (var i in object[16]) {
@@ -591,32 +588,34 @@ function cwwdrawAppointment(calendarobject) {
 	// Startdate Correction Complete Appointment
 	// Setze Startzeit des Termins um , falls er vor meiner Anzeige beginnt
 	var sdt=calendarobject["start_date"].getTime();
-	if(sdt<cwwactualday.getTime()) {
-		//calendarobject["start_date"]=new Date(cwwactualday.getTime());
+	if (sdt<cwwactualday.getTime()) {
 		sdt=new Date(cwwactualday.getTime()).getTime();
 	}
 	// Setze Endzeit des Termins um , falls er nach meiner Anzeige beginnt
 	var edt=calendarobject["end_date"].getTime();
-	if(edt>cwwactualday.getTime()+(cwwdaysinweek*(oneday))) {
-		//calendarobject["end_date"]=new Date(cwwactualday.getTime()+(5*oneday));
+	if (edt>cwwactualday.getTime()+(cwwdaysinweek*(oneday))) {
 		edt=new Date(cwwactualday.getTime()+(cwwdaysinweek*oneday)).getTime();
 	}
 	var sdttmp=sdt;
 	// IST es ein Ganztagstermin
-	if(calendarobject.full_time){		
+	if (calendarobject.full_time){		
 		// Kann Termin angezeigt werden???
 		showappointment=true;
-		while(sdttmp<edt) {
-			if(!document.getElementById(calendarobject.folder_id+"-"+calendarobject.id+"-"+calendarobject.recurrence_position+"-"+zaehler3))	{
+		while (sdttmp<edt) {
+			if (!document.getElementById(calendarobject.folder_id+"-"+calendarobject.id+"-"+calendarobject.recurrence_position+"-"+zaehler3))	{
 				// Hol mir den Tag der Woche
 				var sdd=(new Date(sdttmp).getUTCDay()-new Date(cwwactualday.getUTCDay()) +7) % 7;
+				
+				/*
 				// Hat dieser Tag schon einen Ganztagstermin, wenn ja Listenbild einblenden
-				if(cwwdaysfull[sdd].node.hasChildNodes()) {
+				if (cwwdaysfull[sdd].node.hasChildNodes()) {
 					showappointment=false;
-					if($2("cwwmoreappointments"+sdd).style.display!="") $2("cwwmoreappointments"+sdd).style.display="";
-				}
-				else {
-					//Zeichne Ganztagstermin
+					if ($2("cwwmoreappointments"+sdd).style.display != "") {
+						$2("cwwmoreappointments"+sdd).style.display="";
+					}
+				} else {
+				*/
+					//Zeichne Ganztagstermin					
 					showappointment=true;
 					var appointmentcontainer = cwwdaysfull[sdd].node;
 					var myappointment=$("cww_appointment_template_full_time").cloneNode(true);
@@ -701,9 +700,11 @@ function cwwdrawAppointment(calendarobject) {
 							break;
 					}
 					
-                    title.firstChild.data = calendarobject.location ?
-                        calendarobject.title + " - " + calendarobject.location :
-                        calendarobject.title || "";
+					// title & location
+					var appTitle = [];
+					if (calendarobject.title) appTitle.push(calendarobject.title);
+					if (calendarobject.location) appTitle.push(calendarobject.location);
+					title.firstChild.data = appTitle.join(" - ") || "";
 					
 					// setting confirmation styles
 					if (calendarobject.participants.length) {
@@ -730,20 +731,17 @@ function cwwdrawAppointment(calendarobject) {
 					
 					appointmentcontainer.appendChild(myappointment);
 				}
-			}
+			//}
 			//Zaehle Temp Startzaehler um 24 Stunden hoch
 			sdttmp = sdttmp+oneday;
-		}	
-	}
-	else
-	{
-		if(sdttmp==edt && edt != new Date(cwwactualday.getTime()+(cwwdaysinweek*oneday)).getTime() ) {
+		}
+	} else {
+		if (sdttmp==edt && edt != new Date(cwwactualday.getTime()+(cwwdaysinweek*oneday)).getTime() ) {
 			edt++;
 		}
 		//Hier alle nicht Ganztagstermine	
-		while(sdttmp<edt)
-		{
-			if(!document.getElementById(calendarobject.folder_id+"-"+calendarobject.id+"-"+calendarobject.recurrence_position+"-"+zaehler3)) {
+		while (sdttmp<edt) {
+			if (!document.getElementById(calendarobject.folder_id+"-"+calendarobject.id+"-"+calendarobject.recurrence_position+"-"+zaehler3)) {
 				showappointment=true;
 				var sdd        = (new Date(sdttmp).getUTCDay()-new Date(cwwactualday.getUTCDay()) +7) % 7;
 				var longstart  = (sdttmp % oneday);
@@ -779,8 +777,8 @@ function cwwdrawAppointment(calendarobject) {
 						}
 					}
 				}
-				if(!showappointment){
-					$2("cwwmoreappointments"+sdd).style.display="";
+				if (!showappointment){
+					$2("cwwmoreappointments"+sdd).style.display = "";
 				} else {
 					var myappointment=$("cww_appointment_template").cloneNode(true);
 					myappointment.id=+calendarobject.folder_id+"-"+calendarobject.id+"-"+calendarobject.recurrence_position+"-"+zaehler3;
@@ -901,10 +899,12 @@ function cwwdrawAppointment(calendarobject) {
 								tds[0].className="appointmentFREE";
 								break;
 						}
-						/** Title & Time **/
-                        title.firstChild.data = calendarobject.location ?
-                            calendarobject.title + " - " + calendarobject.location :
-                            calendarobject.title || "";
+						
+						// Title & location
+						var appTitle = [];
+						if (calendarobject.title) appTitle.push(calendarobject.title);
+						if (calendarobject.location) appTitle.push(calendarobject.location);
+						title.firstChild.data = appTitle.join(" - ") || "";
 						
 						// setting confirmation styles
 						if (calendarobject.participants.length) {
@@ -1053,7 +1053,9 @@ function redrawAppointment(elementlength,position,elementid) {
 		d.style.width=(Math.round(100/allobjects[last].highest)-2)+"%";
 		d.style.left=(Math.round(100/allobjects[last].highest)*allobjects[last].pposition)+"%";
 	}
+	cwwresizeTopHeader();	
 }						
+
 /**** Templates Creation *******************************************************************************************/
 /**
 * Create Matrix
@@ -1079,9 +1081,9 @@ function createTemplatesWW(interval,startworktime,endworktime) {
 		}
 	}
 	cwwdaysfull=new Array();
-	for(var zaehler=0;zaehler<cwwdaysinweek;zaehler++) {
+	for(var zaehler=0; zaehler<cwwdaysinweek; zaehler++) {
 		cwwdaysfull[zaehler]=new Object();
-		cwwdaysfull[zaehler].node=$2("cwwheaderfull:"+zaehler);
+		cwwdaysfull[zaehler].node = $2("cwwheaderfull:"+zaehler);
 	}
 }
 function createCalendarContentFullTime() {
@@ -1090,7 +1092,8 @@ function createCalendarContentFullTime() {
 			cwwchangeView(i,list);
 		}
 	}
-	for(var i=0;$2("cwwmoreappointments"+i);i++) {
+	
+	for (var i=0; $2("cwwmoreappointments"+i); i++) {
 		removeTMPId("singleDay"+(i)+"stWw");
 		removeTMPId("cwwmoreappointments"+(i));
 		removeTMPId("cwwwholeday_dnd:"+i);
@@ -1098,64 +1101,58 @@ function createCalendarContentFullTime() {
 		removeTMPId("cww_wholeday:"+i);	
 	}
 	
-	var tbody=newnode("tbody",null,null,[]);
-	var firsttr=newnode("tr",null,null,[]);
-	var secondtr=newnode("tr",null,null,[]);
-	for(var i=0;i<cwwdaysinweek;i++) {
+	removeChildNodes($("cwwheaderdates"));
+	var tbody=newnode("tbody", null,null,[]);
+	//var firsttr=newnode("tr", null, null,[]);
+	var secondtr=newnode("tr", { height: "100%" }, { height: "100%" }, []);
+	for(var i=0; i<cwwdaysinweek; i++) {
 		var onetd=
-		newnode("td",{ width: Math.floor(100/cwwdaysinweek)+"%", borderRight: "1px solid", paddingLeft: "5px", overflow:"hidden" },{className: "border-color-design appointmentViewHeadBG"},[
-			newnode("table",{ width: "100%"},{ cellPadding: 0 , cellSpacing : 0 , border : 0 },[
-				newnode("tbody",null,null,[
-					newnode("tr",null,null,[
-						newnode("td",{ width: "100%"},null,[
-							newnode("div",{ overflow: "hidden" },null,[
-								newnode("div",{ whiteSpace :"nowrap" ,cursor: "pointer", zIndex:"-1" },{id: "singleDay"+(i)+"stWw"},[
-									newnode("img",{},{src: getFullImgSrc("img/dummy.gif")},[])
+			newnode("td",{ width: Math.floor(100/cwwdaysinweek)+"%", borderRight: "1px solid", paddingLeft: "5px", overflow:"hidden" },{className: "border-color-design appointmentViewHeadBG"},[
+				newnode("table",{ width: "100%"},{ cellPadding: 0 , cellSpacing : 0 , border : 0 },[
+					newnode("tbody",null,null,[
+						newnode("tr",null,null,[
+							newnode("td",{ width: "100%"},null,[
+								newnode("div",{ overflow: "hidden" },null,[
+									newnode("div",{ whiteSpace :"nowrap" ,cursor: "pointer", zIndex:"-1" },{id: "singleDay"+(i)+"stWw"},[
+										newnode("img",{},{src: getFullImgSrc("img/dummy.gif")},[])
+									])
+								])
+							]),
+							newnode("td",null,{ id : "cwwmoreappointments"+(i), title : _("Click here for further appointments") },[
+								newnode("div", { paddingRight : "7px", height: "16px" , cursor : "pointer" }, null,[
+									newnode("img",null,{ src : getFullImgSrc("img/menu/weiterzuListe.gif") },[])
 								])
-							])
-						]),
-						newnode("td",null,{ id : "cwwmoreappointments"+(i), title : _("Click here for further appointments") },[
-							newnode("div", { paddingRight : "7px", height: "16px" , cursor : "pointer" }, null,[
-								newnode("img",null,{ src : getFullImgSrc("img/menu/weiterzuListe.gif") },[])
 							])
 						])
 					])
 				])
-			])
-		]);
+			]);
 		addTMPId(onetd.getElementsByTagName("div")[1]);
 		addTMPId(onetd.getElementsByTagName("td")[1]);
 		addDOMEvent(onetd.getElementsByTagName("td")[0],"click",getfunction("day",i));
 		addDOMEvent(onetd.getElementsByTagName("td")[1],"click",getfunction("list",i));
-		firsttr.appendChild(onetd);
+		//firsttr.appendChild(onetd.);
+		$("cwwheaderdates").appendChild(onetd);
 		
-		var secondtd=newnode("td",{ width: Math.floor(100/cwwdaysinweek)+"%", borderRight: "1px solid" },{className: "border-color-design",vAlign : "top", id: "cwwwholeday_dnd:"+i},[
-			newnode("div",{ height:"0px", lineHeight:"0px", width:"100%", position:"relative"},{ id: "cwwheaderfull:"+i },[]),
-			newnode("table",{ width:"100%", height:"100%" },{ cellPadding: 0, cellSpacing : 0, border: 0, id: "cww_wholeday:"+i },[
-				newnode("tbody",null,null,[
-					newnode("tr",null,null,[
-						newnode("td",{ width: "5px", height : "1.6em" },null,[
-						]),
-						newnode("td",null,{ className : "wholeDayBackground" },[
-							newnode("img",null,{ src : getFullImgSrc("img/dummy.gif") },[])
-						])
-					])
-				])
-			])
-		]);
+		var secondtd = newnode("td",{ width: Math.floor(100/cwwdaysinweek) + "%" , borderRight: "1px solid" }, 
+				{ className: "border-color-design", vAlign: "top", id: "cwwwholeday_dnd:" + i },[
+			newnode("div",{ width:"100%", position:"relative"},{ id: "cwwheaderfull:"+i },[ document.createTextNode(" ") ]) ]);
 		function getfunction2(node) {
 			return function() {
 				cww_createNewWholeAppointment(node);
 			}
 		}
+		
 		addTMPId(secondtd);
 		addTMPId(secondtd.getElementsByTagName("div")[0]);
-		addTMPId(secondtd.getElementsByTagName("table")[0]);
-		addDOMEvent(secondtd.getElementsByTagName("div")[0],"dblclick",getfunction2(secondtd.getElementsByTagName("div")[0]));	
-		addDOMEvent(secondtd.getElementsByTagName("table")[0],"dblclick",getfunction2(secondtd.getElementsByTagName("table")[0]));	
+		//addTMPId(secondtd.getElementsByTagName("table")[0]);
+		addDOMEvent(secondtd, "dblclick", getfunction2(secondtd.getElementsByTagName("div")[0]));	
+		//addDOMEvent(secondtd.getElementsByTagName("table")[0],"dblclick",getfunction2(secondtd.getElementsByTagName("table")[0]));	
 		secondtr.appendChild(secondtd);
 	}
-	tbody.appendChild(firsttr);
+	if (IE < 8) $("cwwheaderscroll").style.display="none";
+	else $("cwwheaderscroll").style.display="";
+	
 	delete calendarhovers["daywwcustom"];
 	calendarhovers["daywwcustom"]=new Hover(secondtr,OXAppointmentHover.getContent().node);
 	calendarhovers["daywwcustom"].setSize(OXAppointmentHover.contentobject.node);
@@ -1165,7 +1162,7 @@ function createCalendarContentFullTime() {
                 if (node.oxcalobj) return node.parentNode ? node : null;
                 node = node.parentNode;
             }
-        } catch (e) { /*see default implementation*/ }
+        } catch (e) { }
     };
 	calendarhovers["daywwcustom"].onShow = function (node) {
 		OXAppointmentHover.actualHover=this;
@@ -1197,6 +1194,7 @@ function createCalendarContentFullTime() {
 		return function(event,dragType,data,mouseposition,targetNode) { cww_saveAppointment(data.currentObjects[0],event,"calendar",true,i);  }
 	}
 }
+
 function cww_createNewAppointment(clickedobject) {
 	var day=clickedobject.id.split(":")[1];
 	var time=clickedobject.parentNode.id.split("-")[2];
@@ -1288,7 +1286,6 @@ function createCalendarContentWW(interval,startworktime,endworktime){
 				appointmentinsert.style.lineHeight="0px";
 				appointmentinsert.style.fontSize="0pt";
 				appointmentinsert.style.position="relative";
-//				appointmentinsert.style.overflow="hidden";
 				shorttmp.insertBefore(appointmentinsert,table1[0]);
 			}
 		}
@@ -1319,11 +1316,30 @@ function createCalendarContentWW(interval,startworktime,endworktime){
 	cwwwresizeHeader();
     wwline = (temp1.offsetTop + temp1.offsetHeight) / numOfLines;
 }
+
 function cwwwresizeHeader() {
-	var e1=$("cwwcontentresize");
-	var mywidth=e1.offsetWidth;
-	$("cwwheaderresize").style.width=mywidth+"px";
+	$("cwwheaderresize").style.width = cww_maxShownFD <= 5 ? $("cwwcontentresize").offsetWidth + "px" : $("cwwtimecontentall").offsetWidth + "px";
+	$("cwwheaderresize").style.overflowY = cww_maxShownFD <= 5 ? "hidden" : "scroll";
 }
+
+var cww_maxShownFD = 0;
+function cwwresizeTopHeader() {
+	var tmpMax = 0;
+	// iterate through curr whole day apps and check if something changed
+	// from previous view to current view
+	for (var i=0; i<cwwdaysfull.length; i++) {
+		if (cwwdaysfull[i].node.childNodes.length > tmpMax) {
+			tmpMax = cwwdaysfull[i].node.childNodes.length;			
+		}
+	}
+	// has something changed? if yes, resize the header
+	if (tmpMax != cww_maxShownFD) {
+		var size = tmpMax <= 1 ? 62 : ((tmpMax > 5 ? 5 : tmpMax) * 20) + 40;		
+		resizeSplit("cwwheader_top", size + "px");
+		cww_maxShownFD = tmpMax;
+	}	
+}
+
 /* Create TimeLine */
 function createNewTimeLine(interval) {
 	$("cwwcontentresize").className = "interval" + (interval/60000);
@@ -1427,8 +1443,8 @@ function getDragandDropPoint(e) {
 	var coreelement=$("cwwtimecontent");
 	var scrollposition= $("cwwtimecontentall").scrollTop;
 	var posx=getAbsolutePositionLeft(coreelement);
-	var posy=getAbsolutePositionTop(coreelement)-scrollposition;
-	var poscontent=e.clientY-getAbsolutePositionTop(coreelement);
+	var posy=getAbsolutePositionTop(coreelement);
+	var poscontent=e.clientY-getAbsolutePositionTop(coreelement)-scrollposition;
 	var posheight= $("cwwtimecontentall").offsetHeight;
 	var fieldposx=e.clientX-posx;
 	var fieldposy=e.clientY-posy;
