@@ -365,10 +365,12 @@ function configuration_saveObject(force,hidemessage,myok,myerror,optParam) {
 			if(!hidemessage) {
 				triggerEvent("OX_New_Info",4,_("Your settings have been saved"));
 			}
-			if(activemodule=="configuration") {
-				triggerEvent("OX_Configuration_Changed",currentpath2.join("/"));
-			} else {
-				triggerEvent("OX_Configuration_Changed","");
+			if (!force) {
+				if(activemodule=="configuration") {
+					triggerEvent("OX_Configuration_Changed",currentpath2.join("/"));
+				} else {
+					triggerEvent("OX_Configuration_Changed","");
+				}
 			}
 		}
 	}
@@ -462,7 +464,15 @@ function configuration_saveObject(force,hidemessage,myok,myerror,optParam) {
 		configuration_changed_fields["modules"] = false;
 	}
     if (temporary.folderTabs.viewModified()) {
-        temporary.folderTabs.saveView();
+        temporary.folderTabs.saveView(function() {
+            oMainFolderTree.cache.updateFolders(
+                [temporary.folderTabs.folder.id],
+                function() {
+                    oMainFolderTree.load_view(
+                        oMainFolderTree.cache.folders.root,
+                        oMainFolderTree.tree, true, false);
+                }); 
+        });
         showmessage = false;
     }
 	if(openrequests==0 && showmessage) {
@@ -498,50 +508,42 @@ function displaySignatureConfig(val) {
 }
 
 function LogoutPopup() { }
-LogoutPopup.openWindow = function () {
-	showNode("disable_background_window");
-	$("disable_background_window").style.display="block";
-	showNode("logout_window");
-	centerPopupWindow($("logout_window"));
-	$("logout_window").style.display="block";
-}
-LogoutPopup.closeWindow = function () {
-	hideNode("logout_window");
-	$("logout_window").style.display="none";	
-	hideNode("disable_background_window");
-	$("disable_background_window").style.display="none";
-}
-LogoutPopup.commityes = function () {
-	$("logout_window").style.display="none";	
+LogoutPopup.openWindow = emptyFunction;
+LogoutPopup.closeWindow = emptyFunction;
+LogoutPopup.commityes = function () {	
 	triggerEvent("OX_Save_Configuration",true,true,function() {
 		//NO ERROR
 		window.onbeforeunload = null;
 		new JSON().get(AjaxRoot + "/login?action=logout&session=" + session, null, function() {
 			window.setTimeout( function() { window.location.replace(logout_location.format()); },0);
-			hideNode("disable_background_window");
-			$("disable_background_window").style.display="none";
 		},function() { 
 			window.setTimeout( function() { window.location.replace(logout_location.format()); },0);			
 			return true;
 		});
-	},function(data) {
-		newConfirm(_("Server Error:"),_("Your configuration settings could not be saved. All your changes will be lost. Do you really want to continue?") + "\n\n" + formatError(data), AlertPopup.YESNO,null,null,
-		function() {
-			window.onbeforeunload = null;
-			new JSON().get(AjaxRoot + "/login?action=logout&session=" + session, null, 
-				function() { 
-					window.setTimeout( function() { window.location.replace(logout_location.format()); },0);
-					$("disable_background_window").style.display="none"; 
+	}, function(data) {
+		window.onbeforeunload = null;
+		if (typeof data != "object" || data.code == "SES-0203") {
+			window.setTimeout( function() { 
+				window.location.replace(logout_location.format()); 
+			},0);
+		} else {
+			newConfirm(_("Server Error:"),_("Your configuration settings could not be saved. All your changes will be lost. Do you really want to continue?") + "\n\n" + formatError(data), AlertPopup.YESNO,null,null,
+				function() {
+					
+					new JSON().get(AjaxRoot + "/login?action=logout&session=" + session, null, 
+						function() { 
+							window.setTimeout( function() { window.location.replace(logout_location.format()); },0);
+						},
+						function() { 
+							window.setTimeout( function() {
+								window.location.replace(logout_location.format()); 
+							},0);			
+							return true;
+						});
 				},
-				function() { 
-					window.setTimeout( function() {
-						window.location.replace(logout_location.format()); 
-					},0);			
-					return true;
-				});
-		},function () { 
-			LogoutPopup.closeWindow();  }
-		);
+				emptyFunction
+			);
+		}
 		return true;
 	});
 }
@@ -549,8 +551,6 @@ LogoutPopup.commitno = function () {
 	window.onbeforeunload = null;
 	(new JSON()).get(AjaxRoot + "/login?action=logout&session=" + session, null, function() {
 		window.setTimeout( function() { window.location.replace(logout_location.format()); },0);
-		hideNode("disable_background_window");
-		$("disable_background_window").style.display="none";
 	},function() { 
 		window.setTimeout( function() { window.location.replace(logout_location.format()); },0);
 		return true;
