@@ -67,8 +67,9 @@ function cm_saveConfiguration() {
 	}
 	if (configuration_changed_fields["modules"]) {
 		configSetKey("modules.mail.allowhtmlimages", getBoolofInt(getValueofRadioBox("cm_preloadimages")));
-		if (configContainsKey("modules.mail.contactCollectEnabled") && configContainsKey("modules.mail.contactCollectFolder")) {
-			configSetKey("modules.mail.contactCollectEnabled", getBoolofInt(getValueofRadioBox("cm_emailCollection")));
+		if (configContainsKey("modules.mail.contactCollectEnabled") && configContainsKey("modules.mail.contactCollectFolder")) {			
+			configSetKey("modules.mail.contactCollectOnMailTransport", getBoolofInt(getValueofRadioBox("cm_contactCollectOnMailTransport")));
+			configSetKey("modules.mail.contactCollectOnMailAccess", getBoolofInt(getValueofRadioBox("cm_contactCollectOnMailAccess")));
 		}
 		configSetKey("modules.mail.replyallcc", getBoolofInt(getValueofRadioBox("cm_replyallcc")));
 	}
@@ -184,19 +185,23 @@ function cm_enter() {
 		setIntofRadioBox("cm_preloadimages",configGetKey("modules.mail.allowhtmlimages"));
 		configuration_changed_fields["modules"]=false;
 	}
+	var emailCollectEnabled = false;
 	if (configGetKey("modules.mail.contactCollectEnabled") && 
 			configGetKey("modules.mail.contactCollectEnabled") == true &&
 			configContainsKey("modules.mail.contactCollectFolder") &&
 			configGetKey("modules.mail.contactCollectFolder") != 0) {
-        setIntofRadioBox("cm_emailCollection", configGetKey("modules.mail.contactCollectEnabled"));
+        setIntofRadioBox("cm_contactCollectOnMailTransport", configGetKey("modules.mail.contactCollectOnMailTransport"));
+        setIntofRadioBox("cm_contactCollectOnMailAccess", configGetKey("modules.mail.contactCollectOnMailAccess"));
         configuration_changed_fields["modules"]=false;        
         oMainFolderTree.cache.get_folder(configGetKey("modules.mail.contactCollectFolder"), function(folder) { 
-            $("cm_emailCollection_text").firstChild.nodeValue = format(_("Automatically save E-Mail addresses to folder %s?"), [folder.oxfolder.data.title]);
+            $("cm_emailCollection_text").firstChild.nodeValue = format(_("Automatically collect contacts in the folder \"%s\""), [folder.oxfolder.data.title]);
         });
-        $("cm_emailCollectionContent").style.display="";
-    } else {
-    	$("cm_emailCollectionContent").style.display="none";
+        emailCollectEnabled=true;        
     }
+	$("cm_emailCollectionContent0").style.display=emailCollectEnabled ? "" : "none";
+	$("cm_emailCollectionContent1").style.display=emailCollectEnabled ? "" : "none";
+	$("cm_emailCollectionContent2").style.display=emailCollectEnabled ? "" : "none";
+
     if(configContainsKey("modules.mail.replyallcc")) {
         setIntofRadioBox("cm_replyallcc",configGetKey("modules.mail.replyallcc"));
         configuration_changed_fields["gui"]=false;
