@@ -17,8 +17,7 @@
 // needed later for folder subscribe and updates
 var mail_accounts;
 
-register("OX_Configuration_Loaded", function () {
-	
+register("OX_Configuration_Loaded", function () {	
 	mail_accounts = new Storage(0, [], 0, 0, 0, 0, function(data) { return data.id; });
 		
 	function loadAccounts(cb) {
@@ -34,24 +33,26 @@ register("OX_Configuration_Loaded", function () {
 	                if (cb) cb();
 	            },
 	            // error handler
-	            function() {
-	            	if (cb) cb();
+	            function(error) {
+	            	if (cb) cb(error);
 	            	return false; // standard error handler will be called 
 	            });
 	}
 	// load 
 	
-	loadAccounts(null);
-	
+	if (configGetKey("modules.mail.module") != null) {
+		loadAccounts(null);
+	}
+
 	// if not enabled we won't continue
-	if (!configGetKey("modules.mailaccount.module")) return;
+	if (configGetKey("modules.mail.module") == null || !configGetKey("modules.mailaccount.module")) return;
 		
 	var node = new ox.Configuration.LeafNode("configuration/mail/accounts", 
 			newnode("span",0,0,[ 
 			                    newnode("span",0,0,[document.createTextNode(_("Accounts"))]), 
 			                    newnode("span",{background:"orange",marginLeft:"5px",padding:"2px",
 			                    	MozBorderRadius:"2px",WebkitBorderRadius:"2px",color:"white"},0,
-			                    		[ document.createTextNode(_("Beta"))]) 
+			                    		[ addTranslated("New")]) 
 			                  ]));
 	var split = new ox.Configuration.VSplit(node, _("E-Mail Accounts"), 0.28, true);
 	
@@ -68,12 +69,12 @@ register("OX_Configuration_Loaded", function () {
     	mObj.name = data[5];
     	mObj.primary_address = data[6];
     	mObj.spam_handler = data[7];
-    	mObj.trash = data[8];
-    	mObj.sent = data[9];
-    	mObj.drafts = data[10];
-    	mObj.spam = data[11];
-    	mObj.confirmed_spam = data[12];
-    	mObj.confirmed_ham = data[13];
+    	//mObj.trash = data[8];
+    	//mObj.sent = data[9];
+    	//mObj.drafts = data[10];
+    	//mObj.spam = data[11];
+    	//mObj.confirmed_spam = data[12];
+    	//mObj.confirmed_ham = data[13];
     	mObj.mail_server = data[14];
     	mObj.mail_port = data[15];
     	mObj.mail_protocol = data[16];
@@ -85,16 +86,53 @@ register("OX_Configuration_Loaded", function () {
     	mObj.transport_login = data[22];
     	mObj.transport_passord = data[23];
     	mObj.unified_inbox_enabled = data[24];
+    	mObj.trash_fullname = data[25];
+    	mObj.sent_fullname = data[26];
+    	mObj.drafts_fullname = data[27];
+    	mObj.spam_fullname = data[28];
     	mObj.pop3_refresh_rate = data[31];
     	mObj.pop3_expunge_on_quit = !data[32];
     	mObj.pop3_delete_write_through = data[33];
+    	mObj.personal = data[36];
     	return mObj;
-    }	
+    }
+    
+    // Helper
+    function addCheckBox(accountId) {
+        var checkbox = newnode("input", 0, { type: "checkbox" });
+        addDOMEvent(checkbox, "click", (function() {
+            return function() {
+                if (typeof(accountId) != "undefined") {
+                    // talk with server
+                    var data = { "id": accountId, "unified_inbox_enabled": !!checkbox.checked };
+                    ox.JSON.put(AjaxRoot + "/account?action=update&session=" +
+                        session, data, function(reply) {
+                            // notify
+                            // ox.Configuration.info(_("Your settings have been saved."));
+                            // updating folder tree
+                            oMainFolderTree.cache.update(null, true, null);
+                            // update right checkbox (only)
+                            try {
+                                d = split.get();
+                                d.unified_inbox_enabled = reply.data.unified_inbox_enabled;
+                                split.set(d);
+                                // stop asking if nothing was changes
+                                split.original.unified_inbox_enabled = d.unified_inbox_enabled;
+                                // thx to preuss' "brilliant" idea
+                                mail_accounts.data.data[accountId].unified_inbox_enabled = d.unified_inbox_enabled;
+                            } catch(e) { }
+                    });
+                }
+            }
+        })());
+        return checkbox;
+    }
 
 	/** Init function **/
 	split.init = function() {
 	    var selection = new Selection();
 	    var grid = new LiveGrid([
+	        // Acount name
 	        { 
 	            text: _("Account name"),
 	            clear: LiveGrid.makeClear(""),
@@ -102,7 +140,19 @@ register("OX_Configuration_Loaded", function () {
 	                if (div.firstChild)
 	                    div.firstChild.data = data.name || "";
 	                else
-	                    div.appendChild(document.createTextNode(data.name || ""));                
+	                    div.appendChild(document.createTextNode(data.name || ""));
+	            }
+	        },
+	        // Unified INBOX flag
+	        {
+	            text: _("Use Unified INBOX")/* i18n */,
+	            width: "12em",
+	            clear: emptyFunction,
+	            set: function(div, data) {
+	                if (!div.firstChild) {
+	                    div.appendChild(addCheckBox(data.id));
+	                }
+	                div.firstChild.checked = data.unified_inbox_enabled || false;
 	            }
 	        }
 	    ], selection);
@@ -110,10 +160,10 @@ register("OX_Configuration_Loaded", function () {
 	    
 	    split.list = grid;
 	    
-	    split.enableList = function() {	    	
+	    split.enableList = function() {
 	    	loadAccounts(
 	    			function() {
-		            	grid.enable(mail_accounts);	    				
+		            	grid.enable(mail_accounts);
 	    			}
 	    	);
 	    };
@@ -135,8 +185,14 @@ register("OX_Configuration_Loaded", function () {
 	    	nData.mail_port = parseInt(nData.mail_port);
 	    	nData.transport_port = parseInt(nData.transport_port);
 	    	nData.transport_protocol = "smtp";
+	    	if (nData["mail_protocol"] == "pop3") {
+	    		nData.pop3_storage = "mailaccount";
+	    	}
 	    	
 	    	if ("id" in data) {
+	    		for (var i in nData) {
+	        		if (nData[i] == undefined || nData[i] == "undefined") nData[i]=null; //delete(nData[i]);
+	        	}
 	            ox.JSON.put(AjaxRoot + "/account?action=update&session=" +
 	                        session, nData, function(reply) {
 	            				mail_accounts.localUpdate([data.id], function(old) {
@@ -150,26 +206,31 @@ register("OX_Configuration_Loaded", function () {
 	            	            cont(reply.data);
 	                        });
 	        } else {
-	        	nData.trash = "trash";
-	        	nData.sent = "sent";
-	        	nData.drafts = "drafts";
-	        	nData.spam = "spam";
-	        	nData.confirmed_spam = "confirmed-spam";
-	        	nData.confirmed_ham = "confirmed-ham";
 	        	nData.spam_handler = "NoSpamHandler";
 	            ox.JSON.put(AjaxRoot + "/account?action=new&session=" +
 	                        session, nData, handleNew);
 	        }
 	    	
 	    	function handleNew(reply) {
+	    		if (!reply || !reply.data) {
+	    			triggerEvent("OX_New_Error", 4, format(_("Syntax error in server reply:\n%s"), "no error provided"));
+	    			return;
+	    		}	    		
 	    		var data = reply.data;
 	    		data.pop3_expunge_on_quit=!data.pop3_expunge_on_quit;
 	    		mail_accounts.append([data]);
-	            ox.Configuration.info(_("Your settings have been saved."));
-	            split.onNew();
+	            ox.Configuration.info(_("Your settings have been saved."));	            
+	            //globalalert.SHOWAGAIN=true;	    		
+	            newAlert(_("Info"), _("You have set up an external E-Mail account. The sole responsibility for the availability of the external E-Mail account lies with the service provider."),
+	            		function() {
+		            		globalalert.SHOWAGAIN=null;
+		            		cont(data);
+		            		split.onNew();
+	            		}
+	            );
+
 	            // updating folder tree
 	            oMainFolderTree.cache.update(null, true, null);
-	            cont(data);
 	        }
 	    }
 	    
@@ -185,7 +246,7 @@ register("OX_Configuration_Loaded", function () {
 	    
 	    split.onNew = function() {
 	    	split.right.scrollTop = 0;
-	    	this.addNew({ name: _("New account") });	        
+	    	this.addNew({ name: _("New account") });
 	    };
 	    
 	    
@@ -236,22 +297,46 @@ register("OX_Configuration_Loaded", function () {
 	    /*** new/edit fields on the right side ***/
 	    
 	    /*** blank line ***/
-	    var lb = new ox.UI.Widget();
-	    lb.addContent = function() {
-	        this.node = this.parent.addRow(newnode("br", null, false));
-	    };
-	    
-	    /*** ACCOUNT SETTINGS ***/
+	    var lb = function() { ox.UI.Widget.call(this); };
+	    lb.prototype = extend(ox.UI.Widget, {
+	        addContent: function() {
+	           this.node = this.parent.addRow(newnode("br", null, false));
+            }
+	    });
+        
+        function disabler(widget) {
+            return {
+                get: ox.Configuration.Group.NoField.get,
+                set: function(data) {
+                    widget.setEnabled(data.id !== 0);
+                    return data;
+                }
+            };
+        }
+        
+        /*** ACCOUNT SETTINGS ***/
 	    var account = new ox.Configuration.Group(_("Account Settings"));
-	    split.addWidget(account, ox.Configuration.Group.NoField);
-	    account.addWidget(new ox.UI.Input(_("Account Name")), "name");    
-	    account.addWidget(new ox.UI.Input(_("E-Mail Address")), "primary_address");
-	    account.addWidget(new ox.UI.CheckBox(_("Use Unified INBOX for this account")), "unified_inbox_enabled");
-	    account.addWidget(lb);
+	    var name = new ox.UI.Input(_("Account Name"));
+	    account.addWidget(name, "name");
+	    var primary_address = new ox.UI.Input(_("E-Mail Address"));
+	    account.addWidget(primary_address, "primary_address");
+	    var personal = new ox.UI.Input(_("Your name"));
+	    account.addWidget(personal, "personal");
+	    var unifiedCheckbox = new ox.UI.CheckBox(_("Use Unified INBOX for this account"));
+	    account.addWidget(unifiedCheckbox, "unified_inbox_enabled");
+	    account.addWidget(new lb());
+        split.addWidget(account, {
+            get: ox.Configuration.Group.NoField.get,
+            set: function(data) {
+                name.setEnabled(data.id !== 0);
+                primary_address.setEnabled(data.id !== 0);
+                return data;
+            }
+        });
 	    
 	    /*** SERVER SETTINGS ***/
 	    var mail = new ox.Configuration.Group(_("Server Settings")); 
-	    split.addWidget(mail, ox.Configuration.Group.NoField);	        
+        split.addWidget(mail, disabler(mail));
 	    
 	    function changePort() {
 	    	switch(mail_protocol.get()) {
@@ -279,7 +364,7 @@ register("OX_Configuration_Loaded", function () {
 	        		break;
 	    	}
 	    }
-	    	    
+
 	    
 	    var mail_protocol = new ox.UI.ComboBox(_("Server Type"));
 	    mail_protocol.width = "18.5em";
@@ -297,13 +382,16 @@ register("OX_Configuration_Loaded", function () {
 	    mail.addWidget(mail_secure, "mail_secure");
 	    mail_secure.changed = changePort;
 	    
-	    mail.addWidget(new ox.UI.Input(_("Server Name")), "mail_server");
+	    var mail_server = new ox.UI.Input(_("Server Name")); 
+	    mail.addWidget(mail_server, "mail_server");
 	    var mail_port = new ox.UI.Input(_("Server Port"));
 	    mail_port.default_value = "143";
 	    mail.addWidget(mail_port, "mail_port");
 	    
-	    mail.addWidget(new ox.UI.Input(_("Login")), "login");
-	    mail.addWidget(new ox.UI.Password(_("Password")), "password");
+	    var login = new ox.UI.Input(_("Login"));
+	    mail.addWidget(login, "login");
+	    var password = new ox.UI.Password(_("Password"));
+	    mail.addWidget(password, "password");
 	    
 	    var pop_refresh_rate = new ox.UI.ComboBox(_("Check for new messages every 'n' minutes"));
 	    pop_refresh_rate.width = "5em";	    
@@ -325,12 +413,11 @@ register("OX_Configuration_Loaded", function () {
 	    pop_delete_write_through.setEnabled(false);
 	    mail.addWidget(pop_delete_write_through, "pop3_delete_write_through");
 	    
-	    mail.addWidget(lb);
-	    	    
+	    mail.addWidget(new lb());
 	    
 	    /*** TRANSPORT SETTINGS ***/
 	    var transport = new ox.Configuration.Group(_("Outgoing Server Settings (SMTP)"));
-	    split.addWidget(transport, ox.Configuration.Group.NoField);
+	    split.addWidget(transport, disabler(transport));
 	    
 	    var transport_secure = new ox.UI.CheckBox("Use SSL connection");
 	    transport.addWidget(transport_secure, "transport_secure");
@@ -360,12 +447,40 @@ register("OX_Configuration_Loaded", function () {
 		var transport_password = new ox.UI.Password(_("Password"));
 		transport.addWidget(transport_password, "transport_password");
 		transport_password.disable();
+		
+	    split.addWidget(new lb());
+	    
+	    /*** FOLDER SETTINGS ***/	    
+	    var folder = new ox.Configuration.Group(_("Folder Settings"));
+	    split.addWidget(folder, {
+            get: ox.Configuration.Group.NoField.get,
+            set: function(data) {
+                folder.setVisible(Boolean(data.id));
+                return data;
+            }
+        });
 	    	    
-	    /*** BUTTONS ***/
-	    split.addWidget(lb);
+	    var sent_fullname = new temporary.MailFolderSelection(_("Sent folder"));        
+	    sent_fullname.width = "30em";
+	    folder.addWidget(sent_fullname, "sent_fullname");
+        
+        var trash_fullname = new temporary.MailFolderSelection(_("Trash folder"));        
+        trash_fullname.width = sent_fullname.width;
+        folder.addWidget(trash_fullname, "trash_fullname");
+        
+        var drafts_fullname = new temporary.MailFolderSelection(_("Drafts folder"));        
+        drafts_fullname.width = sent_fullname.width;
+        folder.addWidget(drafts_fullname, "drafts_fullname");
+        
+        var spam_fullname = new temporary.MailFolderSelection(_("Spam folder"));        
+        spam_fullname.width = sent_fullname.width;
+        folder.addWidget(spam_fullname, "spam_fullname");
+	    
+        folder.addWidget(new lb());
+        
+        /*** BUTTONS ***/
 	        
 	    var buttons = new ox.Configuration.HLayout();
-	    split.addWidget(buttons);
 	    
 	    var check_button = new ox.UI.Button(_("Check connection"));
 	    check_button.click = function() { 
@@ -386,14 +501,44 @@ register("OX_Configuration_Loaded", function () {
                     	return true;
                     });
 	    };
-	    buttons.addWidget(check_button);
+        buttons.addWidget(check_button);
+        split.addWidget(buttons, {
+            get: emptyFunction,
+            set: function(data) { check_button.setEnabled(data.id !== 0); }
+        });
 	    
 	    var save_button = new ox.UI.Button(_("Save"));
-	    save_button.click = function() { split.saveView(); };
+	    save_button.click = function(data, pata) {
+	    	function fail(field) {
+	    		setTimeout(function() { 
+	    			triggerEvent("OX_New_Error", 4, format(_("The mandatory field %1$s is not defined."), field)); 
+	    		}, 0);
+	    		return;
+	    	}
+	    	if (name.get() == "") {
+	    		name.formnode.focus();
+	    		return fail(_("Account Name"));
+	    	} else if (primary_address.get() == "") {	  
+	    		primary_address.formnode.focus();
+	    		return fail(_("E-Mail Address"));	 
+	    	} else if (mail_server.get() == "") {
+	    		mail_server.formnode.focus();
+	    		return fail(_("Server Name"));
+    		} else if (login.get() == "") {
+	    		login.formnode.focus();
+	    		return fail(_("Login"));
+    		} else if (!split["id"] && password.isEnabled && password.get() == "") {
+    			password.formnode.focus();
+	    		return fail(_("Password"));
+    		}
+	    	split.saveView(); 	    	
+	    };
 	    buttons.addWidget(save_button);
 	
 	    var cancel_button = new ox.UI.Button(_("Cancel"));
 	    cancel_button.click = function() { split.cancelView(); };
 	    buttons.addWidget(cancel_button);
+	    
+	    //split.disable();
 	}
 });
\ No newline at end of file
