@@ -153,24 +153,18 @@ function cs_saveConfiguration() {
 		setLanguage(configGetKey("language"));
 		cs_region_enter();
 	}
-	if(configuration_changed_fields["gui"]) {		
+	if (configuration_changed_fields["gui"]) {		
 		var selectedTheme = cs_theme.getKey();		
 		if (selectedTheme != configGetKey("gui.theme").path && configContainsKey("modules.themes." + selectedTheme)) {
 			triggerEvent("OX_New_Info",4,_("Theme will be applied after a new login."/*i18n*/));
 			configSetKey("gui.theme", { name: configGetKey("modules.themes")[selectedTheme], path: selectedTheme });
 		}
-				
-		/*
-		 
-		This doesn't really work, so we won't do it ;-) Force user to re-login instead. 
-		 
-		changeImgPath(themeStyle.path);
 		
-		loadCSSFileForNewWindow("themes/"+themeStyle.path+"/css/calendar.css");
-		loadCSSFileForNewWindow("themes/"+themeStyle.path+"/css/global.css");
-		loadCSSFileForNewWindow("themes/"+themeStyle.path+"/css/popup.css");
-		loadCSSFileForNewWindow("themes/"+themeStyle.path+"/css/bgimages.css");
-		*/		
+		var selectedPage = cs_landingPage.getKey();		
+		if (selectedPage) {
+			configSetKey("gui.global.landing_page", { module: selectedPage });
+		}
+			
  		configSetKey("gui.global.save",getValueofRadioBox("cs_saveconfig"));
 		configSetKey("gui.global.autorefresh",cs_autorefresh.getKey());
 		configSetKey("gui.portal.tooltip",getBoolofInt(getValueofRadioBox("cs_showquickinfo")));
@@ -316,9 +310,14 @@ function cs_enter() {
 		cs_theme.setKey(configGetKey("gui.theme").path);
 		configuration_changed_fields["gui"]=false;
 	}
+	if(configContainsKey("gui.global.landing_page")) {
+		cs_landingPage.setKey(configGetKey("gui.global.landing_page").module);
+		configuration_changed_fields["gui"]=false;
+	}
 	cs_autorefresh.setKey(configGetKey("gui.global.autorefresh"));
-	if(configContainsKey("gui.global.save")) {
-		setIntofRadioBox("cs_saveconfig",configGetKey("gui.global.save"));
+	if (configContainsKey("gui.global.save")) {
+		var id = configGetKey("gui.global.save");
+		setIntofRadioBox("cs_saveconfig", id);
 		configuration_changed_fields["gui"]=false;
 	}
 	if(configContainsKey("gui.portal.tooltip")) {
@@ -468,11 +467,20 @@ function cs_init() {
         themes.push({ name: "Default", path: "default" });
     }
     
-	cs_theme = new ComboBox3(window, "cs_theme", "25em", 0, true, "OX_Configuration_Settings_Changed_GUI", 3);
+	cs_theme = new ComboBox3(window, "cs_theme", "30em", 0, true, "OX_Configuration_Settings_Changed_GUI", 3);
 	for(var i=0;i<themes.length;i++) {
 		cs_theme.addElement(themes[i].name, themes[i].path);	
 	}	
     cs_theme.getDomNode();
+    
+    
+	cs_landingPage = new ComboBox3(window, "cs_landing_page", "30em", 0, true, "OX_Configuration_Settings_Changed_GUI", 3);
+	for(var i in modules) {
+		if (modules[i].disable == false && modules[i].name != "configuration") {
+			cs_landingPage.addElement(modules[i].text, modules[i].name);
+		}
+	}	
+	cs_landingPage.getDomNode();
 }
 
 function cs_leave() { }
@@ -481,6 +489,7 @@ var cs_language;
 var cs_autorefresh;
 var cs_timezone;
 var cs_theme;
+var cs_landingPage;
 var cs_dateformat;
 var cs_date_separator;
 
