@@ -1192,8 +1192,10 @@ ox.Configuration.View.prototype = extend(ox.UI.Container,
         
         /**
          * Saves view contents.
+         * @param {Function} callback An optional callback functi which is
+         * called after the view is saved. 
          */
-        saveView: function() {},
+        saveView: function(callback) {},
         
         /**
          * Reverts modifications made by the user.
@@ -1324,7 +1326,7 @@ ox.Configuration.VSplit.prototype = extend(ox.Configuration.View,
                 width: this.split_size + "px", cursor: "e-resize"
             }, { className: "sizesplit-vline" }, [
                 newnode("img", { top: "50%", marginTop: "-10px" },
-                    { src: "themes/default/img/split_grip_v.gif" })
+                    { src: getFullImgSrc("img/split_grip_v.gif") })
             ]);
             addDOMEvent(this.split, "mousedown", d);
             this.right = this.table = newnode("div", {
@@ -1512,7 +1514,7 @@ ox.Configuration.VSplit.prototype = extend(ox.Configuration.View,
             this.list.disable();
         },
         
-        saveView: function() {
+        saveView: function(callback) {
             this.isNew = false;
             if (this.save) {
                 var data = this.get();
@@ -1529,7 +1531,10 @@ ox.Configuration.VSplit.prototype = extend(ox.Configuration.View,
                     } else {
                         Self.original = data;
                     }
+                    if (callback) callback();
                 });
+            } else if (callback) {
+                callback();
             }
         },
 
@@ -1687,11 +1692,14 @@ ox.Configuration.Page.prototype = extend(ox.Configuration.View,
             }
         },
 
-        saveView: function() {
+        saveView: function(callback) {
             if (this.save) {
                 var data = this.get();
                 var Self = this;
-                this.save(data, function() { Self.original = data; });
+                this.save(data, function() {
+                    Self.original = data;
+                    if (callback) callback();
+                });
             }
         },
 
