@@ -45,10 +45,13 @@ registerView("contacts",
 		register("OX_Add_Flag", setFlagInContactView);
         globalSearchMenu.setFields(
             ["first_name", "last_name", "display_name", "email1", "email2",
-                "email3", "categories"],
+                "email3", "company", "street_business", "city_business",
+                "department", "categories"],
             ["First name"/*i18n*/, "Last name"/*i18n*/, "Display name"/*i18n*/,
                 "E-Mail (business)"/*i18n*/, "E-Mail (private)"/*i18n*/,
-                "E-Mail (other)"/*i18n*/, "Tags"/*i18n*/],
+                "E-Mail (other)"/*i18n*/, "Company (business)" /*i18n*/, 
+                "Street (business)" /*i18n*/, "City (business)" /*i18n*/, 
+                "Department" /*i18n*/, "Tags"/*i18n*/],
             configGetKey("modules.contacts.gui.searchFields") ||
                 { first_name: true, last_name: true, display_name: true,
                   email1: true, email2: true, email3: true, categories: true });
@@ -87,8 +90,7 @@ registerView("contacts/phonelist",
 		initLiveGridContacts();	
 		register("OX_Print",contacts_printList);
 		register("OX_New_Search",searchContactByString);
-		register("OX_Delete_Search",deleteSearchContactByString);			
-		contactsFolderPath.drawDOMNode("contactsListHeaderOwner", activefolder);	
+		register("OX_Delete_Search",deleteSearchContactByString);				
 	},
 	function() {
 		if(contactGrid) {
@@ -107,7 +109,6 @@ registerView("contacts/phonelist",
 	function() {
 		myLetterContactTab.buildTab("listeContactsLetterDiv");
 		initLiveGridContacts();	
-		contactsFolderPath.drawDOMNode("contactsListHeaderOwner", activefolder);	
 	}
 );
 registerView("contacts/cards",
@@ -121,8 +122,7 @@ registerView("contacts/cards",
 		else
 			showContactCards();
 		register("OX_New_Search",searchContactByString);	
-		register("OX_Delete_Search",deleteSearchContactByString);	
-		contactsFolderPath.drawDOMNode("contactsCardsHeaderOwner", activefolder);		
+		register("OX_Delete_Search",deleteSearchContactByString);
 		
 		objContactFunctions.refHover = new Hover($("tablecontactscards"),OXContactHover.getContent().node);
 		objContactFunctions.refHover.setSize(OXContactHover.contentobject.node);
@@ -178,7 +178,6 @@ registerView("contacts/cards",
 		scrollerCbar.scrollLeft = 0;	
 		myLetterContactTab.buildTab("cardContactsLetterDiv");		
 		showContactCards();			
-		contactsFolderPath.drawDOMNode("contactsCardsHeaderOwner", activefolder);	
 	}
 );
 registerView("contacts/detail",
@@ -330,6 +329,47 @@ ContactFunctions.prototype = {
 		contact_tag_object.color_label = tag;
 		OXContactMapping.setTag(tag, obj);
 	},
+	
+	sendAsVCard: function() {
+	    // get current selection	   
+        var collection={};
+        collection.objects = currentpath2[1] == "cards" ? contactsSelection2.getSelected() : contactGrid.selection.getSelected();
+        collection.columns = ["display_name", "last_name", "distribution_list"];
+        OXCache.newRequest(null, "contacts", collection, null,
+        function (daten) {
+            if (daten.objects.length) {
+                var selection = daten.objects;
+                // collect contacts (and skip distribution lists)
+                var contacts = [];
+                for (var i = 0; i < selection.length; i++) {
+                    var item = selection[i];
+                    // is contact?
+                    if (item.distribution_list == null) {
+                        // add contact as vCard
+                        contacts.push({
+                            "objectType": "vCard",
+                            "data": {
+                                "args": [{"com.openexchange.groupware.contact.pairs": [{"folder": item.folder_id, "id": item.id}]}],
+                                "identifier": "com.openexchange.contact"
+                            },
+                            "compositeID": { "folder": item.folder_id, "id": item.id },
+                            "name": item.display_name || item.last_name || item.first_name || "contact"
+                        });
+                    }
+                }
+                // open "new email" window
+                var newMail = newWindow("newMail.html", getWindowOptions(null, screen.availHeight-25));
+                newMail.focus();
+                // attach vCards
+                newMail.attachedObjects = contacts;
+            }
+        });
+        
+        
+	    
+	    
+	},
+	
 	deleteContacts: function() {
 		var selection=contactsSelection2.getSelected();
 		
@@ -412,8 +452,7 @@ ContactFunctions.prototype = {
                 scrollerCbar.scrollLeft = ($("contactCardTable").clientWidth/4) * Math.floor(contactGrid.focus/cardsPerRowToView);
             } else { scrollerCbar.scrollLeft = 0; }
             scrollCardView();
-            // moved triggerEvent("Selected", contactsSelection2.getSelected());
-            // from here to end of scrollCardView()
+            contact_HeaderUpdate(collection);
         }
 	},
 	renderWidthScrollbarDiv : function() {
@@ -825,7 +864,9 @@ register("OX_Contact_Delete",
 					objContactFunctions.deleteContacts();
 				}
 		);
-
+register("OX_Contact_SendVCard", function(){
+    objContactFunctions.sendAsVCard();
+});
 
 /**
  * global vars
@@ -1380,7 +1421,6 @@ function duplicateContact()
 	}
 }
 
-
 function DistributionLiveGrid() {
 	this.oDistrList 		= {};
 	this.oDistrList.data 	= new Array();
@@ -1926,119 +1966,124 @@ function initLiveGridOnLoad()
 		contactGrid = null;
 	}
 	
-	contactGrid = new LiveGrid2([
-		{
-			text: "",
-			sortable: false,
-			name : ["mark_as_distributionlist"],    
-			width: "16px",
-			style: {padding: 0},
-			set: function(div,text) {
-				var divIcons = "";
-				if (div) {
-					if (text) {
-						addDOMEvent(div.parentNode, "mousedown", function() { setStatusDLSelection(); });
-						divIcons = "<img src='"+getFullImgSrc("img/menu/distributionlist.gif")+"' alt='Distribution List' />"; 
-					} else {
-						addDOMEvent(div.parentNode, "mousedown", function() { setStatusDLSelection(); });
-						divIcons = "<img src='"+getFullImgSrc("img/folder/contacts.gif")+"' alt='Contact' />"; 
-					}
-					
-				}
-				div.innerHTML = divIcons;
-			},
-			clear: function(div) {
-				if (!div.firstChild)
-					div.appendChild(document.createElement("img"));
-				div.firstChild.src = getFullImgSrc("img/mail/noattachment.gif");
-			}
-		}, {	
-			text: "",
-			name : ["private_flag"],    
-			sortable: false,	
-			width: "16px",
-			style: {padding: 0},
-			set: function(div, text) {
-				if (div.firstChild)
-					div.firstChild.src = !text ? getFullImgSrc("img/dummy.gif") : getFullImgSrc("img/private_flag.gif");
-				else
-					div.appendChild(newnode("img", 0,
-						{src: !text ? getFullImgSrc("img/dummy.gif") : getFullImgSrc("img/private_flag.gif"), alt: "", width: "16", height: "16"}));
-			},
-			clear: function(div) {
-				if (!div.firstChild)
-					div.appendChild(document.createElement("img"));
-				div.firstChild.src = getFullImgSrc("img/mail/noattachment.gif");
-			}
-		},
-		{
-			text: "Name", /*i18n*/
-			sortable: true,
-			i18n: true,
-			name : ["display_name","first_name","last_name"],
-			sort : "last_name",				
-			set: function (div, text) {
-				var nameHeadline = objContactCardFunctions.getHeadline(text,true);
-				if (div.firstChild)
-					div.firstChild.data = nameHeadline;
-				else
-					div.appendChild(document.createTextNode(nameHeadline));
-			},
-			clear: clearLgridField
-		}, {
-			text: "Company", /*i18n*/
-			name:["company"],
-            sort:"company",
-            sortable: true,
-			i18n: true,			
-			width: "14%",
-			set: LiveGrid.defaultSet,
-			clear: clearLgridField
-		}, {
-			text: "City", /*i18n*/
-			name:["city_business"],
-            sort:"city_business",
-			sortable: true,
-			i18n: true,			
-			width: "14%",
-			set: LiveGrid.defaultSet,
-			clear: clearLgridField
-		}, {
-			text: "Phone", /*i18n*/
-			name: ["telephone_business1"],
-			sort: "telephone_business1",
-			sortable: true,
-			i18n: true,				
-			width: "18%",
-			set: LiveGrid.defaultSet,
-			clear: clearLgridField
-		}, {
-			text: "Mobile", /*i18n*/
-			sortable: true,
-			i18n: true,
-			name : ["cellular_telephone1"],
-			sort : "cellular_telephone1",			
-			width: "18%",
-			set: LiveGrid.defaultSet,
-			clear: clearLgridField
-		}, {
-			text: "Flag", /*i18n*/
-			sortable: true,
-			i18n: true,			
-			name : ["color_label"],
-			sort : "color_label",
-			width: "3em",
-			set: function(div,text) {
-				var divIcons = "";
-				if (div) {
-					divIcons = "<img src='"+getFullImgSrc("img/menu/tag_" + (text || 0) + ".gif")+"' alt='tag' />";
-					div.innerHTML = divIcons;
-				}
-			},
-			clear: clearLgridField
-		}
-
-	], contactsSelection2, "contacts");
+	temporary.lists.contacts = temporary.MakeList({
+	    updated: function() { cnotactGrid.recreate(); },
+	    columns: [
+            {
+                text: "",
+                sortable: false,
+                name : ["mark_as_distributionlist"],    
+                width: "16px",
+                style: {padding: 0},
+                set: function(div,text) {
+                    var divIcons = "";
+                    if (div) {
+                        if (text) {
+                            addDOMEvent(div.parentNode, "mousedown", function() { setStatusDLSelection(); });
+                            divIcons = "<img src='"+getFullImgSrc("img/menu/distributionlist.gif")+"' alt='Distribution List' />"; 
+                        } else {
+                            addDOMEvent(div.parentNode, "mousedown", function() { setStatusDLSelection(); });
+                            divIcons = "<img src='"+getFullImgSrc("img/folder/contacts.gif")+"' alt='Contact' />"; 
+                        }
+                        
+                    }
+                    div.innerHTML = divIcons;
+                },
+                clear: function(div) {
+                    if (!div.firstChild)
+                        div.appendChild(document.createElement("img"));
+                    div.firstChild.src = getFullImgSrc("img/mail/noattachment.gif");
+                }
+            }, {    
+                text: "",
+                name : ["private_flag"],    
+                sortable: false,    
+                width: "16px",
+                style: {padding: 0},
+                set: function(div, text) {
+                    if (div.firstChild)
+                        div.firstChild.src = !text ? getFullImgSrc("img/dummy.gif") : getFullImgSrc("img/private_flag.gif");
+                    else
+                        div.appendChild(newnode("img", 0,
+                            {src: !text ? getFullImgSrc("img/dummy.gif") : getFullImgSrc("img/private_flag.gif"), alt: "", width: "16", height: "16"}));
+                },
+                clear: function(div) {
+                    if (!div.firstChild)
+                        div.appendChild(document.createElement("img"));
+                    div.firstChild.src = getFullImgSrc("img/mail/noattachment.gif");
+                }
+            },
+            {
+                text: "Name", /*i18n*/
+                sortable: true,
+                i18n: true,
+                name : ["display_name","first_name","last_name"],
+                sort : "last_name",             
+                set: function (div, text) {
+                    var nameHeadline = objContactCardFunctions.getHeadline(text,true);
+                    if (div.firstChild)
+                        div.firstChild.data = nameHeadline;
+                    else
+                        div.appendChild(document.createTextNode(nameHeadline));
+                },
+                clear: clearLgridField
+            }, {
+                text: "Company", /*i18n*/
+                name:["company"],
+                sort:"company",
+                sortable: true,
+                i18n: true,         
+                width: "14%",
+                set: LiveGrid.defaultSet,
+                clear: clearLgridField
+            }, {
+                text: "City", /*i18n*/
+                name:["city_business"],
+                sort:"city_business",
+                sortable: true,
+                i18n: true,         
+                width: "14%",
+                set: LiveGrid.defaultSet,
+                clear: clearLgridField
+            }, {
+                text: "Phone", /*i18n*/
+                name: ["telephone_business1"],
+                sort: "telephone_business1",
+                sortable: true,
+                i18n: true,             
+                width: "18%",
+                set: LiveGrid.defaultSet,
+                clear: clearLgridField
+            }, {
+                text: "Mobile", /*i18n*/
+                sortable: true,
+                i18n: true,
+                name : ["cellular_telephone1"],
+                sort : "cellular_telephone1",           
+                width: "18%",
+                set: LiveGrid.defaultSet,
+                clear: clearLgridField
+            }, {
+                text: "Flag", /*i18n*/
+                sortable: true,
+                i18n: true,         
+                name : ["color_label"],
+                sort : "color_label",
+                width: "3em",
+                set: function(div,text) {
+                    var divIcons = "";
+                    if (div) {
+                        divIcons = "<img src='"+getFullImgSrc("img/menu/tag_" + (text || 0) + ".gif")+"' alt='tag' />";
+                        div.innerHTML = divIcons;
+                    }
+                },
+                clear: clearLgridField
+            }
+        ]
+	});
+	
+	contactGrid = new LiveGrid2(temporary.lists.contacts.columns,
+	    contactsSelection2, "contacts");
     
     contactGrid.contextmenu = globalContextMenus.contacts;
 	
@@ -2046,6 +2091,8 @@ function initLiveGridOnLoad()
 
 	listHeader.appendChild(contactGrid.getHeader());
 	contactGrid.getTable(list);
+	
+	contactGrid.events.register("Changed", contact_HeaderUpdate);
 		
 	contactGrid.events.register("Selected", 
 		function(ids) {
@@ -2219,7 +2266,8 @@ LetterContactTab.prototype = {
 		// For test purpose only. You can delete this if you see it
 		//configSetKey("modules.contacts.characterSearch",false);
 		
-		if (configContainsKey("modules.contacts.characterSearch") && configGetKey("modules.contacts.characterSearch") == false){
+		if (configContainsKey("modules.contacts.characterSearch") && configGetKey("modules.contacts.characterSearch") == false ||
+				configContainsKey("minimumSearchCharacters") && configGetKey("minimumSearchCharacters") >= 1){
 			var temp_scrollerCbar = $("contactCardScrollerbar");
 			if (temp_scrollerCbar){ temp_scrollerCbar.style.marginRight="0"; }
 			var temp_contactCardTable = $("contactCardTable");
@@ -2288,6 +2336,11 @@ LetterContactTab.prototype = {
 	}
 }
 
+function contact_HeaderUpdate(data) {
+	contactsFolderPath.additionalNode=document.createTextNode(" ("+ data.objects.length + ")");
+	contactsFolderPath.drawDOMNode(currentpath2[1] == "phonelist" ? "contactsListHeaderOwner" : "contactsCardsHeaderOwner", activefolder);
+}
+
 var myLetterContactTab = new LetterContactTab(); 
 function searchContactByString(sModule,sPattern) {	
 	objContactFunctions.getStorageCache(sPattern, true); 
@@ -2306,6 +2359,4 @@ function deleteSearchContactByString() {
 	}
 }
 
-	
-var refToMain;
 fileloaded();
\ No newline at end of file
