@@ -141,9 +141,6 @@ registerView("contact_new/attachment",
 	}
 );
 
-
-
-var refToMain;
 var json = new JSON();
 var contactDetailId = 0;
 var activefolderLocal = "";
@@ -369,9 +366,8 @@ function newContactOnload()
 	initAll();
 	
 	var themeStyle = corewindow.oxThemeStyle || { name: "Default", path: "default" };
-	loadCSSFileForNewWindow("themes/"+themeStyle.path+"/css/global.css");
+    removeCSSFilesForNewWindow(themeStyle.path);
 	loadCSSFileForNewWindow("themes/"+themeStyle.path+"/css/popup.css");
-	loadCSSFileForNewWindow("themes/"+themeStyle.path+"/css/bgimages.css");
 	
 	window.setTimeout(function() {
 		initContactContent();
@@ -1152,8 +1148,7 @@ function writeNewContact()
 }
 
 
-function finalFunction(myObject)
-{	
+function finalFunction(myObject) {	
     if ("new_contains_image1" in myNewContactFunctions) {
         contact_object.contains_image1 =
             myNewContactFunctions.new_contains_image1;
@@ -1161,6 +1156,7 @@ function finalFunction(myObject)
     if (tmp_attachmentDialog.attach_changed()) {
         contact_object.number_of_attachments =
             tmp_attachmentDialog.file_storage.ids.length;
+        corewindow.triggerEvent("OX_Quota_Update");
     }
 	if(modulPopup == "new" || modulPopup == "duplicate") {
        setBeforeUnload(false);
