@@ -14,7 +14,6 @@
  * 
  */
 
-var refToMain = window.opener;
 var contactDetailId = 0;
 var activefolderLocal = "";
 var activemoduleLocal = corewindow.activemodule;
@@ -86,10 +85,8 @@ function initDistributionListLoaded() {
 	initAll();
 	window.setTimeout(function() {
 		var themeStyle = corewindow.oxThemeStyle || { name: "Default", path: "default" };
-			
-		loadCSSFileForNewWindow("themes/"+themeStyle.path+"/css/global.css");
+	    removeCSSFilesForNewWindow(themeStyle.path);
 		loadCSSFileForNewWindow("themes/"+themeStyle.path+"/css/popup.css");
-		loadCSSFileForNewWindow("themes/"+themeStyle.path+"/css/bgimages.css");
 	},0);
 }
 
@@ -470,27 +467,20 @@ function distrFromAddressbookLive() {
 				switch (item.type) {
 					// user
 					case 1:
-						// duplicate?
-						if ( typeof(storage.indices[item.id]) == 'undefined' ) {
-							// add to list
-							storage.append([{ 
-								'id': item.id,
-								'display_name': item.display_name || "",
-								'email': item.mail
-							}]);
-						}						
-						break;
-						
 					// contact
 					case 5:
-						// duplicate?
-						if ( typeof(storage.indices[item.id]) == 'undefined' ) {
-							// add to list
-							storage.append([{ 
+						var myObject = { 
 								'id': item.id,
 								'display_name': item.display_name || "",
 								'email': item.mail
-							}]);
+							};
+						// duplicate?
+						if ( typeof(storage.indices[item.id]) == 'undefined') {
+							// add to list
+							storage.append([myObject]);
+						} else if (typeof(item.recurrence) != "undefined" && item.recurrence != 0) {
+							myObject.id = storage.ids.length;
+							storage.append([myObject]);
 						}
 						break;
 				}
@@ -498,7 +488,7 @@ function distrFromAddressbookLive() {
 		},
 		// showUser, showGroup, showResource, showFolder, title, id, singleFolderSearch
 		true, false, false, true, "Select Contacts", folderOwner); /*i18n*/
-	
+	participants.allEmailAddresses=true;
 	initParticipantContent();
 }
 
@@ -707,7 +697,7 @@ function writeNewContact() {
 		getDistrForSave();
 				
 		json.put(AjaxRoot + "/contacts?action=new" + 
-				"&session=" + refToMain.session + 
+				"&session=" + corewindow.session + 
 				"&folder=" + clickedItemForSave , 
 				contact_object, null, function(idObj){
 				if(idObj) {	
