@@ -177,20 +177,24 @@ function formatRaw(string, params) {
 /**
  * Formats and translates an error returned by the server.
  * @param {Object} result the JSON object as passed to a JSON callback function.
+ * @param {String} formatString an optional format string with the replacement
+ * parameters <dl><dt>%1$s</dt><dd>the error code,</dd>
+ * <dt>%2$s</dt><dd>the fomratter error message,</dd>
+ * <dt>%3$s</dt><dd>the unique error ID.</dd></dl>
  * @type String
  * @returns the formatted and translated error message.
  * @ignore
  */
-function formatError(result) {
+function formatError(result, formatString) {
 	//#. %1$s is the error code.
 	//#. %2$s is the formatted error message.
     //#. %3$s is the unique error ID.
 	//#, c-format
-	return format(_("Error: %2$s (%1$s, %3$s)"), result.code,
+	return format(formatString || _("Error: %2$s (%1$s, %3$s)"), result.code,
                   format(_(result.error), result.error_params),
                   result.error_id);
 }
-	
+
 (function() {
     var current, current_lang;
     var domains = { "": "lang/%s.js" };
@@ -237,10 +241,11 @@ function formatError(result) {
     
     bindtextdomain = function(domain, pattern) {
         domains[domain] = pattern;
-        setLanguage(current_lang);
+        if (languages[current_lang] === current) setLanguage(current_lang);
     };
 
 	setLanguage = function(name) {
+        current_lang = name;
         var new_lang = languages[name];
 		if (!new_lang) {
             loadLanguage(name);
@@ -253,7 +258,6 @@ function formatError(result) {
             }
         }
 		current = new_lang;
-        current_lang = name;
 		for (var i in init.i18n) {
 			var attrs = init.i18n[i].split(",");
 			var node = $(i);
@@ -529,13 +533,21 @@ function getDays(d) { return Math.floor(d / 864e5); }
  * @ignore
  */
 function getWeek(d, inMonth) {
-	var firstDay = getDayInSameWeek(d, weekStart);
-	var keyDay = firstDay + 7 - daysInFirstWeek;
+	var keyDay = getKeyDayOfWeek(d);
 	var keyDate = new Date(keyDay * 864e5);
 	var jan1st = Date.UTC(keyDate.getUTCFullYear(),
 	                      inMonth ? keyDate.getUTCMonth() : 0);
 	return Math.floor((keyDay - getDays(jan1st)) / 7) + 1;
 }
+ 
+/**
+ * Returns the day of the week which decides the week number
+ * @return Day of week
+ */
+function getKeyDayOfWeek(d) {
+	var firstDay = getDayInSameWeek(d, weekStart);
+	return (firstDay + 7 - daysInFirstWeek);
+}
 
 /**
  * Computes the number of the first day of the specified week, taking into
@@ -850,6 +862,9 @@ var parseDateString;
         formats = {
             date: date,
             time: time,
+            //#. Short date format (month and day only)
+            //#. MM is month, dd is day of the month
+            shortdate: _("MM/dd"),
             //#. The relative position of date and time.
             //#. %1$s is the date
             //#. %2$s is the time
@@ -859,6 +874,11 @@ var parseDateString;
             //#. EEE is the short day of the week,
             //#. %s is the date.
             dateday: format(_("EEEE, %s"), date),
+            //#. The date with the day of the week.
+            //#. EEEE is the full day of the week,
+            //#. EEE is the short day of the week,
+            //#. %s is the date.
+            dateshortday: format(_("EEE, %s"), date),
             //#. The format for calendar timescales
             //#. when the interval is at least one hour.
             //#. H is 1-24, HH is 01-24, h is 1-12, hh is 01-12, a is AM/PM,
