@@ -151,7 +151,9 @@ var delJSON = new JSON();
 function deleteItems() {
 	function cbyes() {
 		var ids=infostoreSelection.getSelected();
-		OXInfoStoreMapping.deleteObjects(ids);
+		OXInfoStoreMapping.deleteObjects(ids, function() {
+			triggerEvent("OX_Quota_Update");		
+		});
 	}
 	
 	if(gridInfoList && gridInfoList.collection) { var aDeleteObjectIdsCount = gridInfoList.getSelectedIDs().length; }
@@ -206,162 +208,168 @@ function loadLiveGridInfo()
 		var DomListDivHeader = $("lg_info_listHeader");
 	    var constructor= LiveGrid2; 
 	    
-	    gridInfoList = new LiveGrid2([
+	    temporary.lists.infostore = temporary.MakeList({
+	        updated: function() { gridInfoList.recreate(); },
+	        columns: [
                 {                   
-                name : ["locked_until", "modified_by"],
-                text: "&#xa0;",
-                width: "20px",
-                style: { padding: 0, textAlign: "center" },
-                sortable: false,        
-                set: function(div, content) {
-                    if (!div.firstChild)
-                        div.appendChild(newnode("img", { paddingTop: "1px" },{ align: "top" }));
-                    div.firstChild.src = content["locked_until"] > 0 ? 
-                           getFullImgSrc("img/folder/document_locked.gif") : 
-                           getFullImgSrc("img/folder/document.gif");
-                },
-                clear: function(div) {
-                    if (!div.firstChild)
-                        div.appendChild(newnode("img", { paddingTop: "1px" },{ align: "top" }));
-                    div.firstChild.src = getFullImgSrc("img/mail/noattachment.gif");
-                }
-            }, {
-                name : ["file_size", "filename", "id", "folder_id"],
-                text: "&#xa0;",
-                sortable: false,
-                width: "11px",  
-                style: { padding: 0, textAlign: "center" },
-                set: function(div, content) {
-                    if (!div.firstChild) {
-                        div.appendChild(newnode("img", { paddingTop: "2px" },{ align: "top" }));
+                    name : ["locked_until", "modified_by"],
+                    text: "&#xa0;",
+                    width: "20px",
+                    style: { padding: 0, textAlign: "center" },
+                    sortable: false,        
+                    set: function(div, content) {
+                        if (!div.firstChild)
+                            div.appendChild(newnode("img", { paddingTop: "1px" },{ align: "top" }));
+                        div.firstChild.src = content["locked_until"] > 0 ? 
+                               getFullImgSrc("img/folder/document_locked.gif") : 
+                               getFullImgSrc("img/folder/document.gif");
+                    },
+                    clear: function(div) {
+                        if (!div.firstChild)
+                            div.appendChild(newnode("img", { paddingTop: "1px" },{ align: "top" }));
+                        div.firstChild.src = getFullImgSrc("img/mail/noattachment.gif");
                     }
-                    div.firstChild.src = (content["file_size"]>0) ? getFullImgSrc("img/mail/attachment.gif")
-                                                 : getFullImgSrc("img/mail/noattachment.gif");
-                                                 
-                    if (content["file_size"]>0) {
-                        div.firstChild.onclick = (function(idvalue, object) { 
-                             return function(e) {
-                                openInfostoreFile(e || event, idvalue, object["id"]);
-                             } 
-                        })(content["filename"], content);
-                        div.firstChild.style.cursor="pointer";
-                        div.firstChild.title=_("Download") + " " + content["filename"];
-                    } else {
-                        div.firstChild.onclick = null;
-                        div.firstChild.style.cursor="default";
-                        div.firstChild.title="";
-                    }
-                },
-                clear: function(div) {
-                    if (!div.firstChild) {
-                        div.appendChild(newnode("img", { paddingTop: "2px" },{ align: "top" }));
-                    }
-                    div.firstChild.src = getFullImgSrc("img/mail/noattachment.gif");
-                }
-            }, {
-                name : ["title"],
-                i18n: "description", /*i18n context*/
-                text: "Title", /*i18n*/
-                sortable: true,
-                sort : "title",
-                set: LiveGrid.defaultSet,                   
-                clear: LiveGrid.makeClear("")
-            }, {
-                name : ["file_size"],
-                text: "Size", /*i18n*/
-                i18n: true,
-                sortable: true,
-                sort : "file_size",
-                width: "6em",
-                set: function (div, text) {
-                    if(text < 0 )
-                        var sDisplayString = '';
-                    else
-                    {
-                        var sDisplayString = bytesToString(text);;
-                    }
-                    if (div.firstChild)
-                        div.firstChild.data = sDisplayString;
-                    else
-                        div.appendChild(document.createTextNode(sDisplayString));
-                },
-                clear: LiveGrid.makeClear("")
-            }, {
-                name : ["creation_date"],
-                text: "Created on", /*i18n*/
-                i18n: true,
-                sortable: true,
-                sort : "creation_date",
-                width: "8em",
-                set: LiveGrid.dateSet,
-                clear: LiveGrid.makeClear("")
-            }, {
-                name : ["created_by"],
-                text: "Created by", /*i18n*/
-                i18n: true,
-                sortable: true,
-                sort : "created_by",
-                width: "20%",           
-                set: function  (div, text) {
-                    var nId = parseInt(text);                                           
-                    function cb_fetchUserFromCache(){
-                        return function (arg)                       
-                        {
-                            if (div.firstChild)
-                                div.firstChild.data = arg[nId].display_name;
-                            else
-                                div.appendChild(document.createTextNode(arg[nId].display_name));
+                }, {
+                    name : ["file_size", "filename", "id", "folder_id"],
+                    text: "&#xa0;",
+                    sortable: false,
+                    width: "11px",  
+                    style: { padding: 0, textAlign: "center" },
+                    set: function(div, content) {
+                        if (!div.firstChild) {
+                            div.appendChild(newnode("img", { paddingTop: "2px" },{ align: "top" }));
                         }
+                        div.firstChild.src = (content["file_size"]>0) ? getFullImgSrc("img/mail/attachment.gif")
+                                                     : getFullImgSrc("img/mail/noattachment.gif");
+                                                     
+                        if (content["file_size"]>0) {
+                            div.firstChild.onclick = (function(idvalue, object) { 
+                                 return function(e) {
+                                    openInfostoreFile(e || event, idvalue, object["id"]);
+                                 } 
+                            })(content["filename"], content);
+                            div.firstChild.style.cursor="pointer";
+                            div.firstChild.title=_("Download") + " " + content["filename"];
+                        } else {
+                            div.firstChild.onclick = null;
+                            div.firstChild.style.cursor="default";
+                            div.firstChild.title="";
+                        }
+                    },
+                    clear: function(div) {
+                        if (!div.firstChild) {
+                            div.appendChild(newnode("img", { paddingTop: "2px" },{ align: "top" }));
+                        }
+                        div.firstChild.src = getFullImgSrc("img/mail/noattachment.gif");
                     }
-                    internalCache.getUsers([nId],cb_fetchUserFromCache());      
-                },
-                clear: LiveGrid.makeClear("")
-            }, {
-                name : ["version"],         
-                text: "Version", /*i18n*/
-                i18n: true,
-                style:{textAlign:"center"},
-                sortable: true,
-                sort : "version",
-                width: "6em",           
-                set: LiveGrid.defaultSet,                   
-                clear: LiveGrid.makeClear("")
-            }, {                
-                name : ["last_modified"],
-                text: "Last modified", /*i18n*/
-                i18n: true,             
-                sortable: true,
-                sort : "last_modified",
-                width: "10em",
-                set: function(div, modified) {
-                    var dateToShow = modified ? formatDate(modified, isToday(modified) ? "time" : "datetime") : "";
-                    if (!div.firstChild) {
-                        div.appendChild(div.ownerDocument.createTextNode(dateToShow));
-                    } else {
-                        div.firstChild.data = dateToShow;
+                }, {
+                    name : ["title"],
+                    i18n: "description", /*i18n context*/
+                    text: "Title", /*i18n*/
+                    sortable: true,
+                    sort : "title",
+                    set: LiveGrid.defaultSet,                   
+                    clear: LiveGrid.makeClear("")
+                }, {
+                    name : ["file_size"],
+                    text: "Size", /*i18n*/
+                    i18n: true,
+                    sortable: true,
+                    sort : "file_size",
+                    width: "6em",
+                    set: function (div, text) {
+                        if(text < 0 )
+                            var sDisplayString = '';
+                        else
+                        {
+                            var sDisplayString = bytesToString(text);;
+                        }
+                        if (div.firstChild)
+                            div.firstChild.data = sDisplayString;
+                        else
+                            div.appendChild(document.createTextNode(sDisplayString));
+                    },
+                    clear: LiveGrid.makeClear("")
+                }, {
+                    name : ["creation_date"],
+                    text: "Created on", /*i18n*/
+                    i18n: true,
+                    sortable: true,
+                    sort : "creation_date",
+                    width: "8em",
+                    set: LiveGrid.dateSet,
+                    clear: LiveGrid.makeClear("")
+                }, {
+                    name : ["created_by"],
+                    text: "Created by", /*i18n*/
+                    i18n: true,
+                    sortable: true,
+                    sort : "created_by",
+                    width: "20%",           
+                    set: function  (div, text) {
+                        var nId = parseInt(text);                                           
+                        function cb_fetchUserFromCache(){
+                            return function (arg)                       
+                            {
+                                if (div.firstChild)
+                                    div.firstChild.data = arg[nId].display_name;
+                                else
+                                    div.appendChild(document.createTextNode(arg[nId].display_name));
+                            }
+                        }
+                        internalCache.getUsers([nId],cb_fetchUserFromCache());      
+                    },
+                    clear: LiveGrid.makeClear("")
+                }, {
+                    name : ["version"],         
+                    text: "Version", /*i18n*/
+                    i18n: true,
+                    style:{textAlign:"center"},
+                    sortable: true,
+                    sort : "version",
+                    width: "6em",           
+                    set: LiveGrid.defaultSet,                   
+                    clear: LiveGrid.makeClear("")
+                }, {                
+                    name : ["last_modified"],
+                    text: "Last modified", /*i18n*/
+                    i18n: true,             
+                    sortable: true,
+                    sort : "last_modified",
+                    width: "10em",
+                    set: function(div, modified) {
+                        var dateToShow = modified ? formatDate(modified, isToday(modified) ? "time" : "datetime") : "";
+                        if (!div.firstChild) {
+                            div.appendChild(div.ownerDocument.createTextNode(dateToShow));
+                        } else {
+                            div.firstChild.data = dateToShow;
+                        }
+                    },
+                    clear: LiveGrid.makeClear("")
+                }, {
+                    name : ["color_label"],     
+                    text: "Flag", /*i18n*/
+                    i18n: true,             
+                    sortable: true,
+                    sort : "color_label",
+                    width: "4em",
+                    style: { padding: 0, textAlign: "center" },
+                    set: function(div, content) {
+                        if (!div.firstChild)
+                            div.appendChild(newnode("img", { paddingTop: "2px" },{ align: "top" }));
+                        div.firstChild.src = getFullImgSrc("img/menu/tag_"+ (content || 0 ) +".gif");
+                    },
+                    clear: function(div) {
+                        if (!div.firstChild)
+                            div.appendChild(newnode("img", { paddingTop: "2px" },{ align: "top" }));
+                        div.firstChild.src = getFullImgSrc("img/menu/tag_0.gif");
                     }
-                },
-                clear: LiveGrid.makeClear("")
-            }, {
-                name : ["color_label"],     
-                text: "Flag", /*i18n*/
-                i18n: true,             
-                sortable: true,
-                sort : "color_label",
-                width: "4em",
-                style: { padding: 0, textAlign: "center" },
-                set: function(div, content) {
-                    if (!div.firstChild)
-                        div.appendChild(newnode("img", { paddingTop: "2px" },{ align: "top" }));
-                    div.firstChild.src = getFullImgSrc("img/menu/tag_"+ (content || 0 ) +".gif");
-                },
-                clear: function(div) {
-                    if (!div.firstChild)
-                        div.appendChild(newnode("img", { paddingTop: "2px" },{ align: "top" }));
-                    div.firstChild.src = getFullImgSrc("img/menu/tag_0.gif");
                 }
-            }
-        ], infostoreSelection, "infostore");
+            ]
+	    });
+	    
+	    gridInfoList = new LiveGrid2(temporary.lists.infostore.columns,
+	        infostoreSelection, "infostore");
         
         gridInfoList.contextmenu = globalContextMenus.infostore;
 		
@@ -391,6 +399,7 @@ function loadLiveGridInfo()
 					deleteItems();
 			}	
 		);
+		gridInfoList.events.register("Changed",infostore_HeaderUpdate);
 	    var hv = gridInfoList.addHover(OXInfostoreHover.getContent().node, function(id) {
 	        OXInfostoreHover.actualHover=hv;
 	        OXInfostoreHover.refillContent(id.id,id.folder_id);                 
