@@ -69,7 +69,8 @@ function fn_infostore_getDetails(objects, forceUpdate) {
 
 function expandInfostoreSplitHeader(fullHeader) {
     if (fullHeader) $('infosplit.header_ext').style.display = "";
-    $("infosplit.expand_plus").getElementsByTagName("img")[0].src="themes/default/img/" + (fullHeader ? "minus" : "plus") + ".gif";
+    $("infosplit.expand_plus").getElementsByTagName("img")[0].src =
+        getFullImgSrc("img/" + (fullHeader ? "minus" : "plus") + ".gif");
     configSetKey("gui.infostore.fullsplitheader", fullHeader);    
     var steps = 6*pxPerEm;
     animate(configGetKey("gui.effects.fading") ? 250 : 0, steps, function(stepN) { 
@@ -173,14 +174,20 @@ function updateInfostoreSplit(object) {
     	          })(idvalue, object);
 	              $("infosplit."+idfield).appendChild(oNodAncS);
                   
+	              function _openFile(idvalue, object) { 
+                	  return function(e) {
+                		  openInfostoreFile(e || event, idvalue, object["id"]);
+                	  } 
+                  }
+	              
                   var oNodAnc = newnode("span", 0, {className:"linkstyle"},
-                        [ document.createTextNode(idvalue) ]);                  
-                  oNodAnc.onclick = (function(idvalue, object) { 
-              	         return function(e) {
-              	         	openInfostoreFile(e || event, idvalue, object["id"]);
-              	         } 
-      	          })(idvalue, object);
-                  $("infosplit."+idfield).appendChild(newnode("img", { paddingRight:"5px" },{ align:"absmiddle", src:getFullImgSrc("img/mail/open_ISattachment.gif") }));
+                        [ document.createTextNode(idvalue) ]);  
+                  oNodAnc.onclick = _openFile(idvalue, object);
+                  
+                  var img = newnode("img", { paddingRight:"5px" },{ className: "cursorPointer", align:"absmiddle", src:getFullImgSrc("img/mail/open_ISattachment.gif") });
+                  img.onclick = _openFile(idvalue, object);
+                  
+                  $("infosplit."+idfield).appendChild(img);
                   $("infosplit."+idfield).appendChild(oNodAnc);
                   
                   $("infosplit.file_info").style.display="";
@@ -515,6 +522,7 @@ function loadLiveGridInfoSplit() {
 				deleteItems();
 			}	
 		);
+		gridInfoSplit.events.register("Changed",infostore_HeaderUpdate);
 		var hv = gridInfoSplit.addHover(OXInfostoreHover.getContent().node, function(id) {
 	        OXInfostoreHover.actualHover=hv;
 	        OXInfostoreHover.refillContent(id.id,id.folder_id);                 
