@@ -75,11 +75,9 @@ registerView("infostore/list",
 		}, 
 		function() { 
 			loadLiveGridInfo();
-			infostoreFolderPath.drawDOMNode("infostoreListHeaderOwner", activefolder);
 			if (gridInfoList) {				
 				infostore_setFocus(gridInfoList);
 			}
-			
 			register('OX_InfoStore_Delete', deleteItems);
             register('OX_InfoStore_Edit', editItem);
             register('OX_InfoStore_Lock', lockItem);
@@ -89,7 +87,9 @@ registerView("infostore/list",
 			register("OX_Delete_Search",deleteSearchInfoItem);			
 			register("OX_Print",infostore_print);
 			register("OX_InfoStore_Send_Attachment",infostore_sendAttachment);
-			register("OX_InfoStore_Send_Link",infostore_sendLink);
+			if ("infostore_sendLink" in window) {
+				register("OX_InfoStore_Send_Link",infostore_sendLink);
+			}
 			register("OX_InfoStore_Open_Attachment",openFileinInfoStore);
             register("OX_InfoStore_Save_Attachment",saveFileinInfoStore);
         }, 
@@ -106,7 +106,9 @@ registerView("infostore/list",
 			unregister("OX_Delete_Search",deleteSearchInfoItem);									
 			unregister("OX_Print",infostore_print);	
 			unregister("OX_InfoStore_Send_Attachment",infostore_sendAttachment);
-			unregister("OX_InfoStore_Send_Link",infostore_sendLink);
+			if ("infostore_sendLink" in window) {
+				unregister("OX_InfoStore_Send_Link",infostore_sendLink);
+			}
 			unregister("OX_InfoStore_Open_Attachment",openFileinInfoStore);
             unregister("OX_InfoStore_Save_Attachment",saveFileinInfoStore);
         },
@@ -118,7 +120,6 @@ registerView("infostore/list",
         	if (changedFolder != undefined) {
         		 menuclearSearch();
         		 loadLiveGridInfo();
-                 infostoreFolderPath.drawDOMNode("infostoreListHeaderOwner", activefolder);
         		 if (gridInfoList) {
         		    infostore_setFocus(gridInfoList); 				    
         		 }
@@ -133,7 +134,6 @@ registerView("infostore/split",
         function() {
             loadLiveGridInfoSplit();                      
             setTabLists(infoSplitTabsList, infoSplitPanelsList, infoSplitEventList);
-            infostoreFolderPath.drawDOMNode("infostoreHsplitHeaderOwner", activefolder); 
             if (gridInfoSplit) {            	
                 infostore_setFocus(gridInfoSplit);
             }           
@@ -142,7 +142,10 @@ registerView("infostore/split",
             if (oLastSelectedInfoObject.length && oLastSelectedInfoObject[0].directLink &&
                 oLastSelectedInfoObject[0].id) {
                 delete(oLastSelectedInfoObject[0].directLink);
-                gridInfoSplit.selection.selectIDs([ Key.createfromObject(oLastSelectedInfoObject[0]) ])                    
+                gridInfoSplit.selection.selectIDs([ Key.createfromObject(oLastSelectedInfoObject[0]) ])
+            } else {
+                gridInfoSplit.selection.selectIDs(
+                    gridInfoSplit.selection.getSelected());
             }
             expandInfostoreSplitHeader(configGetKey("gui.infostore.fullsplitheader"));
             
@@ -155,7 +158,9 @@ registerView("infostore/split",
             register("OX_Delete_Search", deleteSearchInfoItem); 
             register("OX_Print",infostore_print);     
             register("OX_InfoStore_Send_Attachment", infostore_sendAttachment);
-            register("OX_InfoStore_Send_Link", infostore_sendLink);
+            if ("infostore_sendLink" in window) {
+            	register("OX_InfoStore_Send_Link", infostore_sendLink);
+            }
             register("OX_InfoStore_Open_Attachment", openFileinInfoStore);  
             register("OX_InfoStore_Save_Attachment", saveFileinInfoStore);  
         }, 
@@ -179,7 +184,9 @@ registerView("infostore/split",
             unregister("OX_Delete_Search", deleteSearchInfoItem);
             unregister("OX_Print",infostore_print);
             unregister("OX_InfoStore_Send_Attachment", infostore_sendAttachment);
-            unregister("OX_InfoStore_Send_Link", infostore_sendLink);
+            if ("infostore_sendLink" in window) {
+            	unregister("OX_InfoStore_Send_Link", infostore_sendLink);
+            }
             unregister("OX_InfoStore_Open_Attachment", openFileinInfoStore);
             unregister("OX_InfoStore_Save_Attachment", saveFileinInfoStore);
         },
@@ -191,7 +198,6 @@ registerView("infostore/split",
         	if (changeFolder != undefined) {
         		menuclearSearch();
         		loadLiveGridInfoSplit();
-                infostoreFolderPath.drawDOMNode("infostoreHsplitHeaderOwner", activefolder);
         		if (gridInfoSplit) {
                     infostore_setFocus(gridInfoSplit);                    
                 }                
@@ -451,4 +457,9 @@ function callback_error(arg) {
 	newServerError(arg);
 }
 
+function infostore_HeaderUpdate(data) {
+	infostoreFolderPath.additionalNode=document.createTextNode(" ("+ data.objects.length + ")");
+	infostoreFolderPath.drawDOMNode(currentpath2[1] == "split" ? "infostoreHsplitHeaderOwner" : "infostoreListHeaderOwner", activefolder);
+}
+
 fileloaded();
\ No newline at end of file
