@@ -488,14 +488,7 @@ function viewThisDetailsDetailView(oObj,sPrefix)
 									+ '?action=document&session=' + session
 									+ '&content_type=' + encodeURIComponent(sContentType)
 									+ '&id=' + encodeURIComponent(nObjectIdCl);
-						if(IE6)		
-						{
-							newWindow(sURL);	
-						}
-						else
-						{
-							$('dlIframe').src = sURL;
-						}
+						$('dlIframe').src = sURL;						
 						stopEvent(evt);
 					}
 				}
