@@ -204,6 +204,7 @@ function LiveGrid(columns, selection, module) {
 		for (var i = from; i < to; i++) Self.unfetched[i] = true;
 		Self.doScroll();
 		Self.updateStyles();
+		Self.events.trigger("Changed", Self.storage);
 	};
 	
 	/**
@@ -248,6 +249,32 @@ LiveGrid.prototype = {
 	 */
 	granularity: 1,
 	
+    /**
+     * Recreates the LiveGrid, taking into account updated column definitions
+     * etc.
+     */
+	recreate: function() {
+        var storage = this.storage;
+        var oldHeader = this.headerNode;
+        this.disable();
+        for (var i in this.rows) this.deleteRow(i);
+        this.rowcache = [];
+        this.from = 0;
+        this.to = 0;
+        this.ruWidth = 0;
+        var header = this.getHeader();
+        if (oldHeader && oldHeader.parentNode) {
+            oldHeader.parentNode.replaceChild(header, oldHeader);
+        }
+        if (this.parent) {
+            this.parent.removeChild(this.heightDiv);
+            this.parent.removeChild(this.emptyMessage);
+            this.getTable(this.parent);
+        }
+        if (this.hoverNode) this.addHover(this.hoverNode, this.hoverCallback);
+        if (storage) this.enable(storage);
+    },
+	
 	/**
 	 * Creates a DOM tree for the headers of the LiveGrid.
 	 * The returned DOM tree must be inserted in its place in the document.
@@ -275,7 +302,7 @@ LiveGrid.prototype = {
 		var colgroup = this.getColGroup();
 		colgroup.appendChild(this.ruCorner = newnode("col", {width: "0"}));
 		var tbody = newnode("tbody",{verticalAlign : "top"});
-		var table = newnode("table", {tableLayout: "fixed"},
+		var table = this.headerNode = newnode("table", {tableLayout: "fixed"},
 		                    {cellPadding: "0", cellSpacing: "0", className: "livegrid"},
 		                    [colgroup, tbody]);
 		var row = newnode("tr", {height: this.lineHeight + "em"},
@@ -384,6 +411,8 @@ LiveGrid.prototype = {
 	 * object will be called automatically by the LiveGrid.
 	 */
 	addHover: function(hover, callback) {
+        this.hoverNode = hover;
+	    this.hoverCallback = callback;
 		this.hover = new Hover(this.heightDiv, hover);
 		var Self = this;
 		this.hover.onShow = function(node) {
@@ -927,10 +956,12 @@ LiveGrid.dateSet = function(div, date) {
  * @param {String} utc The utc to format in the DIV element.
  */
 LiveGrid.dateSetTime = function(div, date) {
+    var dateString = "\u00a0";
+    if (null != date) dateString = formatDate(date, "datetime");
 	if (div.firstChild)
-		div.firstChild.data = formatDate(date, "datetime");
+		div.firstChild.data = dateString
 	else
-		div.appendChild(document.createTextNode(formatDate(date, "datetime")));
+		div.appendChild(document.createTextNode(dateString));
 };
 
 /**
@@ -1135,7 +1166,7 @@ function LiveGrid2(columns, selection, module) {
      * @private
      */
     this.selected_cb = function(count) {
-        Self.updateStyles();
+    	Self.updateStyles();
         Self.events.trigger("Selected", count);
     };
     
@@ -1168,6 +1199,33 @@ LiveGrid2.prototype = {
      */
     granularity: 15,
     
+    /**
+     * Recreates the LiveGrid, taking into account updated column definitions
+     * etc.
+     */
+    recreate: function() {
+        var enabled = Boolean(this.collection);
+        var oldHeader = this.headerNode;
+        this.disable();
+        for (var i in this.rows) this.deleteRow(i);
+        this.rowcache = [];
+        this.from = 0;
+        this.to = 0;
+        this.ruWidth = 0;
+        var header = this.getHeader();
+        if (oldHeader && oldHeader.parentNode) {
+            oldHeader.parentNode.replaceChild(header, oldHeader);
+        }
+        if (this.parent) {
+            this.parent.removeChild(this.heightDiv);
+            this.parent.removeChild(this.emptyMessage);
+            this.getTable(this.parent);
+        }
+        if (this.hoverNode) this.addHover(this.hoverNode, this.hoverCallback);
+        if (enabled) this.enable(this.collectiondata.criteria,
+                                 this.collectiondata.search);
+    },
+    
     /**
      * Creates a DOM tree for the headers of the LiveGrid2.
      * The returned DOM tree must be inserted in its place in the document.
@@ -1199,7 +1257,7 @@ LiveGrid2.prototype = {
         var colgroup = this.getColGroup();
         colgroup.appendChild(this.ruCorner = newnode("col", {width: "0"}));
         var tbody = newnode("tbody",{verticalAlign : "top"});
-        var table = newnode("table", {tableLayout: "fixed"},
+        var table = this.headerNode = newnode("table", {tableLayout: "fixed"},
                             {cellPadding: "0", cellSpacing: "0", className: "livegrid"},
                             [colgroup, tbody]);
         var row = newnode("tr", {height: this.lineHeight + "em"},
@@ -1497,13 +1555,13 @@ LiveGrid2.prototype = {
      */
 	enable : function(criteria,search,force) {
 		var Self=this;
-		var collectiondata = {
+		this.collectiondata = {
              "criteria" : criteria,
 			 "order" : [{sort : this.sort_id , order : this.sort_order}],
              columns : []
         };
 		if(search) {
-			collectiondata["search"]=search;
+			this.collectiondata["search"]=search;
 		}
         if(this.collection) {
 			if(this.uniqueName) {
@@ -1549,14 +1607,32 @@ LiveGrid2.prototype = {
                 },null,null,disabled,defaultdisabledremove);
             }
         }
-		var returnObject=OXCache.newRequest(null,this.module,collectiondata,
-			function modifiedCallback(data) {
-			  Self.collection=data;
-	          Self.rowCount = data.objects.length;
-	          Self.selection.setCollection(Self.collection);
-	          Self.change_cb(0,data.objects.length); 
-			  Self.events.trigger("Changed", data, true);
-			},
+        var oldFocus = 0, fallbackSelection;
+        var returnObject=OXCache.newRequest(null, this.module,
+            this.collectiondata, {
+                before: function() {
+                    oldFocus = Self.focus;
+                    if (!Self.collection) return;
+                    while (Self.selection.get(oldFocus)) oldFocus++;
+                    fallbackSelection = Self.collection.objects[oldFocus];
+                },
+                fn: function modifiedCallback(data) {
+                    Self.collection=data;
+                    Self.rowCount = data.objects.length;
+                    var index;
+                    if (fallbackSelection) {
+                        index = Self.collection.getIndex(fallbackSelection) - 1;
+                    }
+                    if (index == undefined) {
+                        index = Math.min(oldFocus, Self.rowCount - 1);
+                    }
+                    if (Self.selection.setCollection(Self.collection, index)) {
+                        Self.focus = index;
+                    }
+                    Self.change_cb(0,data.objects.length); 
+                    Self.events.trigger("Changed", data, true);
+                }
+            },
 			function callback(data) {
 				Self.collection=data;
 	            Self.rowCount = data.objects.length;
@@ -1623,6 +1699,8 @@ LiveGrid2.prototype = {
      * @private
      */
     updateStyles: function() {
+    	// return if the selection has no collection
+    	if (!this.selection.collection) return;
         for (var i in this.rows) {
             var newclass = this.selection.get(i) ? "tr selected" : i%2 ? "tr " : "tr_h ";
             if (focusedElement == this.parent && i == this.focus)
@@ -1685,17 +1763,17 @@ LiveGrid2.prototype = {
      */
     doScroll: function() {
 		var Self=this;       
-	    var newruWidth = this.parent.offsetWidth - this.parent.clientWidth;
-        if (newruWidth > 0 && newruWidth != this.ruWidth) {
-            this.ruCorner.style.width = newruWidth + "px";
-            this.ruWidth = newruWidth;
-        }
         if (!this.rowHeight) this.calculateRowHeight();
         this.height = Math.floor(this.parent.clientHeight / this.rowHeight);
         var len = this.collection ? this.collection.objects.length : 0;
         var newHeight = (len * this.rowHeight) + "px"
         var hDivStyle = this.heightDiv.style;
         if (newHeight != hDivStyle.height) hDivStyle.height = newHeight;
+        var newruWidth = this.parent.offsetWidth - this.parent.clientWidth;
+        if (newruWidth > 0 && newruWidth != this.ruWidth) {
+            this.ruCorner.style.width = newruWidth + "px";
+            this.ruWidth = newruWidth;
+        }
         var Self = this;
         if (this.heightDiv.offsetWidth != this.parent.clientWidth)
             hDivStyle.width = Self.parent.clientWidth + "px";
@@ -1913,7 +1991,7 @@ LiveGrid2.prototype = {
             this.selection.click(focus, e);
         }
         cancelDefault(e);
-        if (!IE6) setFocus(this.parent);
+        if (!IE6 && corewindow.hasFocus) setFocus(this.parent);
     },
     
     /**
