@@ -23,7 +23,7 @@ var isPrintableView = refToMain.isPrintableView;
 var registerPrintView = refToMain.registerPrintView;
 var OXMailMapping = refToMain.OXMailMapping, OXCache = refToMain.OXCache;
 var oSel = -1, nested_msgs = "", detailmessage, propertiesPopUp;
-var attachExists=false, mailFetchTimestamp, detailrequest, message = new Object();
+var attachExists=false, mailFetchTimestamp, detailrequest, message = new Object(), selectedAttachments = [];
 var smilies = {
 	";-)": "wink.gif",
 	";)": "wink.gif",
@@ -153,6 +153,7 @@ registerView("mail_detail",
 );
 
 function mail_saveAttachmentInDocStore() {
+	var selAttachment = selectedAttachments[0].data;
 	propertiesPopUp = corewindow.newWindow("newInfoItemMain.html#attachmail=" + selAttachment.id + "&edit_id=" + -1
 			+ "&filename=" + encodeURIComponent(selAttachment.filename)
 			+ "&mailid=" + encodeURIComponent(url["id"])
@@ -281,9 +282,8 @@ function initMailDetail() {
 	session = refToMain.session;
 	
 	var themeStyle = corewindow.oxThemeStyle || { name: "Default", path: "default" };
-	loadCSSFileForNewWindow("themes/"+themeStyle.path+"/css/global.css");
+    removeCSSFilesForNewWindow(themeStyle.path);
 	loadCSSFileForNewWindow("themes/"+themeStyle.path+"/css/popup.css");
-	loadCSSFileForNewWindow("themes/"+themeStyle.path+"/css/bgimages.css");
 	
 	var detailedMail = new Object();
 	detailedMail.id = url["id"];
@@ -499,7 +499,7 @@ function setMessageText(message) {
     
 	for (idfield in attachmentParam) {
 		var conArr = attachmentParam[idfield];
-		var ct = conArr["content_type"].toLowerCase();
+		var ct = conArr["content_type"] ? conArr["content_type"].toLowerCase() : "application/unknown";
 		var con = conArr["content"];
 		if (ct.search(/text\//) != -1 && con != null) {
 			if (ct.search(/text\/plain/) != -1) {
@@ -511,39 +511,38 @@ function setMessageText(message) {
 			}			
 		} else {	
 			if(conArr["filename"]) {
-				attachments.push(conArr);
-				var aimg = getMimeImage(ct).match(/empty.png/g) ? getFullImgSrc("img/mail/attachment.gif") : getMimeImage(ct);
-				attachExists = true;
-				var oDOMDiv = newnode("div", 0, { className: "mailDetailAttachmentsCont" },
-					[ newnode("img",0,{src: aimg, align: "absmiddle", padding: "3px"}),
-					  	newnode("span",0,{className: "nixo"},
-					  		[ document.createTextNode(format(_(" %1$s (%2$s); "),
-					  			conArr["filename"], bytesToString(conArr["size"]))) ]
-					  	)
-					]
-				);	
+				attachments.push(conArr);				
 				
-				(function(oDOMDiv, selAttach) {
-                    addDOMEvent(oDOMDiv, "mousedown", function(e) {	
-						selectAttachment(oDOMDiv, selAttach);
-					});			
-    				addDOMEvent(oDOMDiv, "contextmenu", function(e) {
-                        stopEvent(e);
-                        selectAttachment(oDOMDiv, selAttach);
-                        globalContextMenus.attachments.display(e.clientX,
-                                                               e.clientY);
+				var aimg = getMimeImage(ct).match(/empty.png/g) ? getFullImgSrc("img/mail/attachment.gif") : getMimeImage(ct.toLowerCase());
+                attachExists = true;
+                
+                var oDOMDiv = newnode("div", { MozUserSelect: "none" }, { className: "mailDetailAttachmentsCont" },[
+				  newnode("img", { verticalAlign: "middle" }, { src: aimg, padding: "3px" }),
+                  newnode("span",0,{ className: "nothing" }, [ document.createTextNode(format(_(" %1$s (%2$s); "), 
+                		  conArr["filename"], bytesToString(conArr["size"]))) ])
+                ]); 
+                // prevent text selection on dbl click
+                oDOMDiv.onselectstart = function() { return false; };
+                (function(selAttach) {
+                	var wrapper = function(e) {
+                		selectAttachment(selAttach, (Mac ? e.metaKey : e.ctrlKey), false);                        		
+                	};
+                    addDOMEvent(oDOMDiv, "click", wrapper);
+                    addDOMEvent(oDOMDiv, "dblclick", function(e) { 
+                        openAttachment("OPEN");
                     });
-    				addDOMEvent(oDOMDiv, "dblclick", function(e) {
-						stopEvent(e);		
-						selectAttachment(oDOMDiv, selAttach);
-						openAttachment("OPEN");	
-					});
-    				if (menucountsubselected == 0) {
-                    	selectAttachment(oDOMDiv, selAttach);
+                    addDOMEvent(oDOMDiv, "contextmenu", function(e) {
+                        stopEvent(e);
+                        selectAttachment(selAttach, false, true);
+                        globalContextMenus.attachments.display(
+                            e.clientX, e.clientY);
+                    });                            
+                    if (menucountsubselected == 0) {
+                    	selectAttachment(selAttach, false, false);
+                    	menucountsubselected=1;
                     }
-                })(oDOMDiv, conArr);
-
-				mda.appendChild(oDOMDiv);
+                })({ node: oDOMDiv, data: conArr}); 
+                mda.appendChild(oDOMDiv);
 			} else {
 				removeChildNodes(mda);
 			}
@@ -556,53 +555,52 @@ function setMessageText(message) {
 			(function(o) {
 				var oNestedMessage = new Array(nested_msgs[o]);
 				attachments.push({ filename: nested_msgs[o].filename || nested_msgs[o].subject, content_type: "message/rfc822", size: nested_msgs[o].size });
-				var textAttachment = addTranslated(nested_msgs[o].filename || nested_msgs[o].subject || "message/rfc822 Part");
+				var textAttachment = addTranslated(nested_msgs[o].filename || nested_msgs[o].subject || "message/rfc822 Part" );
 				var blank = document.createTextNode(" ");
-				var oDOMDiv = newnode("div", 0, { className: "mailDetailAttachmentsCont" },
-					[ newnode("img",0,{src: getFullImgSrc("img/mail/unread.gif"), align: "top", title: textAttachment.data, padding: "3px"}),
-					  	newnode("span",0,{className: "ox_none"},
+				var oDOMDiv = newnode("div", { MozUserSelect: "none" }, { className: "mailDetailAttachmentsCont" },
+					[ newnode("img",0,{ src: getFullImgSrc("img/mail/unread.gif"), align: "top", title: textAttachment.data, padding: "3px"}),
+					  	newnode("span",0,{className: "_nothing"},
 					  		[ blank ]
 					  	),
-					  	newnode("span",0,{className: "ox_none", title: textAttachment.data },
+					  	newnode("span", 0, {className: "_nothing", title: textAttachment.data },
 					  		[ textAttachment ]
-					  	),
+					  	)
 					]
 				);
-				
-				(function(oDOMDiv, selNested_msgs, nMessage) {
-                    addDOMEvent(oDOMDiv, "mousedown", function(e) {	
-						selectAttachment(oDOMDiv, selNested_msgs.length ? selNested_msgs[0] : selNested_msgs);
-						detailNestedMessage = selNested_msgs;
+				// prevent text selection on dbl click
+                oDOMDiv.onselectstart = function() { return false; };
+				(function(oDOMDiv, selNested_msgs) {
+					var wrapper = function(e) {
+                		selectAttachment({ node: oDOMDiv, data: selNested_msgs.length ? selNested_msgs[0] : selNested_msgs}, (Mac ? e.metaKey : e.ctrlKey), false);
+                		detailNestedMessage = selNested_msgs;
 						if (!detailNestedMessage.sid) 
 							detailNestedMessage.sid = !isNaN(url["sid"]) ? url["sid"] + nMessage : nMessage;
-					});
-    				
-    				addDOMEvent(oDOMDiv, "contextmenu", function(e) {
+                	};
+                    addDOMEvent(oDOMDiv, "click", wrapper);
+                    addDOMEvent(oDOMDiv, "contextmenu", function(e) {
                         stopEvent(e);
-                        selectAttachment(oDOMDiv, selNested_msgs.length ? selNested_msgs[0] : selNested_msgs);
+                        selectAttachment({ node: oDOMDiv, data: selNested_msgs.length ? selNested_msgs[0] : selNested_msgs}, false, true);
                         detailNestedMessage = selNested_msgs;
                         if (!detailNestedMessage.sid) 
                             detailNestedMessage.sid = !isNaN(url["sid"]) ? url["sid"] + nMessage : nMessage;
                         globalContextMenus.attachments.display(e.clientX,
                                                                e.clientY);
                     });
-    				
-    				addDOMEvent(oDOMDiv, "dblclick", function(e) {
-						stopEvent(e);		
+					addDOMEvent(oDOMDiv, "dblclick", function(e) {
+						cancelBubbling(e);							
 						detailNestedMessage = selNested_msgs;
 						if (!detailNestedMessage.sid) 
 							detailNestedMessage.sid = !isNaN(url["sid"]) ? url["sid"] + nMessage : nMessage;
-						openNestedMessage();
+						openNestedMessage();	
 					});
-    				
-    				if (menucountsubselected == 0) {
-    					selectAttachment(oDOMDiv, selNested_msgs.length ? selNested_msgs[0] : selNested_msgs);
-						detailNestedMessage = selNested_msgs;
-						if (!detailNestedMessage.sid) 
+					if (menucountsubselected == 0) {
+                    	selectAttachment({ node: oDOMDiv, data: selNested_msgs.length ? selNested_msgs[0] : selNested_msgs}, false, false);
+                    	detailNestedMessage = selNested_msgs;
+                    	if (!detailNestedMessage.sid) 
 							detailNestedMessage.sid = !isNaN(url["sid"]) ? url["sid"] + nMessage : nMessage;
+						menucountsubselected=1;
                     }
-				})(oDOMDiv, oNestedMessage, o);
-				
+				})(oDOMDiv, oNestedMessage);
 				mda.appendChild(oDOMDiv);
 			})(nMessage)
 		}
@@ -653,14 +651,30 @@ function setMessageText(message) {
     }, 0);
 }
 
-function selectAttachment(attachCon, selAttach) {
-	if (oSel != -1)
-		oSel.className = "mailDetailAttachmentsCont";
-	attachCon.className = "mailDetailAttachmentsContSel background-color-PMG-selection-elements";
-	selAttachment = selAttach;
-	oSel = attachCon;
-	triggerEvent("OX_Selected_Nested",false);
-	triggerEvent("SubSelected", 1);	
+function selectAttachment(selAttach, multi, context) {
+	// check if click is a context click and if click was on already selected item
+	for (var i in selectedAttachments) {
+		if (selectedAttachments[i].node == selAttach.node && context) {
+			return;
+		}			
+	}
+	var nAtt = [], found = false;
+	for (var i in selectedAttachments) {
+		var attach = selectedAttachments[i];
+		if ((!multi || (multi && attach.node == selAttach.node)) && attach.node.className.match(/mailDetailAttachmentsContSel/)) {
+			attach.node.className = "mailDetailAttachmentsCont";
+			found = (multi && attach.node == selAttach.node);
+		} else if (multi) {
+			nAtt.push(attach);
+		}
+	}
+	selectedAttachments = nAtt;
+	if (!found) {
+		selAttach.node.className = "mailDetailAttachmentsContSel background-color-PMG-selection-elements";
+		selectedAttachments.push(selAttach);
+	}
+	triggerEvent("OX_Selected_Nested", false);
+	triggerEvent("SubSelected", selectedAttachments.length);
 }
 
 function openNestedMessage() {
@@ -675,23 +689,36 @@ function openNestedMessage() {
 		detailMail.focus();
 	}
 }
-	
-function openAttachment(action) {
-	var tF = parent.frames["mail.detail.pop.attachment.save"];
-	var n_url = AjaxRoot + '/mail?action=attachment'
-		 + '&session=' + session + '&folder=' + encodeURIComponent(url["folder"])
-		 + '&id=' + encodeURIComponent(url["id"])
-		 + '&attachment=' + encodeURIComponent(selAttachment.id);
+
+function openAttachment(action) {	
+	var selAttach = selectedAttachments[0].data;
+	var tF = $("mail.detail.pop.attachment.save");
+	var n_url = AjaxRoot + '/mail'
+		 + '?action=' + (action == "SAVE" && 
+				 selectedAttachments.length > 1 ? "zip_attachments" : "attachment")
+		 + '&session=' + session 
+		 + '&folder=' + encodeURIComponent(url["folder"])
+		 + '&id=' + encodeURIComponent(url["id"])			 
 	if (action == "OPEN") {
-		var attachWin = corewindow.newWindow(n_url + "&save=0&filter=1", getWindowOptions(null, null, "scrollbars=yes"),
-			{ "folder": encodeURIComponent(message.folder_id), "id": encodeURIComponent(message.id), "attach_id": encodeURIComponent(selAttachment.id) },
-			window);		
-		attachWin.focus();
-		try{
-			attachWin.document.title = selAttachment.filename;
+		var attachWin = corewindow.newWindow(
+			n_url + "&attachment=" + selAttach.id + "&save=0&filter=1",
+			getWindowOptions(null, null, "scrollbars=yes"),
+			{ "folder": encodeURIComponent(url["folder"]), 
+			  "id": encodeURIComponent(url["id"]), 
+			  "attach_id": encodeURIComponent(selAttach.id) },
+			window);
+		if (attachWin) {
+			attachWin.focus();
+		}
+		try {
+			attachWin.document.title = selAttach.filename;
 		} catch (e) { }
-	} else if (action == "SAVE" && tF && tF.location) {
-		tF.location.href=n_url+"&save=1";
+	} else if (action == "SAVE" && tF && tF.src) {
+		var mattachments = "&attachment="
+		for (var i in selectedAttachments) {
+			mattachments += selectedAttachments[i].data.id + ",";
+		}
+		tF.src = n_url + mattachments.substring(0, mattachments.length-1) + "&save=1";
 	} else {
 		//#. %s will be replaced with an internal error code
 		triggerEvent("OX_New_Error", 4, format(_("Internal Error: Unable to open the Attachment (%s)."), "MA01"));
