@@ -87,7 +87,11 @@ function Participants(attachpoint, cbFunction, showUser, showGroup, showResource
 	/**
 	 * @private
 	 */
-	this.internalStorage2 = new Storage(0, [], "", 0, 0,  null, function(x){ return x[0] + "." + x[1];});
+	this.internalStorage2 = new Storage(0, [], "", 0, 0,  null, 
+			function(x){ 
+				return x[0] + "." + x[1] + "." + x[8] || 0;
+			}
+	);
 	/**
 	 * @private
 	 */
@@ -235,7 +239,11 @@ function ParticipantsSmall(attachpoint, cbFunction, showUser, showGroup, showRes
 	/**
 	 * @private
 	 */
-	this.internalStorage2 = new Storage(0, [], "", 0, 0,  null, function(x){ return x[0] + "." + x[1];});
+	this.internalStorage2 = new Storage(0, [], "", 0, 0,  null, 
+			function(x){ 
+				return x[0] + "." + x[1] + "." + x[8] || 0;
+			}
+	);
 	/**
 	 * @private
 	 */
@@ -288,10 +296,11 @@ function ParticipantsSmall(attachpoint, cbFunction, showUser, showGroup, showRes
 	this.searchField=$("searchpattern_participants");
 	this.searchpattern="";
 	this.blurTimer;
+	this.allEmailAddresses = false;
 	this.getHTML(); 
 	var Self = this;
 
-	register("closeParticipantsWindowOK", function(){ if(Self.enabled) Self.closeParticipantsWindowOK(); });
+	register("closeParticipantsWindowOK", function() { if (Self.enabled) Self.closeParticipantsWindowOK(); });
 	register("closeParticipantsWindowCancel", function(){ if(Self.enabled) Self.closeParticipantsWindowCancel(); });
 	register("addToParticipantsList", function(){ if(Self.enabled) Self.addToParticipantsList(); });
 	register("addToResourceList", function(){ if(Self.enabled) Self.addToResourceList(); });
@@ -361,9 +370,8 @@ Participants.prototype = {
 	},
 	
 	getHTML: function() {
-//		$("tableContainerAddParticipants").style.display = "block";
 		var Self=this;
-		if(this.setFullParticipants){
+		if (this.setFullParticipants) {
 			var sel = this.selectionObject;
 
 			sel.toggle2 = sel.toggle;
@@ -450,7 +458,7 @@ Participants.prototype = {
 						removeChildNodes(div);
 						var dn = text[2] || text[5] || _("unknown"); /*i18n*/
 						if(text[6] == "groupMember"){
-							div.appendChild(newnode("img", 0, {src: getFullImgSrc("img/calendar/user.gif"), alt: "Group Member", align: "absmiddle"}));
+							div.appendChild(newnode("img", 0, {src: getFullImgSrc("img/calendar/user.gif"), alt: _("Group Member"), title: _("Group Member"), align: "absmiddle"}));
 							div.appendChild(document.createTextNode("\u00a0" + dn));
 						} else {
 							div.appendChild(document.createTextNode(dn));
@@ -475,7 +483,7 @@ Participants.prototype = {
 				}, {
 					text: "Comment", /*i18n*/
 					i18n: true,
-					sortable: true,
+					/* sortable: true, */
 					set: function(div, text){
 						if(text[6] == "groupMember"){
 							removeChildNodes(div);
@@ -531,7 +539,7 @@ Participants.prototype = {
 					width: "20px",
 					style: {padding: 0},
 					set: function(div, text) {
-							var color = "";
+							var color = "";							
 							var item_type = getTyp(text[0]);
 							switch (item_type) {
 								case "contact":
@@ -549,7 +557,7 @@ Participants.prototype = {
 										div.firstChild.src = getFullImgSrc("img/calendar/" + img);
 									else{
 										removeChildNodes(div);
-										div.appendChild(newnode("img", 0, {src: getFullImgSrc("img/calendar/" + img), alt: "User", align: "absmiddle"}));
+										div.appendChild(newnode("img", 0, {src: getFullImgSrc("img/calendar/" + img), alt: _("User"), title: _("User"), align: "absmiddle"}));
 									}
 									break;
 								case "group":
@@ -558,7 +566,7 @@ Participants.prototype = {
 										div.firstChild.src = (Self.bDisableG!= -1)?getFullImgSrc("img/calendar/group.gif"):getFullImgSrc("img/calendar/user_d.gif");
 									else{
 										removeChildNodes(div);
-										div.appendChild(newnode("img", 0, {src: getFullImgSrc("img/calendar/group.gif"), alt: "User"}));
+										div.appendChild(newnode("img", 0, {src: getFullImgSrc("img/calendar/group.gif"), alt: _("Group"), title: _("Group")}));
 									}
 									break;
 								case "resource":
@@ -581,7 +589,7 @@ Participants.prototype = {
 					clear: LiveGrid.makeClear("...")
 				}, {	
 					text: "Name", /*i18n*/
-					sortable: true,
+					/* sortable: true, */
 					width: "40%",
 					//set: LiveGrid.defaultSet,
 					//index:2
@@ -592,7 +600,7 @@ Participants.prototype = {
 					clear: LiveGrid.makeClear("...")
 				}, {
 					text: "E-Mail", /*i18n*/
-					sortable: true,
+					/* sortable: true, */
 					set: LiveGrid.defaultSet,
 					clear: LiveGrid.makeClear("..."),
 					index:3
@@ -634,13 +642,14 @@ Participants.prototype = {
 				Self.f_toggleButton(canAddResource, "buttonAddToResourcesList", Self.f_addResource);
 			});
 
-			this.participantsGridSmall.events.register("Activated", function(ids){
-				//participantsGridSmall.selection.click(participantsGridSmall.selection.getSelected());
-				if((Self.bDisableG == -1) && (ids[0].split('_')[0] == 'group')) {return;}
-				if(ids[0] == undefined) return;
+			this.participantsGridSmall.events.register("Activated", function(ids) {				
+				if (ids[0] == undefined && Self.bDisableG == -1 && 
+						ids[0].split('_')[0] == 'group') {
+					return;
+				}
 				Self.participantsGridSmall.selection.select(ids[0]);
 								
-				if(ids[0].split('_')[0] == 'resource')
+				if (ids[0].split('_')[0] == 'resource')
 					triggerEvent('addToResourceList');				
 				else	
 					triggerEvent('addToParticipantsList');				
@@ -718,7 +727,7 @@ Participants.prototype = {
 						text:_("Group Members"),				
 						index: 2,	
 						set: LiveGrid.defaultSet,					
-						clear: LiveGrid.makeClear("...")
+						clear: LiveGrid.makeClear("")
 					}
 				],new Selection());
 
@@ -745,7 +754,7 @@ Participants.prototype = {
 	},
 	openAddParticipantsWindow: function(bDisableG) {
 
-		if(this.opened)	return;
+		if (this.opened)	return;
 
 		var Self = this; //bind
 		
@@ -815,22 +824,12 @@ Participants.prototype = {
 			$("floatingdivParticipants-h-c").firstChild.data = _(this.title);
 		this.selectedParticipants = new Array();
 		this.selectedResource = new Array();
-		/*
-		if(this.selectedParticipantsGrid != null)
-		{			
-			this.selectedParticipantsGrid.enable(new Storage(0, []));
-		}
-		if(this.selectedRessourcesGrid != null)
-		{			
-			this.selectedRessourcesGrid.enable(new Storage(0, []));
-		}*/
 		this.enabled = true;
 		this.changedParticipants = new Array();
         this.changedResources = [];
-		if(!this.internalStorage2.groups)
+		if (!this.internalStorage2.groups) {
 			this.internalStorage2.groups = new Array();
-//		if(!this.setFullParticipants)
-//			triggerEvent('searchParticipants');
+		}
 		removeChildNodes($("selectedParticipants"));
 		removeChildNodes($("selectedResource"));
 		triggerEvent("searchParticipants");
@@ -845,11 +844,11 @@ Participants.prototype = {
 	},
 	
 	getParticipants: function(onlyInternal) {
-		if(!onlyInternal)
+		if(!onlyInternal) {
 			onlyInternal = false;
-
+		}
 		var parts = [];
-		if(this.internalStorage2.data.data){
+		if (this.internalStorage2.data.data){
 			for(i in this.internalStorage2.data.data){
 				if(this.internalStorage2.data.data[i][4] != null){
 					var tmpObj = {id : getID(this.internalStorage2.data.data[i][0]), display_name : this.internalStorage2.data.data[i][2]};
@@ -873,7 +872,7 @@ Participants.prototype = {
 						default:
 							break;
 					}
-					if(!parts[0])
+					if (!parts[0])
 						parts.push(tmpObj);
 					else if(tmpObj.id != parts[0].id && tmpObj.type){
 						if(tmpObj.type == 5){
@@ -886,7 +885,7 @@ Participants.prototype = {
 			}
 		}
 		//we need empty participants array!!!
-		//if(parts.length > 0) 
+		//if(parts.length > 0) 		
 		return parts;
 		
 		function getID(id){ return id = id.substring(id.indexOf("_")+1); }
@@ -907,12 +906,14 @@ Participants.prototype = {
 		}
 		return false;
 	},
+	
     searchParticipantsBlur : function(event, Self) {
         if (trimStr(Self.searchField.value).length == 0) {
             Self.searchField.value=Self.emptySearchText;
             Self.searchField.style.color="silver";
         }
     },
+    
     searchParticipantsEnter: function (event, Self){
         if (Self.searchField.value == Self.emptySearchText) {
             Self.searchField.value="";
@@ -923,6 +924,7 @@ Participants.prototype = {
             //$(liveGridDivResult).focus();
         }
     },
+    
     displayError: function(msg) {
     	$("participantsSearchError").style.display="";
     	$("participantsSearchError").getElementsByTagName("DIV")[0].firstChild.data=msg;
@@ -932,9 +934,7 @@ Participants.prototype = {
 	 * @private
 	 */	
 	searchParticipants: function() {
-    	
 		var Self = this; // bind
-		
 		this.searchpattern="";
         var inVal=this.searchField.value;
         if (trimStr(inVal).length == 0 ||
@@ -968,8 +968,10 @@ Participants.prototype = {
             this.searchpattern=inVal;
         }
         
-		//if no folder set, use "internal user" = folder 6
-		if(clickedItemParticipant == null || clickedItemParticipant == "")	clickedItemParticipant = 6;
+		//if no folder set, use the default
+        if(clickedItemParticipant == null || clickedItemParticipant == "") {
+            clickedItemParticipant = defaultParticipantFolder;
+        }
         var pattern = trimStr(this.searchpattern) ? this.searchpattern : "*";
         var patternObj = { pattern: pattern };
         var userPatternObj = { display_name: pattern, email1: pattern,
@@ -980,11 +982,14 @@ Participants.prototype = {
             userPatternObj.folder = clickedItemParticipant;
         }
 		
-		this.internalStorage = new Storage(0, [], "", 0, 0,  null, function(x){ return x[0] + "." + x[1];});		
+		this.internalStorage = new Storage(0, [], "", 0, 0,  null, 
+				function(x){ 
+					return x[0] + "." + x[1] + "." + x[5] || 0;
+				}
+		);		
 		
 		var oObj;
 		var aRequests = new Array();
-		
 		var oRequestObj = new Object();
 
 		if(this.showUser){
@@ -996,56 +1001,69 @@ Participants.prototype = {
 			oRequestObj['data'] = userPatternObj;
 			aRequests.push(oRequestObj);
 		}
-		if (this.showGroup && clickedItemParticipant == 6){		
+		if (this.showGroup && clickedItemParticipant == defaultParticipantFolder){		
 			var oRequestObj = new Object();		
 			oRequestObj['module'] = "group";
 			oRequestObj['action'] = "search";		
 			oRequestObj['data'] = patternObj;
-	
 			aRequests.push(oRequestObj);
 		}
-		if (this.showResource  && clickedItemParticipant == 6){
+		if (this.showResource  && clickedItemParticipant == defaultParticipantFolder){
 			var oRequestObj = new Object();		
 			oRequestObj['module'] = "resource";
 			oRequestObj['action'] = "search";		
 			oRequestObj['data'] = patternObj;
-			
 			aRequests.push(oRequestObj);		
 		}
-		
+
 		json.put(AjaxRoot + "/multiple?" + "session=" + session,aRequests,null,function (arg){
-			for(var indx=0;indx<aRequests.length;indx++)
-			{
+			for(var indx=0;indx<aRequests.length;indx++) {
 				switch (aRequests[indx].module){
 					case "contacts": 
 						var tmpArray = new Array();
-						for(var i = 0; i< arg[indx].data.length; i++){
-							var cb = arg[indx];
+						for (var i=0; i<arg[indx].data.length; i++){
 							// Add a user only when it is not a Distributionlist
 							// and either the user has a mail address or admin enabled
 							// displaying of participants without email.
-							var mailaddr = cb.data[i][3] || cb.data[i][6] || cb.data[i][7];
-							// distinguish between internal (i.e. users) and external contacts
-							if(!cb.data[i][4] && (mailaddr || configGetKey("participants.showWithoutEmail"))) {
-								if (cb.data[i][5] && cb.data[i][5] > 0) {
-									// internal contact (user)
-									tmpArray.push(["user_" + cb.data[i][0], cb.data[i][1], cb.data[i][2], mailaddr, cb.data[i][5]]);
-								} else {
-									// external contact
-									tmpArray.push(["contact_" + cb.data[i][0], cb.data[i][1], cb.data[i][2], mailaddr, cb.data[i][5]]);
-								}
-								// remember contact-user-relation of any seen contact
-								Self.contact2user[cb.data[i][0]] = cb.data[i][5];
+							var cb = arg[indx].data[i];
+							
+							// ignore distribution list
+							if (cb[4]) {
+								continue; 
 							}
+							
+							if (!cb[3] && !cb[6] && !cb[7] && configGetKey("participants.showWithoutEmail")) {
+								// contact do not have any e-mail address but config says show it anyway
+								// but we just want to have it once
+								tmpArray.push(["contact_" + cb[0], cb[1], cb[2], null, cb[5], 0]);
+							} else {
+								function isUser(user) {
+									return user && user > 0;
+								}
+							
+								// iterate through addresses
+								for (var ia=0; ia<3; ia++) {
+									var mailaddr = cb[[ 3, 6, 7][ia]];
+									// do not add if noaddress available
+									if (!mailaddr) continue; 									
+									tmpArray.push([( isUser(cb[5]) ? "user_" : "contact_") + cb[0], cb[1], cb[2], mailaddr, cb[5], ia]);
+									// we don't want all of the users addresses so we
+									// break after adding the first one
+									if (!Self.allEmailAddresses) break;
+								}		
+							}
+							
+							// remember contact-user-relation of any seen contact
+							Self.contact2user[cb[0]] = cb[5];							
 						}							
-						Self.internalStorage.append(tmpArray);					
+						Self.internalStorage.append(tmpArray);
 						break;
 					case "group": 
 						var tmpArray = new Array();		
 						for(var i = 0; i< arg[indx].data.length; i++){
 							var cb = arg[indx];		
 							var foldertype = (("comboboxProps" in window) && comboboxProps && (comboboxProps.getKey() == "m_mail")) ?	"m_mail" : "";									
-							tmpArray[i] = ["group_" + cb.data[i].id, 0, cb.data[i].display_name, "", foldertype];
+							tmpArray[i] = ["group_" + cb.data[i].id, 0, cb.data[i].display_name, "", foldertype, 0];
 						}
 						tmpArray.sort(function(a,b){
 							if (a[2] && b[2]) 
@@ -1059,7 +1077,7 @@ Participants.prototype = {
 						var tmpArray = new Array();							
 						for(var i = 0; i< arg[indx].data.length; i++){
 							var cb = arg[indx];			
-							tmpArray[i] = ["resource_" + cb.data[i].id, 0, cb.data[i].display_name, ""];
+							tmpArray[i] = ["resource_" + cb.data[i].id, 0, cb.data[i].display_name, "", 0, 0];
 						}
 						tmpArray.sort(function(a,b){
 							if (a[2] && b[2])
@@ -1075,34 +1093,29 @@ Participants.prototype = {
 			Self.enable_small_grid(Self.internalStorage);
 		});
 	},
+	
 	enable_small_grid : function (storage){
-		//$("addParticipantsTableHeader").appendChild(this.temp_storage_head);
-//		if(this.temp_storage && this.temp_storage_parent)
-//			this.temp_storage_parent.appendChild(this.temp_storage);			
 		this.participantsGridSmall.enable(storage);		
-		if(this.participantsGridSmall && this.participantsGridSmall.selection)
+		if (this.participantsGridSmall && this.participantsGridSmall.selection) {
 			this.participantsGridSmall.selection.reset();
+		}
 	},
+	
 	disable_small_grid : function (){
-//		this.temp_storage = this.participantsGridSmall.heightDiv;
-//		this.temp_storage_parent = 	this.participantsGridSmall.heightDiv.parentNode;		
-	//	removeChildNodes($("addParticipantsTableHeader"));
-//		this.participantsGridSmall.heightDiv.parentNode.removeChild(this.participantsGridSmall.heightDiv);
 		this.participantsGridSmall.disable();		
 	},
+	
 	/**
 	 * @private
 	 */	
 	closeParticipantsWindowOK: function() {
-		
 		var Self = this; // bind
-		
 		this.opened = false;
 		
         if ($("disable_background_window")) {
         	var childs = $("disable_background_window").childNodes;
         	var closeall=true;
-		    for(var i=0;i<childs.length;i++) {
+		    for (var i=0;i<childs.length;i++) {
 		        if(childs[i].tagName && childs[i].tagName == "DIV") {
 		            if(childs[i].style.display && childs[i].style.display != "none") {
 		                closeall=false;
@@ -1131,7 +1144,7 @@ Participants.prototype = {
 		// copy selected contacts, groups, and resources
 		// resources first (higher priority)
 		
-		if(this.selectedResource && this.selectedResource.length > 0) {
+		if (this.selectedResource && this.selectedResource.length > 0) {
 			// loop selected resources
 			for(var i = 0; i < this.selectedResource.length; i++) {
 				var resource = parseItem(this.selectedResource[i]);
@@ -1139,10 +1152,10 @@ Participants.prototype = {
 				switch (resource.type) {
 					case "user":
 						var user_as_contact = parseItem(
-							"contact_" + resource.id + "." + resource.folder
+							"contact_" + resource.id + "." + resource.folder + ".0"
 							);
 						var contact_as_resource = parseItem(
-							"resource_" + this.contact2user[resource.id] + ".0"
+							"resource_" + this.contact2user[resource.id] + ".0.0"
 							);
 						// not in grid?
 						if ( !inGrid(contact_as_resource.key) ) {
@@ -1180,52 +1193,6 @@ Participants.prototype = {
 				columns: ["display_name", "email1", "email2", "email3", "internal_userid"]
 			};
 		
-		// contacts / groups in second run
-		if (this.selectedParticipants && this.selectedParticipants.length > 0) {
-			// loop selected contacts
-			for (var i = 0; i < this.selectedParticipants.length; i++) {
-				var participant = parseItem(this.selectedParticipants[i]);				
-				// distinguish type
-				switch (participant.type) {
-					case "user":
-						// no conflict with resource?						
-						var contact_as_resource = parseItem(
-								"resource_" + this.contact2user[participant.id] + ".0"
-								);
-						// not in grid?
-						var user_as_contact = parseItem(
-								"contact_" + participant.id + "." + participant.folder
-								);
-						if ( inGrid(contact_as_resource.key) || inGrid(user_as_contact.key) ) break;
-						// nobreak
-					case "contact":
-						// not in grid (neither as contact nor as resource)
-						if ( !inGrid(participant.key) ) {
-							// add contact
-							this.selContacts.push({
-								id: participant.id,
-								folder: participant.folder
-							});
-							collection_contact.objects.push({
-								module: "contacts",
-								id: participant.id,
-								folder_id: participant.folder
-							});
-						}
-						break;
-					case "group":
-						// not in grid?			
-						if ( !inGrid(participant.key) ) {
-							// add group
-							this.selGroups.push({ 
-								id: participant.id
-							});
-						}
-						break;
-				}
-			}
-		}
-
 		this.enabled = false;
 		
 		// fill grid now
@@ -1247,7 +1214,7 @@ Participants.prototype = {
 				var item = items[key];
 				tmpArray.push([
 				               "resource_" + item.id, 0, item.display_name, 
-				               _("not sent"), "", "", "resource"
+				               _("not sent"), "", "", "resource", 0, 0
 				               ]);
 				// add as changed
 				Self.changedParticipants.push({
@@ -1257,6 +1224,63 @@ Participants.prototype = {
 			}				
 			// add to grid
 			Self.internalStorage2.append(tmpArray);
+			
+			// contacts / groups in second run
+	        if (Self.selectedParticipants && Self.selectedParticipants.length > 0) {
+	            // loop selected contacts
+	            for (var i = 0; i < Self.selectedParticipants.length; i++) {
+	                var participant = parseItem(Self.selectedParticipants[i]);
+	                // distinguish type
+	                switch (participant.type) {
+	                    case "user":
+	                        // no conflict with resource?
+	                        var contact_as_resource = parseItem(
+	                                "resource_" + Self.contact2user[participant.id] + ".0.0"
+	                                );
+	                        // not in grid?
+	                        var user_as_contact = parseItem(
+	                                "contact_" + participant.id + "." + participant.folder + "." + participant.recurrence
+	                                );
+	                        if ( inGrid(contact_as_resource.key) || inGrid(user_as_contact.key) ) break;
+	                        // nobreak
+	                    case "contact":
+	                        // not in grid (neither as contact nor as resource)
+	                        if ( !inGrid(participant.key) ) {
+	                            // add contact
+	                            Self.selContacts.push({
+	                                id: participant.id,
+	                                folder: participant.folder,
+	                                recurrence: participant.recurrence,
+	                                email: participant.email
+	                            });
+	                            collection_contact.objects.push({
+	                                module: "contacts",
+	                                id: participant.id,
+	                                folder_id: participant.folder,
+	                                recurrence: participant.recurrence,
+	                                email: participant.email
+	                            });
+	                        }
+	                        break;
+	                    case "group":
+	                        // not in grid?         
+	                        if ( !inGrid(participant.key) ) {
+	                            // add group
+	                            Self.selGroups.push({ 
+	                                id: participant.id
+	                            });
+	                        }
+	                        break;
+	                }
+	            }
+	        }
+			
+			// fetch contacts via cache
+	        corewindow.OXCache.newRequest(
+	            null, "contacts", 
+	            corewindow.clone(collection_contact, window), // don't ask (IE7)
+	            null, cb_fetch_contacts
+	        );
 		});
 		
 		var cb_fetch_contacts = joint.add(function(data) {
@@ -1265,31 +1289,51 @@ Participants.prototype = {
 			for(i = 0; i < data.objects.length; i++) {
 				// shortcut
 				var item = data.objects[i];
+				// needed later to map email addresses
+				var map_item = collection_contact.objects[i];				
+				
 				// look for email address
 				item.email = item.email1 || item.email2 || item.email3;
 				// add
 				tmpArray.push([
 						        "contact_" + item.id, item.folder_id,
 					            item.display_name, _("not sent"), "",
-					            item.email, "contact", item.internal_userid
+					            item.email, "contact", item.internal_userid,
+					            (map_item.recurrence || 0)
 					            ]);
+				
+				var recurrence = 0, mail = item.email;
+				// really bad hack to provide ALL email addresses of a user
+				// recurrence is the number of the email [email1, email2 or email3]
+				if ( Self.allEmailAddresses ) {
+					recurrence = map_item.recurrence ? map_item.recurrence : 0;					
+					if (map_item.recurrence != 0) {
+						mail = item["email" + (parseInt(map_item.recurrence)+1)];
+					}
+				}
+				
 				// add as changed
 				if ( item.internal_userid && item.internal_userid > 0 ) {
 					// add as changed (internal user)
 					Self.changedParticipants.push({
-						"id": item.internal_userid, "display_name": item.display_name,
-						"mail": item.email, "type": 1
+						"id": item.internal_userid, 
+						"display_name": item.display_name,
+						"mail": mail, "type": 1, "recurrence": recurrence 
 					});
-				} else {
+				} else {					
 					// add as changed (external contact)
 					Self.changedParticipants.push({
-						"id": item.id, "display_name": item.display_name, 
-						"mail": item.email, "type": 5
+						"id": item.id, 
+						"display_name": item.display_name, 
+						"mail": mail, "type": 5, "recurrence": recurrence
 					});
 				}
 			}
 			// add to grid (via storage)
 			Self.internalStorage2.append(tmpArray);
+			
+			// fetch groups via cache
+	        internalCache.getGroups(flattenIds(Self.selGroups), cb_fetch_groups);
 		});
 		
 		var cb_fetch_groups = joint.add(function(items) {
@@ -1312,17 +1356,7 @@ Participants.prototype = {
 		});
 		
 		// fetch resources via cache
-		internalCache.getRessources(flattenIds(this.selResources), cb_resources);
-		
-		// fetch contacts via cache
-		corewindow.OXCache.newRequest(
-				null, "contacts", 
-				corewindow.clone(collection_contact, window), // don't ask (IE7)
-				null, cb_fetch_contacts
-				);
-		
-		// fetch groups via cache
-		internalCache.getGroups(flattenIds(this.selGroups), cb_fetch_groups);
+		internalCache.getResources(flattenIds(this.selResources), cb_resources);
 		
 		function flattenIds(objects) {
 			var ids = new Array();
@@ -1342,20 +1376,20 @@ Participants.prototype = {
 		
 		function parseItem(str) {
 			// use regular expression
-			var reg = /^([^\_]+)\_(\w+)\.(\w+)$/;
+			var reg = /^([^\_]+)\_(\w+)\.(\w+)\.(\w+)$/;
 			var matches = reg.exec(str);
-			return { key: matches[0], type: matches[1], id: matches[2], folder: matches[3] };
+			return { key: matches[0], type: matches[1], id: matches[2], folder: matches[3], recurrence: matches[4] };
 		}
-		
-		function getTyp(id){ return id.substring(0, id.indexOf("_")); }
-		function getID(id){ return id.substring(id.indexOf("_")+1, id.indexOf(".")); }
-		function getFolder(id){ return id.substr(id.indexOf(".") +1); }
 	},
 	
-	initalFillBigGrid: function(obj) {
+	initalFillBigGrid: function(obj, callback) {
 
 		if(this.initalFilled)
-			this.internalStorage2 = new Storage(0, [], "", 0, 0,  null, function(x){ return x[0] + "." + x[1];});
+			this.internalStorage2 = new Storage(0, [], "", 0, 0,  null, 
+					function(x) {
+						return x[0] + "." + x[1] + ".0";
+					}
+		);
 		if(!this.internalStorage2.groups)
 			this.internalStorage2.groups = new Array();
 			
@@ -1378,7 +1412,7 @@ Participants.prototype = {
 		this.tmpArrayGroup = new Array();
 		this.tmpArrayResource = new Array();			
 		
-		for(var k = 0; k < this.part.length; k++){
+		for(var k = 0; k < this.part.length; k++) {
 			switch(this.part[k].type){
 				case 1:
 					this.userToReq.push({id : this.part[k].id, type : 1});
@@ -1397,95 +1431,94 @@ Participants.prototype = {
 			}
 		}
 		
-		if(Self.userToReq.length > 0 ){
-			internalCache.getObjects(Self.userToReq, function(cb){
-				var count = 0;
-				for(i in cb){
-					var userstatus = "";
-					var message = ""
-					var folder = 0;
-					for(var j = 0; j < Self.users.length; j++){
-						if(Self.users[j].id == i){
-							folder = 6;
-							if(Self.users[j].confirmation > -1 && Self.users[j].confirmation < 4)
-								userstatus = _(Self.stati[Self.users[j].confirmation]);
-							if(Self.users[j].confirmmessage)
-								message = Self.users[j].confirmmessage;
-							break;
-						}
-					}
-					Self.tmpArrayContact[count++] = ["contact_" + cb[i].user_id, folder, cb[i].display_name, userstatus, message, "", "contact", i];
-					Self.internalStorage2.groups.push(false);
-				}
-				Self.tmpArrayContact.sort(function(a,b){
-					if (a[2] && b[2])
-						return a[2] < b[2] ? -1 : 1;
-					else
-						return -1;
-				});
-				Self.internalStorage2.append(Self.tmpArrayContact);
-			});
-		} 
-
-		if(Self.groupToReq.length > 0){
-
-			internalCache.getObjects(Self.groupToReq, function(cb){
-
-					var count = 0;
-					var tmpArray = new Array();
-					var toGetTmp = new Array();
-					for(i in cb){
-						for(k in cb[i].members){
-							toGetTmp[cb[i].members[k]] = cb[i].members[k];
-						}
-					}
-					var toGet = new Array();
-					for(var ho = 0; ho < toGetTmp.length; ho++){
-						if(toGetTmp[ho])
-							toGet.push({id : toGetTmp[ho], type : 1});
-					}
-					
-					internalCache.getObjects(toGet, function(cbObj){
-						for(t in cb){
-							Self.tmpArrayGroup.push(["group_" + cb[t].id, 6, cb[t].display_name, "", "", "", "group"]);
-//	   							      tmpArray.push(["group_" + cb.data[t].id, 0, cb.data[t].display_name, _("not sent"), "", "", "group"]);
-						//	Self.internalStorage2.groups.push({before: 0, after: cb[t].members.length});
-							Self.groupResolution["group_" + cb[t].id] = cb[t].members;
-							/*var countMember = 1;
-							for(bt in cb[t].members){							
-								var userstatus = "";
-								var message = "";
-								var btt = cb[t].members[bt]; 
-								for(var j = 0; j < Self.users.length; j++){
-									if(Self.users[j].id == btt){
-										if(Self.users[j].confirmation > -1 && Self.users[j].confirmation < 4)
-											userstatus = _(Self.stati[Self.users[j].confirmation]);
-										if(Self.users[j].confirmmessage)
-											message = Self.users[j].confirmmessage;
-									}
-								}
-								Self.tmpArrayGroup.push(["groupMember_" + btt, 0, cbObj[btt].display_name, userstatus, message, "", "groupMember", [count, cb[t].members.length-count++]]);
-								Self.internalStorage2.groups.push({before: countMember, after: cb[t].members.length-countMember});
-								countMember++;
-							}*/
-						}
-
-						Self.internalStorage2.append(Self.tmpArrayGroup);
-					});
-			});
+		var joint = new Join(function() {
+		    // mark as filled
+		    Self.initalFilled = true;
+		    // call back
+		    if (callback) callback();
+		});
+		
+		var outerJoin = joint.add(emptyFunction);
+        
+		// users
+		if(Self.userToReq.length > 0 ) {
+		    // define callback
+		    var user2reqCB = joint.add(function(cb) {
+	            var count = 0;
+	            for(i in cb){
+	                var userstatus = "";
+	                var message = ""
+	                var folder = 0;
+	                for(var j = 0; j < Self.users.length; j++){
+	                    if(Self.users[j].id == i){
+	                        folder = 6;
+	                        if(Self.users[j].confirmation > -1 && Self.users[j].confirmation < 4)
+	                            userstatus = _(Self.stati[Self.users[j].confirmation]);
+	                        if(Self.users[j].confirmmessage)
+	                            message = Self.users[j].confirmmessage;
+	                        break;
+	                    }
+	                }
+	                Self.tmpArrayContact[count++] = ["contact_" + cb[i].user_id, folder, cb[i].display_name, userstatus, message, "", "contact", i, 0];
+	                Self.internalStorage2.groups.push(false);
+	            }
+	            Self.tmpArrayContact.sort(function(a,b){
+	                if (a[2] && b[2])
+	                    return a[2] < b[2] ? -1 : 1;
+	                else
+	                    return -1;
+	            });
+	            Self.internalStorage2.append(Self.tmpArrayContact);
+	        });
+		    // go!
+			internalCache.getObjects(Self.userToReq, user2reqCB);
 		}
 		
-		if(Self.resourceToReq.length > 0){
-			internalCache.getObjects(Self.resourceToReq, function(cb){
-				var count = 0;
-				for(i in cb){
-					Self.tmpArrayResource[count++] = ["resource_" + i, 6, cb[i].display_name, "", "", "", "resource"];
-					Self.internalStorage2.groups.push(false);
-				}
-				Self.internalStorage2.append(Self.tmpArrayResource);
-			});
+		// groups
+		if(Self.groupToReq.length > 0) {
+		    // define callback
+	        var groupToReqCB = joint.add(function(cb) {
+
+	            var count = 0;
+	            var tmpArray = new Array();
+	            var toGetTmp = new Array();
+	            for(i in cb){
+	                for(k in cb[i].members){
+	                    toGetTmp[cb[i].members[k]] = cb[i].members[k];
+	                }
+	            }
+	            var toGet = new Array();
+	            for(var ho = 0; ho < toGetTmp.length; ho++){
+	                if(toGetTmp[ho])
+	                    toGet.push({id : toGetTmp[ho], type : 1});
+	            }
+	            
+	            internalCache.getObjects(toGet, function(cbObj){
+	                for(t in cb){
+	                    Self.tmpArrayGroup.push(["group_" + cb[t].id, 6, cb[t].display_name, "", "", "", "group"]);
+	                }
+
+	                Self.internalStorage2.append(Self.tmpArrayGroup);
+	            });
+	        });
+	        // go!
+			internalCache.getObjects(Self.groupToReq, groupToReqCB);
+		}
+
+        // resources
+		if (Self.resourceToReq.length > 0){
+		    // define callback
+	        var resourceToReqCB = joint.add(function(cb) {
+	            var count = 0;
+	            for(i in cb){
+	                Self.tmpArrayResource[count++] = ["resource_" + i, 6, cb[i].display_name, "", "", "", "resource"];
+	                Self.internalStorage2.groups.push(false);
+	            }
+	            Self.internalStorage2.append(Self.tmpArrayResource);
+	        });
+	        // go!
+			internalCache.getObjects(Self.resourceToReq, resourceToReqCB);
 		}
-		
 		
 		if(externalUser.length > 0){
 			var tmpArrayExternal = new Array();
@@ -1496,7 +1529,9 @@ Participants.prototype = {
 			}
 			Self.internalStorage2.append(tmpArrayExternal);
 		}
-		this.initalFilled = true;
+		
+		// complete join
+		outerJoin();
 	},
 	
 	enableTheGrid: function(){
@@ -1831,9 +1866,16 @@ ParticipantsSmall.prototype = Participants.prototype;
 
 var contactAddressbookTreeParticipantLoaded = false;
 var currentDivIdForAddressbook = "";
-var clickedItemParticipant = 6;
-
-//register("Loaded",initParticipantContent);
+var defaultParticipantFolder = corewindow.defaultParticipantFolder || 6;
+var clickedItemParticipant = corewindow.clickedItemParticipant;
+register("OX_Configuration_Loaded_Complete", function() {
+    corewindow.oMainFolderTree.checkGAL(function(GAL) {
+        defaultParticipantFolder = GAL ? 6 : configGetKey("folder.contacts");
+        if (clickedItemParticipant === undefined) {
+            clickedItemParticipant = defaultParticipantFolder;
+        }
+    });
+});
 
 
 function initParticipantContent() {
