@@ -245,9 +245,13 @@ MousePopup.prototype = extend(Popup, {
     },
 
     hide: function() {
-        Popup.prototype.hide.call(this);
-        MousePopup.active--;
-        this.unregisterHide();
+        // check if the pop-up is visible. otherwise MousePopup.active gets into
+        // an invalid state and hovers do not work any longer
+        if (this.isVisible) {
+            Popup.prototype.hide.call(this);
+            MousePopup.active--;
+            this.unregisterHide();
+        }
     },
 
     /**
