@@ -28,14 +28,8 @@
  * the DOM Event as parameter.
  */
 
-function SearchListAddressBook(searchstring, floatingpopupdiv, liveGridDivSearch, liveGridDivResult, divAddContact, searchField, moreFields) {
-	// hack to hide the global address book
-	// use this with care! will be removed with upcomming releases!
-	if (new Boolean(configGetKey("modules.contacts.hideGlobalAddressBook")) == true &&
-		configGetKey("modules.infostore.module") == false) {
-		clickedItem = configGetKey("folder.contacts");
-		this.setAllFolders = function(){ };
-	}
+function SearchListAddressBook(searchstring, floatingpopupdiv, liveGridDivSearch, liveGridDivResult, divAddContact, searchField, moreFields)
+{
 	var Self = this;
 	this.emptySearchText = _("Please enter your search");
 	this.searchField = searchField;
@@ -64,7 +58,10 @@ function SearchListAddressBook(searchstring, floatingpopupdiv, liveGridDivSearch
 	this.myAddedContacts = new AddedSearchContacts();
 	this.updateList = false;
 	this.tmpDistId = 210000000;
-	this.moreFields = moreFields || new Array();
+	this.moreFields = new Array();
+	
+	if(moreFields)
+	this.moreFields = moreFields;
 	this.method = "";
 	this.aFindedAddressboks = new Array();
 	this.recipientType = "to";	
@@ -165,7 +162,7 @@ SearchListAddressBook.prototype = {
 		if(!json)
 		var json = new JSON();
 		this.distrids = [];
-		json.put(AjaxRoot + "/contacts?action=search&session=" + refToMain.session + "&columns=1,500,555,556,557,524,602,592",
+		json.put(AjaxRoot + "/contacts?action=search&session=" + corewindow.session + "&columns=1,500,555,556,557,524,602,592",
 			Self.searchObject,
 			null,
 			function(findContactForDistrList) {	
@@ -551,7 +548,7 @@ SearchListAddressBook.prototype = {
 				index:1
 			}, {
 				text: _("E-Mail"),
-				sortable: true,
+				/* sortable: true, */
 				set: LiveGrid.defaultSet,
 				clear: LiveGrid.makeClear("..."),
 				index:2
@@ -672,11 +669,13 @@ AddedSearchContacts.prototype = {
 var contactAddressbookTreeLoaded = false;
 var treeAddressbookVisible = false;
 var newAddressbookFolderTree = null;
-var clickedItem = 6;
+var clickedItem = "";
 var currentDivIdForAddressbook = "";
 
 function addressbookFolderPath() {
-	//clickedItem = window.opener.configGetKey("folder.contacts");	
+    corewindow.oMainFolderTree.checkGAL(function(GAL) {
+        clickedItem = GAL ? 6 : corewindow.configGetKey("folder.contacts");
+    });
 	session = window.opener.session;
 	var folderViewSettingsNewContact = new Object();
 	var folderViewSettingsNewContactById = new Object();
