@@ -5,7 +5,7 @@ function ox_folder_cache(){
 	/* contains all folders which are stored hierarchically in storagecaches */
 	this.folders = {"root":{children:null,parent:null,oxfolder:null}};
 	var Self = this;
-	this.columns = "1,301,300,307,304,306,302,305,308,311,2,314,313,315";
+	this.columns = "1,301,300,307,304,306,302,305,308,311,2,314,313,315,3010";
 	this.fast_access = new Object();
 	this.timestamp = 0;
 }
@@ -29,26 +29,27 @@ ox_folder_cache.prototype = {
 			join_fn(Self.folders);			
 		} else {
 			var locJson = new JSON();		
-			locJson.get("/ajax/folders?action=root&columns="+this.columns+"&session="+session,null,
-									function(arg) {		
-											Self.folders["root"].children = {};
-											Self.timestamp = arg.timestamp;
-											for (var nfldr=0;nfldr<arg.data.length;nfldr++)
-											{											
-												Self.folders["root"].children[arg.data[nfldr][0]] = 
-																{oxfolder:new ox_folder(arg.timestamp,arg.data[nfldr]),parent:Self.folders["root"],
-																																		children:null};
-												Self.fast_access[Self.folders["root"].children[arg.data[nfldr][0]].oxfolder.data.id] = Self.folders["root"].children[arg.data[nfldr][0]];
-												if(oState && oState[arg.data[nfldr][0]])
-												{
-													Self.load_subfolders(arg.data[nfldr][0],Self.folders["root"].children[arg.data[nfldr][0]],
-																		oState[arg.data[nfldr][0]],join_param,bReplace);
-												}														
-											}		
-											join_fn(Self.folders);							
-										});		
+			locJson.get(AjaxRoot + "/folders?action=root&columns="+this.columns+"&session="+session,null,
+                function(arg) {		
+                    Self.folders["root"].children = {};
+                    Self.timestamp = arg.timestamp;
+                    for (var nfldr=0; nfldr<arg.data.length; nfldr++) {
+                        var id = arg.data[nfldr][0];
+                        var child = Self.folders.root.children[id] = {
+                            oxfolder: new ox_folder(arg.timestamp,
+                                                    arg.data[nfldr]),
+                            parent: Self.folders.root,
+                            children: null
+                        };
+                        Self.fast_access[child.oxfolder.data.id] = child;
+                        if(oState && oState[id]) {
+                            Self.load_subfolders(id, child, oState[id],
+                                                 join_param, bReplace);
+                        }														
+                    }		
+                    join_fn(Self.folders);							
+                });		
 		}
-		
 	},
 	
 	do_load_subfolders : function (nId,refer,oState,callback,bReplace){
@@ -63,6 +64,7 @@ ox_folder_cache.prototype = {
 	/*loads subfolders from server*/
 	load_subfolders : function (nId, refer, oState, join_param, bReplace) {
 		var Self = this;
+		
 		var join_fn = join_param.add(
 		      function (arg) {
 		          join_param.arg = arg;
@@ -77,58 +79,46 @@ ox_folder_cache.prototype = {
 			}					
 			join_fn(refer);		
 		} else {
-			var locJson = new JSON();
-			function fn_cb(arg) {      
-	            // if children loaded before server responsed
-	            if(refer.children != null && !bReplace) {
-	                join_fn(refer); 
-	                return;
-	            }
-	            refer.children = {};
-	            for (var nfldr=0; nfldr<arg.data.length; nfldr++) {	            	
-	            	
-	            	// hack to hide the global address book
-	            	// use this with care! will be removed with upcomming releases!
-	            	if (new Boolean(configGetKey("modules.contacts.hideGlobalAddressBook")) == true &&
-            			configGetKey("modules.infostore.module") == false &&
-	            		arg.data[nfldr][0] == 6) {
-	            		//arg.data[nfldr][5] = [{ bits:4, entity:0, group:false }];
-	            		//arg.data[nfldr][7] = false;
-  	            		if (arg.data.length == 1) {
-	            			refer.oxfolder.data.subfolders=false;
-	            			refer.children = null;
-	            			oMainFolderTree.nodes[oMainFolderTree.getDOMID(2)].hasChildren=false;
-	            			oMainFolderTree.nodes[oMainFolderTree.getDOMID(2)].setOpen(false);
-	            		}
-	            		continue;
-	            	}
-	            	
-	                refer.children[arg.data[nfldr][0]] = 
-                        { "oxfolder": new ox_folder(arg.timestamp,arg.data[nfldr]),
-                          "parent"  : refer,
-                          "children": null
-                        };
-	                var oldrefer = null;
-	                if (refer.oxfolder.data.id == configGetKey("folder.infostore") && Self.fast_access[arg.data[nfldr][0]] != undefined) {
-	                    refer.children[arg.data[nfldr][0]] = 
-	                        { "oxfolder": new ox_folder(arg.timestamp,arg.data[nfldr]),
-                              "parent"  : refer, 
-                              "children": Self.fast_access[arg.data[nfldr][0]].children
+			var callback = (function(nId, refer, oState, join_param, bReplace, join_fn) {
+			    return function(arg) {
+    	            // if children loaded before server responsed
+    	            if(refer.children != null && !bReplace) {
+    	                join_fn(refer); 
+    	                return;
+    	            }
+    	            refer.children = {};
+    	            if (nId == 2) Self.GALPresent = false;
+    	            for (var nfldr=0; nfldr<arg.data.length; nfldr++) {
+    	                var id = arg.data[nfldr][0];
+    	                if (id == 6) Self.GALPresent = true;
+    	                refer.children[id] = 
+                            { "oxfolder": new ox_folder(arg.timestamp, arg.data[nfldr]),
+                              "parent"  : refer,
+                              "children": null
                             };
-	                }
-	                    
-	                Self.fast_access[refer.children[arg.data[nfldr][0]].oxfolder.data.id] = refer.children[arg.data[nfldr][0]]; 
-	                if (oState && oState[arg.data[nfldr][0]]) {
-	                    Self.load_subfolders(arg.data[nfldr][0], refer.children[arg.data[nfldr][0]],
-                                             oState[arg.data[nfldr][0]], join_param, bReplace);
-	                }                                                   
-	            }
-	            join_fn(refer);                         
-	        }
+    	                var oldrefer = null;
+    	                if (refer.oxfolder.data.id == configGetKey("folder.infostore") && Self.fast_access[id] != undefined) {
+    	                	var child = Self.fast_access[id].children;
+    	                    refer.children[id] = 
+    	                        { "oxfolder": new ox_folder(arg.timestamp, arg.data[nfldr]),
+                                  "parent"  : refer, 
+                                  "children": (isEmpty(child) ? null : child) 
+                                };
+    	                }
+    	                    
+    	                Self.fast_access[refer.children[id].oxfolder.data.id] = refer.children[id]; 
+    	                if (oState && oState[id]) {
+    	                    Self.load_subfolders(id, refer.children[id],
+                                                 oState[id], join_param, bReplace);
+    	                }                                                   
+    	            }
+    	            join_fn(refer);
+    	        };
+			})(nId, refer, oState, join_param, bReplace, join_fn);
 	        
-			locJson.get("/ajax/folders?action=list&all=1"
+			(new JSON()).get(AjaxRoot + "/folders?action=list&all=1"
 			     + "&columns=" + this.columns 
-			     + "&parent=" + getUrlEncodedString(nId) + "&session=" + session, null, fn_cb);
+			     + "&parent=" + getUrlEncodedString(nId) + "&session=" + session, null, callback);
 		}
 	},
 	
@@ -175,61 +165,64 @@ ox_folder_cache.prototype = {
 		                 + '&session=' + session 
 		                 + '&id=' + getUrlEncodedString(nId) 
 		                 + '&columns=1,300';
-		var pathJson = new JSON();
 		
-		function cb_fn_path(arg) {
-			var oState = {};
-			var statetmp  = oState;
-			var bFoundFolder = false;
-			var oRefer;
-			/*
-			 * fixed bug, in this case is the requested folder a first level folder and it must be present
-			 * return the path
-			 */
-			if (arg.data.length <= 1) {
-				var join_fn = join_param.add(
-			        function (arg, arg2) {
-			            if (arg) join_param.arg = arg;
-			            if( arg2) join_param.arg2 = arg2;
-			        }
-				);		
-				join_fn(Self.fast_access[nId], arg.data);
-				return;
-			}
-			join_param.arg2 = arg.data;
-			for (var indx=(arg.data.length-1); indx>0; indx--) {
-				//found the last loaded node and load the rest
-				if (!bFoundFolder && Self.fast_access[arg.data[indx][0]] != undefined) {
-					oRefer = Self.fast_access[arg.data[indx][0]];
-				} else {
-					if (!bFoundFolder) {
-						nParentId = arg.data[indx][0];				
-					}
-					bFoundFolder = true;
-					statetmp[arg.data[indx][0]] = {};
-					statetmp = statetmp[arg.data[indx][0]];
-				}
-			}
-			var join_fn = join_param.add(
-			    function (arg, arg2) {
-			    	if (arg) join_param.arg = arg;
-			        if (arg2) join_param.arg2 = arg2;
-			    }
-			);				
-			//if node not found, load complete path
-			if (oRefer == undefined) {
-				join_param.count--;
-				Self.load_folders(oState, join_param, true);
-				
-			} else if(oRefer.children == null || oRefer.children != null && oRefer.children[nId] == undefined) {
-				join_param.count--;			
-				Self.load_subfolders(oRefer.oxfolder.data.id, oRefer, oState, join_param, (true && !bNOReplace));
-				
-			} else {
-				join_fn(oRefer.children[nId], arg.data);
-			}
-		}
-		pathJson.get(sAjaxRequest,null,cb_fn_path);
+		var callback = (function(nId, join_param, bNOReplace) {
+		    return function(arg) {
+		        
+    			var oState = {};
+    			var statetmp  = oState;
+    			var bFoundFolder = false;
+    			var oRefer;
+    			/*
+    			 * fixed bug, in this case is the requested folder a first level folder and it must be present
+    			 * return the path
+    			 */
+    			if (arg.data.length <= 1) {
+    				var join_fn = join_param.add(
+    			        function (arg, arg2) {
+    			            if (arg) join_param.arg = arg;
+    			            if( arg2) join_param.arg2 = arg2;
+    			        }
+    				);		
+    				join_fn(Self.fast_access[nId], arg.data);
+    				return;
+    			}
+    			join_param.arg2 = arg.data;
+    			for (var indx=(arg.data.length-1); indx>0; indx--) {
+    				//found the last loaded node and load the rest
+    				if (!bFoundFolder && Self.fast_access[arg.data[indx][0]] != undefined) {
+    					oRefer = Self.fast_access[arg.data[indx][0]];
+    				} else {
+    					if (!bFoundFolder) {
+    						nParentId = arg.data[indx][0];				
+    					}
+    					bFoundFolder = true;
+    					statetmp[arg.data[indx][0]] = {};
+    					statetmp = statetmp[arg.data[indx][0]];
+    				}
+    			}
+    			var join_fn = join_param.add(
+    			    function (arg, arg2) {
+    			    	if (arg) join_param.arg = arg;
+    			        if (arg2) join_param.arg2 = arg2;
+    			    }
+    			);				
+    			//if node not found, load complete path
+    			if (oRefer == undefined) {
+    				join_param.count--;
+    				Self.load_folders(oState, join_param, true);
+    				
+    			} else if(oRefer.children == null || oRefer.children != null && oRefer.children[nId] == undefined) {
+    				join_param.count--;			
+    				Self.load_subfolders(oRefer.oxfolder.data.id, oRefer, oState, join_param, (true && !bNOReplace));
+    				
+    			} else {
+    				join_fn(oRefer.children[nId], arg.data);
+    			}
+    		};
+		})(nId, join_param, bNOReplace);
+		
+		(new JSON()).get(sAjaxRequest, null, callback);
 	},
 	
 	/* updates all folders; fetches new subfolder if availible, removes deleted folder from cache */
@@ -266,18 +259,14 @@ ox_folder_cache.prototype = {
 						if (nFound != 0 && Self.fast_access[indx].parent.oxfolder && Self.fast_access[indx].parent.oxfolder.data.id != 10) {					
 							if (aRootNodes[Self.fast_access[indx].parent.oxfolder.data.id] == undefined) {
 								aRootNodes[Self.fast_access[indx].parent.oxfolder.data.id] = new Array();
-								aRootNodes[Self.fast_access[indx].parent.oxfolder.data.id].push({id:indx,type:nFound});
-							} else {
-								aRootNodes[Self.fast_access[indx].parent.oxfolder.data.id].push({id:indx,type:nFound});
 							}
+							aRootNodes[Self.fast_access[indx].parent.oxfolder.data.id].push({id:indx,type:nFound});
 							
 						} else if (nFound != 0) {					
 							if (aRootNodes[Self.fast_access[indx].oxfolder.data.id] == undefined) {
 								aRootNodes[Self.fast_access[indx].oxfolder.data.id] = new Array();
-								aRootNodes[Self.fast_access[indx].oxfolder.data.id].push({id:indx,type:nFound});
-							} else {
-								aRootNodes[Self.fast_access[indx].oxfolder.data.id].push({id:indx,type:nFound});
 							}
+							aRootNodes[Self.fast_access[indx].oxfolder.data.id].push({id:indx,type:nFound});
 						} else {
 							fn_traverse(refer.children[indx]);
 						}
@@ -360,7 +349,7 @@ ox_folder_cache.prototype = {
 			this.load_path(nId, 
 			     new Join(
 				     function () {
-				     	callback(this.arg);
+				    	 Self.get_folder(nId, callback);
 				     }
 				 ), true);
 		} else if (callback) {	
@@ -386,6 +375,7 @@ function ox_folder(timestamp, dataArray) {
 		this.data.subscribed = dataArray[11];		
 		this.data.capabilities = dataArray[12];
 		this.data.subscr_subflds = dataArray[13];
+		this.data["com.openexchange.publish.publicationFlag"] = dataArray[14];
 	}
 	
 	this.timestamp = timestamp;
