@@ -69,6 +69,7 @@ function cFolderTree(DOMNode, actionTree, enableDND,cache_param,state)
 	
 	this.nodes = {};
 	this.dashed = null;
+	this.GALCallbacks = [];
 }
 cFolderTree.prototype = {
 get_folder_path : function (nId,fn_callback){		
@@ -154,22 +155,28 @@ setSaveConfiguration : function (oReferObj)
 	this.saveConfObj = oReferObj;
 },	
 fetchAndGetFolders : function (afolders,cb_fn){
-	var aResult = new Object();
-	function exec_cb()
-	{
+	var aResult = {};
+	function exec_cb() {
 		cb_fn(aResult);
 	}
-	var join_all = new Join(exec_cb);		
+	// create join
+	var join_all = new Join(exec_cb);
+	// add outer join
 	var fn_join_outer = join_all.add();
-	for(var indx=0;indx<afolders.length;indx++)
-	{		
+	for(var indx=0; indx<afolders.length; indx++) {
+	    // create a wrapper here. otherwise indx might contain the wrong number
+	    // when the function is called.
+	    var wrapper = (function(index) {
+	        return function(arg) {
+	            aResult[afolders[index]] = arg;
+                fn_join_();
+	        };
+	    })(indx);
 		var fn_join_ = join_all.add();
-		this.cache.get_folder(afolders[indx],function (arg){
-															aResult[afolders[indx]] = arg;
-															fn_join_();
-														});														
+		// cache is of type "ox_folder_cache"
+		this.cache.get_folder(afolders[indx], wrapper);
 	}
-	fn_join_outer();	
+	fn_join_outer();
 },
 getVisibleImapFolders : function () {
 	var Self = this;
@@ -212,9 +219,31 @@ load : function (){
 	if(this.cache.folders.root.children == null)
 	{
 		this.cache.load_folders(this.state,new Join(function (){
-												Self.cache.events.trigger("initialized");
-												Self.load_view(this.arg.root,Self.tree);
-											}));	
+            if (Self.cache.GALPresent === undefined) {
+                (new JSON).get(AjaxRoot +
+                    "/folders?action=list&all=1&columns=1&parent=2&session=" +
+                    session, null, function(response) {
+                        Self.cache.GALPresent = false;
+                        for (var i = 0; i < response.data.length; i++) {
+                            if (response.data[i][0] == 6) {
+                                Self.cache.GALPresent = true;
+                                break;
+                            }
+                        }
+                        callGALCallbacks();
+                    });
+            } else {
+                callGALCallbacks();
+            }
+            function callGALCallbacks() {
+                for (var i = 0; i < Self.GALCallbacks.length; i++) {
+                    Self.GALCallbacks[i](Self.cache.GALPresent);
+                }
+                delete Self.GALCallbacks;
+            }
+            Self.cache.events.trigger("initialized");
+            Self.load_view(this.arg.root,Self.tree);
+		}));	
 	}
 	else
 	{
@@ -227,6 +256,22 @@ load : function (){
 		this.cache.events.register("Deleted",function (arg){Self.delete_node(arg)});
 	}
 },
+
+/**
+ * Waits until the availability of the global address list is determined, then
+ * calls the specified callback function.
+ * @param {Function} callback The callback function which is called with
+ * a single boolean parameter which is true if the global address list is
+ * available and false otherwise.
+ */
+checkGAL: function(callback) {
+    if (this.cache.GALPresent === undefined) {
+        this.GALCallbacks.push(callback);
+    } else {
+        callback(this.cache.GALPresent);
+    }
+},
+
 getFolderID : function (sId){
 	var aSplited = sId.split('$');
 	var sFolderID = '';
@@ -305,17 +350,7 @@ load_view : function (oFolders,attPoint,bReplace,bRootOnly){
 		{
 			continue;
 		}
-		var sNodeDOMID = this.getDOMID(OXFolder.data.id);
-		if(OXFolder.data.module == 'infostore' &&  oFolders.oxfolder && (oFolders.oxfolder.data.id == 1 ||
-										attPoint.link)) //children from link are links too.
-		{
-			sNodeDOMID += '$link';
-			bLink = true;
-		}
-		else
-		{
-			bLink = false;				
-		}		
+		var sNodeDOMID = this.getDOMID(OXFolder.data.id);	
 		var bEnabled = true;
 		if(OXFolder.data.module=='mail') {
 			bEnabled = (getPermAsString(false, OXFolder.data.own_rights, 7).bit>=2)
@@ -332,12 +367,12 @@ load_view : function (oFolders,attPoint,bReplace,bRootOnly){
 		if (oFolders.children[nFldr].parent.oxfolder) {
 			var sImageSRC = getIconImagePath(oFolders.children[nFldr].parent.oxfolder.data.id,OXFolder.data.id,
 																				OXFolder.data.module,
-																				bLink,bEnabled,
+																				false,bEnabled,
 																				OXFolder.data.standard_folder);	
 		} else {																						
 			var sImageSRC = getIconImagePath(oFolders.children[nFldr].parent,OXFolder.data.id,
 																				OXFolder.data.module,															
-																				bLink,bEnabled,
+																				false,bEnabled,
 																	OXFolder.data.standard_folder);
 		}
 
@@ -363,7 +398,14 @@ load_view : function (oFolders,attPoint,bReplace,bRootOnly){
                  replacedname ? addTranslated(replacedname)
                               : OXFolder.data.title,
                  sNodeDOMID, {}, sShowUnread);
-		oNode.link = bLink;
+		var f = OXFolder.data;
+		var me = configGetKey("identifier")
+        if (   f["com.openexchange.publish.publicationFlag"]
+            ||    f.permissions.length > 1
+               && (f.type == 1 || f.module == "infostore" && f.created_by == me))
+        {
+            oNode.setDecoration([getFullImgSrc("img/folder/shared.png")]);
+        }
 		if (OXFolder.data.id == 1) {
 			if (configGetKey("modules.folder.read_create_shared_folders")) {
 				oNode.div.quickinfo="Private folders are under your control and by default no other user has access to your private folders. You may share your private folders to let others look at your private folders. In case you grant other users modification permission, such changes will be done under your name.";/*i18n*/
@@ -384,8 +426,6 @@ load_view : function (oFolders,attPoint,bReplace,bRootOnly){
 			oNode.div.quickinfo="The UserStore includes all shared personal InfoStore folders from other users. This means, if an user shared his InfoStore folder or the subfolder structure, the user can see the objects.";/*i18n*/
 		} else if( OXFolder.data.id == 14) {
 			oNode.div.quickinfo="Other InfoStore folders contain shared subfolders from parent folders that are not accessible to you.";/*i18n*/
-		} else if (oNode.link) {
-			oNode.div.quickinfo="The My InfoStore folder is a copy of the personal UserStore folder at the InfoStore section.";/*i18n*/
 		}
 		
 		if (parseInt(OXFolder.data.unread) > 0 && this.show_new_messages) {
@@ -516,26 +556,16 @@ expand_node : function (oNode,fn_opt){
 	}
 	
 },
-update_sub_tree : function(ofolder){
+
+update_sub_tree : function(ofolder) {
 	var Self = this;
 	var oSubRoot = this.nodes[this.getDOMID(ofolder.oxfolder.data.id)];
 	if(ofolder == undefined || oSubRoot == undefined)
 		return;
 	this.load_view(ofolder,oSubRoot,true);
-	var sLinkId = this.getDOMID(ofolder.oxfolder.data.id) + '$link';
-	
-	var childrennodes = false;
-	for(var i in this.nodes[sLinkId])
-	{
-		childrennodes = true;
-		break;
-	}
-	if(this.nodes[sLinkId] != undefined && childrennodes)	
-	{		
-		this.load_view(ofolder,this.nodes[sLinkId],true);
-	}
 	this.tree.setState(this.state);
 },
+
 delete_node : function (folderID) {
 	if (oUnreadCounterStorage) {
 		oUnreadCounterStorage.unregister(folderID);
@@ -838,12 +868,12 @@ function folderServerMove(sourceFolder, Folder, targetFolder, bOnlyServerMove, f
 			folderTreeFolderToMove = -1;
 			if (Folder.oxfolder.data.module == "mail") {
 				oMainFolderTree.update(null, true, function() {
-					   oMainFolderTree.display_folder(targetFolder.oxfolder.data.id);
-                    });
+					oMainFolderTree.display_folder(targetFolder.oxfolder.data.id);
+                });
 			} else {
 				oMainFolderTree.update(null, false, function() {
-					   oMainFolderTree.display_folder(Folder.oxfolder.data.id);
-					});
+					oMainFolderTree.display_folder(Folder.oxfolder.data.id);
+				});
 			}
 			if (fn_cb_fm) fn_cb_fm();
 		}
