@@ -706,20 +706,13 @@ function saveFolder(fn_opt) {
 				configfolder = sId;
 				bNew = false;				
 				triggerEvent("OX_New_Info",4,_("Your settings have been saved"));				
-				oConfigFolderTree.cache.get_folder(configparentfolder,function (oFolder){					
-					oMainFolderTree.update(null,(oFolder.oxfolder.data.module=="mail" || String(oFolder.oxfolder.data.id).match(/^default(\d+)?/)),function ()
-					{
-						configparentfolder = -1;
-						if(currentpath[0]== "configuration" && currentpath[1]== "folder")
-						{
-							triggerEvent("OX_Switch_View","configuration/folder/overview");	
-							unLoadFolderProps();
-							loadFolderProps();					
-						}
+				oConfigFolderTree.cache.get_folder(configparentfolder, 
+					function (oFolder) {					
+						oMainFolderTree.update(null, 
+								(oFolder.oxfolder.data.module=="mail" || String(oFolder.oxfolder.data.id).match(/^default(\d+)?/)), 
+								emptyFunction);
 					}
-					);		
-
-				});
+				);
 			}			
 			if (fn_opt) fn_opt();
 		}
@@ -734,14 +727,7 @@ function saveFolder(fn_opt) {
 					activefolder = (oFolder.oxfolder.data.module=="mail")?arg.data:configfolder;	
 					configfolder = activefolder;						
 					triggerEvent("OX_New_Info",4,_("Your settings have been saved"));						
-					oMainFolderTree.update(null,(oFolder.oxfolder.data.module=="mail"),function ()
-					{
-						if(currentpath[0]== "configuration" && currentpath[1]== "folder") {
-							triggerEvent("OX_Switch_View","configuration/folder/overview");	
-							unLoadFolderProps();
-							loadFolderProps();					
-						}
-					});	
+					oMainFolderTree.update(null, (oFolder.oxfolder.data.module=="mail"), emptyFunction);	
 				} else {				
 					oMainFolderTree.update();															
 					disableNodeActions = false;		
