@@ -103,7 +103,7 @@ function loadFolderTree(stateTree,nSelectedIdStorage) {
         function() {           
             var myfolder=oMainFolderTree.get_folder_by_node_id(
                 this.getContext().data.id);
-            if (myfolder && myfolder.oxfolder.data) {           
+            if (myfolder && myfolder.oxfolder.data) {       
                 infostore_sendLink([{ data: {
                     folder_id: myfolder.oxfolder.data.id,
                     module: myfolder.oxfolder.data.module
@@ -111,30 +111,34 @@ function loadFolderTree(stateTree,nSelectedIdStorage) {
             }
         });
     menu.addItem(link);
-
-    var import_data = new MenuItem("Import",
-			function() { 
-    			importFolderDestination = oMainFolderTree.get_folder_by_node_id(this.getContext().data.id);
-    			triggerEvent("OX_Switch_View","configuration/import");
-    		});
-    menu.addItem(import_data);
-    
-	var export_submenu = new PopupMenu();
-    var export_submenu_vcard = new MenuItem("vCard", 
-            	function() { exportContacts(this.getContext().data, "VCARD");
-            	});
-   	export_submenu.addItem(export_submenu_vcard);
-
-    var export_submenu_csv = new MenuItem("CSV",
-    			function() { exportContacts(this.getContext().data, "CSV");
-    		});
-   	export_submenu.addItem(export_submenu_csv);
-
-    var export_contact = new MenuItem("Export", /*i18n*/
-    		export_submenu);
-    menu.addItem(export_contact);
     
+    // "Extended" (submenu)
+    extended_folder_menu = new PopupMenu();
+        // Import
+        var import_data = new MenuItem("Import",
+    			function() { 
+        			importFolderDestination = oMainFolderTree.get_folder_by_node_id(this.getContext().data.id);
+        			triggerEvent("OX_Switch_View","configuration/import");
+        		});
+        extended_folder_menu.addItem(import_data);
+        // Export (Submenu)
+    	var export_submenu = new PopupMenu();
+            var export_submenu_vcard = new MenuItem("vCard", 
+                    	function() { exportContacts(this.getContext().data, "VCARD");
+                    	});
+           	export_submenu.addItem(export_submenu_vcard);
+            var export_submenu_csv = new MenuItem("CSV",
+            			function() { exportContacts(this.getContext().data, "CSV");
+            		});
+           	export_submenu.addItem(export_submenu_csv);
+        var export_contact = new MenuItem("Export", /*i18n*/
+                export_submenu);
+        extended_folder_menu.addItem(export_contact);
+    // add to menu
+    var extended = new MenuItem("Extended" /*i18n*/, extended_folder_menu);
+    menu.addItem(extended);
     
+    // separator
     menu.addItem(new MenuSeparator());
     
     var del = new MenuItem("Delete", /*i18n*/
@@ -186,7 +190,7 @@ function loadFolderTree(stateTree,nSelectedIdStorage) {
                                  && String(oxfolder.id).match(/^default(\d+)?/))
                 ? "mail" : oxfolder.module;
             subscribe.setVisible(oxfolder.module == "mail");
-            link.setEnabled(oxfolder.own_rights & (127 << 7) && oxfolder.module != "mail");
+            link.setEnabled(oxfolder.own_rights & (127 << 7) && oxfolder.module != "mail" && ("infostore_sendLink" in window));
             link.setVisible(!(oxfolder.module == "mail" || (oxfolder.module == "system" && this.context.type == "mail")));
             del.setEnabled(deleteAllowed(folder.oxfolder));
             rename.setEnabled(renamingAllowed(folder.oxfolder));
@@ -199,10 +203,14 @@ function loadFolderTree(stateTree,nSelectedIdStorage) {
                             && oxfolder.own_rights >> 21 & 127);
             sep1.setVisible(empty.visible);
             
-            import_data.setEnabled((oxfolder.own_rights & 127) >= 2);
-            import_data.setVisible(oxfolder.module == "calendar" || oxfolder.module == "contacts" || oxfolder.module == "tasks");            
-            export_contact.setEnabled(oxfolder.type != 3 && oxfolder.module == "contacts");
-            export_contact.setVisible(!(oxfolder.module != "contacts" || oxfolder.type == 3));
+            import_data.setEnabled(
+                    (oxfolder.own_rights & 127) >= 2 && 
+                    (oxfolder.module == "calendar" || oxfolder.module == "contacts" || oxfolder.module == "tasks")
+            );
+            export_contact.setEnabled(
+                    oxfolder.type != 3 && oxfolder.module == "contacts" && 
+                    !(oxfolder.module != "contacts" || oxfolder.type == 3)
+            );
         } else {
             new_folder.setEnabled(false);
             subscribe.setEnabled(false);
