@@ -61,10 +61,8 @@ register ("OX_Timestamp_Changed_By_Attach",fn_changeTimstamp);
 
 function initNewTaskLoaded() {
 	var themeStyle = corewindow.oxThemeStyle || { name: "Default", path: "default" };
-			
-	loadCSSFileForNewWindow("themes/"+themeStyle.path+"/css/global.css");
+    removeCSSFilesForNewWindow(themeStyle.path);
 	loadCSSFileForNewWindow("themes/"+themeStyle.path+"/css/popup.css");
-	loadCSSFileForNewWindow("themes/"+themeStyle.path+"/css/bgimages.css");
 }
 
 function fn_changeTimstamp(newTStamp)
@@ -260,7 +258,6 @@ function newTaskOnload() {
 	config = window.opener.config;
 	internalCache = window.opener.internalCache;
 	check0GroupDisplayName = window.opener.check0GroupDisplayName;
-	refToMain = window.opener;	
 	initParticipantsGrid();
 	activefolder = url["folder"];
 	
@@ -703,6 +700,9 @@ function updateTask() {
 						}
 					}
 					corewindow.OXTaskMapping.editObjects([oldObject],newObject);
+					if (tmp_attachmentDialog.attach_changed()) {
+						corewindow.triggerEvent("OX_Quota_Update");
+					}
                     fn_cb();
 				}
 				if (tmp_attachmentDialog.attach_changed()) 
@@ -753,6 +753,9 @@ function writeNewTask() {
 						}
 					}
 					corewindow.OXTaskMapping.createObject(newObject);
+					if (tmp_attachmentDialog.attach_changed()) {
+						corewindow.triggerEvent("OX_Quota_Update");
+					}
                     fn_cb();
 				}
 				if (tmp_attachmentDialog.attach_changed()) 
