@@ -58,13 +58,13 @@ function() {
     register("Loaded",init_Tasks);
     
     register("OX_Tasks_Switch_Split_Detail",function(param) { 
-    	menuswitchTaskDetail(param) 
+        menuswitchTaskDetail(param) 
     });
     
     function init_Tasks() {
-    	tasksFolderPath = new FolderPath("tasks");
-    	tasksTabsList = new Array('tasktab1','tasktab2', 
-    	       'tasktab4');
+        tasksFolderPath = new FolderPath("tasks");
+        tasksTabsList = new Array('tasktab1','tasktab2', 
+               'tasktab4');
         tasksPanelsList = new Array('taskpanel1','taskpanel2',
                'taskpanel4');
         tasksEventList = new Array(
@@ -75,8 +75,8 @@ function() {
         );        
     }
     registerView("tasks",
-    		null,
-    		null,
+            null,
+            null,
             function() {
                 if (tmpDetailRequest) {
                     OXCache.unregister(tmpDetailRequest.uniqueName);
@@ -102,13 +102,13 @@ function() {
             if (gridlist.collection) gridlist.disable();
             unregister("OX_New_Search", taskSearch);
          },
-		 function() { 
-		    hideNode("taskslist");  
-		    $("taskslist").style.display="none";
+         function() { 
+            hideNode("taskslist");  
+            $("taskslist").style.display="none";
             unregister("OX_Delete_Search", taskSearchDelete);
             unregister("OX_New_Search", taskSearch);
          },
-		 null
+         null
     );
     
     registerView("tasks/list",
@@ -116,11 +116,10 @@ function() {
             showNode("taskslist");  
             $("taskslist").style.display=""; 
         }, 
-        function() {    	 	
+        function() {            
             var criteria= { "folder_id" : activefolder };
             gridlist.disablehover=!configGetKey("gui.effects.hover.tasks");
-            gridlist.enable(criteria);            
-            tasksFolderPath.drawDOMNode("taskoflistview", activefolder);
+            gridlist.enable(criteria);
             tasks_setFocus(gridlist);
             register("OX_Print",printTasks);
             register("OX_New_Search", taskSearch);
@@ -129,7 +128,7 @@ function() {
             register("OX_Task_MarkAsDone", tasks_markAsDone);
          }, 
          function() {
-         	tasksFolderPath.clear();
+            tasksFolderPath.clear();
             if (gridlist) gridlist.disable();
             unregister("OX_Add_Flag", fn_add_Tag_tasks);    
             unregister("OX_New_Search", taskSearch);
@@ -143,16 +142,15 @@ function() {
             $("taskslist").style.display="none";
          },
          function(changeFolder) { 
-        	if (changeFolder != undefined) {
-	            var criteria = { "folder_id" : activefolder };
-	            gridlist.disablehover=!configGetKey("gui.effects.hover.tasks");
-	            gridlist.enable(criteria);	            
-	            tasksFolderPath.drawDOMNode("taskoflistview", activefolder);
-	            tasks_setFocus(gridlist);
-        	}
+            if (changeFolder != undefined) {
+                var criteria = { "folder_id" : activefolder };
+                gridlist.disablehover=!configGetKey("gui.effects.hover.tasks");
+                gridlist.enable(criteria);
+                tasks_setFocus(gridlist);
+            }
          }
     );
-	
+    
     registerView("tasks/split",
             function() {
                 showNode("taskssplit");  
@@ -164,11 +162,15 @@ function() {
                 gridsplit.disablehover=!configGetKey("gui.effects.hover.tasks");
                 gridsplit.enable(criteria);                
                 // reselect id if it's a direct link for example
-                if (activeTaskId.length && activeTaskId[0].directLink && activeTaskId[0].id) {
-                	delete(activeTaskId[0].directLink);
+                if (activeTaskId.length && activeTaskId[0].directLink &&
+                    activeTaskId[0].id)
+                {
+                    delete(activeTaskId[0].directLink);
                     gridsplit.selection.selectIDs([ Key.createfromObject(activeTaskId[0]) ]);
+                } else {
+                    gridsplit.selection.selectIDs(
+                        gridsplit.selection.getSelected());
                 }
-                tasksFolderPath.drawDOMNode("taskofsplitview", activefolder);
                 expandTaskSplitHeader(configGetKey("gui.tasks.fullsplitheader"));
                 
                 register("OX_Print",printTasks);
@@ -182,7 +184,7 @@ function() {
                 triggerEvent("Confirmation_Changed", 0);
              }, 
              function() {
-             	tasksFolderPath.clear();          
+                tasksFolderPath.clear();          
                 if (gridsplit) gridsplit.disable();
                 gridsplitTask = false;
                 if (tmpDetailRequest) {
@@ -197,20 +199,20 @@ function() {
                 unregister("OX_Delete_Search", taskSearchDelete);
                 unregister("OX_Task_MarkAsDone", tasks_markAsDone);
              },
-             function() { 
+             function() {
+                latestRenderedTask = null
                 hideNode("taskssplit");  
                 $("taskssplit").style.display="none";
              },
              function(changeFolder) {
-				if (changeFolder != undefined) {
-				    var criteria= { "folder_id" : activefolder };
-					gridsplit.disablehover=!configGetKey("gui.effects.hover.tasks");
-					gridsplit.enable(criteria,false);
-					tasksFolderPath.drawDOMNode("taskofsplitview", activefolder);
-					tasks_setFocus(gridlist);
-					// update confirm button
-					triggerEvent("Confirmation_Changed", 0);
-				}
+                if (changeFolder != undefined) {
+                    var criteria= { "folder_id" : activefolder };
+                    gridsplit.disablehover=!configGetKey("gui.effects.hover.tasks");
+                    gridsplit.enable(criteria,false);
+                    tasks_setFocus(gridlist);
+                    // update confirm button
+                    triggerEvent("Confirmation_Changed", 0);
+                }
              }
     );
     
@@ -270,23 +272,23 @@ function() {
 
     function taskdetail_change_Confirm() {
         var taskconfirm=new AcceptDeny(true);
-        taskconfirm.showConfirmation(new AcceptDenyObject("tasks", completedetailtask));
+        taskconfirm.showConfirmation([new AcceptDenyObject("tasks", completedetailtask)]);
     }
     
     function cb_selection_changed() {
-    	// get current task to prevent double selection (-> double rendering)
+        // get current task to prevent double selection (-> double rendering)
         var currentTask = activeTaskId.length > 0 ? activeTaskId[0].id : null;
         if (currentTask == latestRenderedTask) return;
-       	// remember current task
+        // remember current task
         latestRenderedTask = currentTask;
         // now process selection
-    	if (!tasksSelection2.getSelected().length) return;
-    	tasks_setFocus(gridsplit)         
+        if (!tasksSelection2.getSelected().length) return;
+        tasks_setFocus(gridsplit)         
         fn_tasks_getDetails(tasksSelection2.getSelected());        
     }
     
     function tasks_setFocus(grid) {
-    	if (grid && grid.collection && tasksSelection2.getSelected().length) {
+        if (grid && grid.collection && tasksSelection2.getSelected().length) {
             var index = grid.collection.getIndex(tasksSelection2.getSelected()[0]);
             grid.focus = index ? index-1 : 0;
             grid.showFocus();
@@ -294,7 +296,7 @@ function() {
     }
     
     function cb_object_changed() {
-        fn_tasks_getDetails(tasksSelection2.getSelected(), true);
+        (tasksSelection2.getSelected(), true);
     }
     
     function switchToTaskStdView() {
@@ -326,18 +328,14 @@ function() {
     function taskSearchDelete() {
         if (activemodule != "tasks") { return; }
         var criteria= { "folder_id" : activefolder };
-        if (currentpath2[1] == "split") {
-        	gridsplit.searchActive=false;
-        	gridsplit.disablehover=!configGetKey("gui.effects.hover.tasks");
-        	gridsplit.enable(criteria);
-        	tasksFolderPath.drawDOMNode("taskofsplitview", activefolder);
-                
-        } else if(currentpath2[1] == "list") {
-        	gridlist.searchActive=false;
-        	gridlist.disablehover=!configGetKey("gui.effects.hover.tasks");              
-        	gridlist.enable(criteria);
-        	tasksFolderPath.drawDOMNode("taskoflistview", activefolder);
-        }     
+        var split = gridsplit, view = "taskofsplitview";
+        if(currentpath2[1] == "list") {
+            split = gridlist, view = "taskoflistview";
+        }    
+        split.searchActive=false;
+        split.disablehover=!configGetKey("gui.effects.hover.tasks");
+        split.enable(criteria);
+        tasksFolderPath.drawDOMNode(view, activefolder);
     }
     
     var gridlist, gridsplit, gridatt;
@@ -381,14 +379,14 @@ function() {
     });
         
     function tasks_markAsDone() {
-    	function cb_changes(object) {
-    		if (object["percent_completed"] && object["percent_completed"] == 100) {
-    			return null;
-    		} else {
-    			return { "percent_completed": 100, "status": 3 };
-    		}
-    	}    	
-    	tasks_udpateTasks(tasksSelection2.getSelected(), ["percent_completed"], cb_changes);
+        function cb_changes(object) {
+            if (object["percent_completed"] && object["percent_completed"] == 100) {
+                return null;
+            } else {
+                return { "percent_completed": 100, "status": 3 };
+            }
+        }       
+        tasks_udpateTasks(tasksSelection2.getSelected(), ["percent_completed"], cb_changes);
     }
     
     /**
@@ -403,66 +401,68 @@ function() {
      * all selected items would be updated with the last changes!
      */
     function tasks_udpateTasks(ids, columns, cb_changes) {
-    	if (ids == undefined || !ids.length) return false;
+        if (ids == undefined || !ids.length) return false;
         var collection={};
         collection.objects=ids;
         collection.columns=columns;
         OXCache.newRequest(null,"tasks",collection,null,
             function(daten) {
-            	if (!daten.objects) return;            	
-            	var fPutData = new Array(); 
-            	var fOCData = null;           	
+                if (!daten.objects) return;             
+                var fPutData = new Array(); 
+                var fOCData = null;             
                 for (var i in daten.objects) {
-                	var object = daten.objects[i];
+                    var object = daten.objects[i];
                     var timestamp = object["timestamp"] || 0;
                     changes = cb_changes(object);                    
                     if (!changes) continue ; 
                     fOCData = changes;               
                     fPutData.push({
-                    	"action": "update",
-                    	"module": "tasks",
-                    	"folder": object["folder_id"],
+                        "action": "update",
+                        "module": "tasks",
+                        "folder": object["folder_id"],
                         "id": object["id"],
                         "timestamp": object["timestamp"] || 0,
-                    	"data" : fOCData               	
+                        "data" : fOCData                
                     });
                 }
                 if (!fPutData.length || fOCData == null) return;
                 new JSON().put(AjaxRoot + "/multiple?session=" + session, 
                        fPutData, null,
                        function(cb) { 
-                       	    if (!cb.length) return;
-                       	    fOCData["timestamp"] = cb[0]["timestamp"] || 0;
-                       	    OXTaskMapping.editObjects(ids,fOCData);
+                            if (!cb.length) return;
+                            fOCData["timestamp"] = cb[0]["timestamp"] || 0;
+                            OXTaskMapping.editObjects(ids,fOCData);
                        }
                     );
             });
-    	
+        
     }
     
-    function makeGrid(gridName,newlivegrid) {
-    	function cb_changes(object) {
-            var new_pc = 100;
-            var new_status = 3;
-            if (object["percent_completed"] && object["percent_completed"] >= 100) {
-                new_pc = 0;
-                new_status = 1;
-            }
-            return { "percent_completed": new_pc, "status": new_status };
+    function cb_changes(object) {
+        var new_pc = 100;
+        var new_status = 3;
+        if (object["percent_completed"] && object["percent_completed"] >= 100) {
+            new_pc = 0;
+            new_status = 1;
         }
-    	
-    	function addCheckBox() {
-	        var checkbox = newnode("input", 0, { type: "checkbox", className: "noborder" });
-	        addDOMEvent(checkbox, "click", function() {
-	        	    if (!tasksSelection2.getSelected().length) return false;
-                    tasks_udpateTasks([tasksSelection2.getSelected()[0]], ["percent_completed"], cb_changes);
-	        });
-	        return checkbox;
-	    }
-    	
-        var me = configGetKey("identifier");
-        var constructor= newlivegrid ? LiveGrid2 : LiveGrid;
-        var grid = new constructor([ 
+        return { "percent_completed": new_pc, "status": new_status };
+    }
+    
+    function addCheckBox() {
+        var checkbox = newnode("input", 0, { type: "checkbox", className: "noborder" });
+        addDOMEvent(checkbox, "click", function() {
+                if (!tasksSelection2.getSelected().length) return false;
+                tasks_udpateTasks([tasksSelection2.getSelected()[0]], ["percent_completed"], cb_changes);
+        });
+        return checkbox;
+    }
+    
+    temporary.lists.tasks = temporary.MakeList({
+        updated: function() {
+            gridlist.recreate();
+            gridsplit.recreate();
+        },
+        columns: [
             {
                 sortable: false,
                 name : ["recurrence_type"],
@@ -476,10 +476,14 @@ function() {
                         div.firstChild.src = getFullImgSrc("img/tasks/tasks16x16.gif");
                         div.firstChild.alt = "";
                         div.firstChild.style.verticalAlign = "middle";
+                        div.firstChild.style.width = "16px";
+                        div.firstChild.style.height = "16px";
                     } else {
                         div.firstChild.src = getFullImgSrc("img/tasks/sequence.gif");
                         div.firstChild.alt = _("Series");   /*i18n*/
                         div.firstChild.style.verticalAlign = "middle";
+                        div.firstChild.style.width = "16px";
+                        div.firstChild.style.height = "16px";
                     }
                 },
                 clear: function(div) {
@@ -488,6 +492,8 @@ function() {
                     div.firstChild.src = getFullImgSrc("img/tasks/tasks16x16.gif");
                     div.firstChild.alt = "";
                     div.firstChild.style.verticalAlign = "middle";
+                    div.firstChild.style.width = "16px";
+                    div.firstChild.style.height = "16px";
                 }
             },{
                 name: ["folder_id", "id", "percent_completed"],
@@ -498,8 +504,6 @@ function() {
                     if (!div.firstChild) div.appendChild(addCheckBox());
                     div.firstChild.style.display = "";
                     div.firstChild.checked = (data["percent_completed"] && data["percent_completed"] >= 100);
-                    div.firstChild.disabled =
-                        grid.write_own && (data.created_by != me);
                 },
                 clear: function(div) {
                     if (!div.firstChild) div.appendChild(addCheckBox());
@@ -516,16 +520,16 @@ function() {
                         div.firstChild.src = !text ? getFullImgSrc("img/dummy.gif") : getFullImgSrc("img/private_flag.gif");
                         div.firstChild.alt = !text ? "" : _("Private"); /*i18n*/
                     } else
-                        div.appendChild(newnode("img", 0,
-                            {src: !text ? getFullImgSrc("img/dummy.gif") : getFullImgSrc("img/private_flag.gif"), alt: "", width: "16", height: "16" }));
+                        div.appendChild(newnode("img", {width: "16px", height: "16px" },
+                            {src: !text ? getFullImgSrc("img/dummy.gif") : getFullImgSrc("img/private_flag.gif"), alt: ""}));
                 },
                 clear: function(div) {
                     if (div.firstChild) {
                         div.firstChild.src = getFullImgSrc("img/dummy.gif");
                         div.firstChild.alt = "";
                     } else
-                        div.appendChild(newnode("img", 0,
-                            {src: getFullImgSrc("img/dummy.gif"), alt: "", width: "16", height: "16"}));
+                        div.appendChild(newnode("img", {width: "16px", height: "16px" },
+                            {src: getFullImgSrc("img/dummy.gif"), alt: "" }));
                 }
             }, {
                 text: "Subject",    /*i18n*/
@@ -540,10 +544,10 @@ function() {
                     if (object.title) {
                         div.firstChild.data = object.title;
                         if(object["percent_completed"] && object["percent_completed"] >= 100) {
-                        	div.className="cell font-color-disabled";                        	
+                            div.className="cell font-color-disabled";                           
                             div.style.textDecoration = "line-through";                            
                         } else {
-                        	div.className="cell";
+                            div.className="cell";
                             div.style.textDecoration = "none";
                         }
                     } else {
@@ -563,13 +567,13 @@ function() {
                             : (prio == 1) ? getFullImgSrc("img/tasks/taskprio1.gif")
                             : getFullImgSrc("img/tasks/taskprio2.gif");
                     if (!div.firstChild)
-                        div.appendChild(newnode("img", 0, {src: src, alt: ""}));
+                        div.appendChild(newnode("img", {height : "11px", width : "35px"}, {src: src, alt: ""}));
                     else
                         div.firstChild.src = src;
                 }, 
                 clear: function(div) {
                             if (!div.firstChild)
-                                div.appendChild(newnode("img", 0, {src: getFullImgSrc("img/tasks/taskprio2.gif"), alt: ""}));
+                                div.appendChild(newnode("img", {height : "11px", width : "35px"}, {src: getFullImgSrc("img/tasks/taskprio2.gif"), alt: ""}));
                             else
                                 div.firstChild.src = getFullImgSrc("img/tasks/taskprio2.gif");
                         }
@@ -587,10 +591,10 @@ function() {
                     if (object.start_date) {
                         div.firstChild.data = formatDate(object.start_date, "date");
                         if(object["percent_completed"] && object["percent_completed"] >= 100) {
-                        	div.className="cell font-color-disabled";
+                            div.className="cell font-color-disabled";
                             div.style.textDecoration = "line-through";
                         } else {
-                        	div.className="cell";  
+                            div.className="cell";  
                             div.style.textDecoration = "none";
                         }
                     } else {
@@ -610,17 +614,17 @@ function() {
                         div.appendChild(document.createTextNode("\u00a0"));
                     }
                     if (object.end_date) {
-                    	div.style.color = "";
+                        div.style.color = "";
                         div.firstChild.data = formatDate(object.end_date, "date");
                         if(object["percent_completed"] && object["percent_completed"] >= 100) {
-                        	div.className="cell font-color-disabled";
+                            div.className="cell font-color-disabled";
                             div.style.textDecoration = "line-through";
                         } else if (getDays(new Date()-new Date(object.end_date)) > 0) {
                             div.style.textDecoration = "none";
                             div.style.color = "red";
                         } else {
-                        	div.className="cell";  
-                        	div.style.textDecoration = "none";
+                            div.className="cell";  
+                            div.style.textDecoration = "none";
                         }
                     } else {
                         div.firstChild.data = "\u00a0";
@@ -641,14 +645,14 @@ function() {
                     if (percent_completed != undefined) {
                         div.firstChild.data = percent_completed + "%";
                         if (percent_completed >= 100) {
-                        	div.className="cell font-color-disabled";
+                            div.className="cell font-color-disabled";
                             div.style.textDecoration = "line-through";
                         } else {
-                        	div.className="cell";
+                            div.className="cell";
                             div.style.textDecoration = "none";
                         }
                     } else {
-                    	div.className="cell";
+                        div.className="cell";
                         div.style.textDecoration = "none";
                         div.firstChild.data = "\u00a0";
                     }
@@ -663,11 +667,18 @@ function() {
                 sortable: true,
                 set: function(div,text) {
                     if (div)
-                        div.innerHTML = "<img src='"+getFullImgSrc("img/menu/tag_"+(text||0)+".gif")+"' alt='' />";
+                        div.innerHTML = "<img src='"+getFullImgSrc("img/menu/tag_"+(text||0)+".gif")+"' alt='' style='width:16px; height:16px'/>";
                 },
                 clear: clear
             }
-        ], newlivegrid ? tasksSelection2 : tasksSelection , "tasks");
+        ]
+    });
+
+    
+    function makeGrid(gridName,newlivegrid) {
+        var constructor= newlivegrid ? LiveGrid2 : LiveGrid;
+        var grid = new constructor(temporary.lists.tasks.columns,
+            newlivegrid ? tasksSelection2 : tasksSelection , "tasks");
         
         var contextData = [];
         var count = Value(), writable = Value(), deletable = Value();
@@ -700,12 +711,16 @@ function() {
         menu.addItem(new MenuSeparator());
     
         var confirm = new MenuItem("Change confirmation"/*i18n*/, function() {
-            triggerEvent('OX_Task_Change_Confirm', contextData);
+            var objects = new Array(contextData.length);
+            for (var i = 0; i < objects.length; i++) {
+                objects[i] = new AcceptDenyObject("tasks", contextData[i]);
+            }
+            (new AcceptDeny(true)).showConfirmation(objects);
         });
         confirm.setIcon("img/menu/global_confirmation_change.gif",
                         "img/menu/global_conf_change_d.gif");
         confirm.setEnabledF(function() { 
-        	return count() > 0 && confirmable(); 
+            return count() > 0 && confirmable(); 
         });
         menu.addItem(confirm);
     
@@ -729,7 +744,7 @@ function() {
                 { columns: ["users"], objects: sel }, null, userData);
             function userData(data) {
                 contextData = data.objects;
-                for(var i in contextData) {                	
+                for(var i in contextData) {                 
                     var users = contextData[i].users;
                     var me = config.identifier;
                     CheckUsers: {
@@ -760,10 +775,11 @@ function() {
         });
         
         grid.events.register("Selected", function(ids) {
-        	activeTaskId = id = grid.getSelectedIDs() || [];
+            activeTaskId = id = grid.getSelectedIDs() || [];
             if (ids == 1)  {
                 cb_selection_changed();             
             } else if (currentpath2[1]=="split") {
+                if (ids == 0) latestRenderedTask = null;
                 clearSplitDetails();                
             }
             triggerEvent("Selected", activeTaskId);
@@ -778,6 +794,7 @@ function() {
         );
         $(gridName + "Header").appendChild(grid.getHeader());
         grid.getTable($(gridName));
+        grid.events.register("Changed",tasks_HeaderUpdate);
         var hv = grid.addHover(OXTaskHover.getContent().node, function(id) {
             OXTaskHover.actualHover=hv;
             OXTaskHover.refillContent(id.id,id.folder_id);                  
@@ -856,27 +873,22 @@ function() {
         $("tasks.split.detail_container.content").style.display="none";
         $("tasks.split.detail_container.loading").style.display="none";
         if ($("tasks.split.bottom_str").firstChild) {
-        	$("tasks.split.bottom_str").firstChild.data="\u00a0"; // clean bottom str
+            $("tasks.split.bottom_str").firstChild.data="\u00a0"; // clean bottom str
         }
-        /*
-        if (currentpath2[1] == "split" && currentpath2[2] != "overview") { 
-            triggerEvent("OX_Switch_View", "tasks/split/overview");
-        }
-        */
     }
     
     function printTasks() {
         if (!tasksSelection2 || activemodule != "tasks") {
-        	return;
+            return;
         } else if (tasksSelection2.count != 1) {
-        	if (currentpath2[1] == "split" && gridsplit) {
-        		globalprint.printLiveGrid(gridsplit);
-        	} else if (gridlist) {
-        		globalprint.printLiveGrid(gridlist);
-        	}
-        	return;
-        }    	
-    	
+            if (currentpath2[1] == "split" && gridsplit) {
+                globalprint.printLiveGrid(gridsplit);
+            } else if (gridlist) {
+                globalprint.printLiveGrid(gridlist);
+            }
+            return;
+        }       
+        
         var aPrintDetailTask = new Array();
         aPrintDetailTask = [];
                 
@@ -956,14 +968,14 @@ function fn_tasks_getDetails(objects, forceUpdate) {
     }
     tmpDetailRequest=OXCache.newRequest(null, "tasks", collection, function(daten) {      
         if (!daten || !daten.objects) {
-        	enableTaskLoadingScreen(false);
-        	return;
+            enableTaskLoadingScreen(false);
+            return;
         }
         updateTaskSplit(daten.objects[0]);
     }, function(daten) {
         if (!daten || !daten.objects) {
-        	enableTaskLoadingScreen(false);
-        	return;
+            enableTaskLoadingScreen(false);
+            return;
         }
         updateTaskSplit(daten.objects[0]);
     }, forceUpdate);
@@ -972,7 +984,8 @@ function fn_tasks_getDetails(objects, forceUpdate) {
 
 function expandTaskSplitHeader(fullHeader) {
     if (fullHeader) $('tasks.split.header_ext').style.display = "";
-    $("tasks.split.expand_plus").getElementsByTagName("img")[0].src="themes/default/img/" + (fullHeader ? "minus" : "plus") + ".gif";
+    $("tasks.split.expand_plus").getElementsByTagName("img")[0].src =
+        getFullImgSrc("img/" + (fullHeader ? "minus" : "plus") + ".gif");
     configSetKey("gui.tasks.fullsplitheader", fullHeader);    
     var steps = 6*pxPerEm;
     animate(configGetKey("gui.effects.fading") ? 250 : 0, steps, function(stepN) { 
@@ -991,7 +1004,7 @@ function enableTaskLoadingScreen(enabled) {
     if (enabled && $("tasks.split.detail_container.content").style.display != "none") {
         $("tasks.split.detail_container.content").style.display="none";
     } else if (!enabled && $("tasks.split.detail_container.content").style.display != "block") {
-    	$("tasks.split.detail_container.content").style.display="block";
+        $("tasks.split.detail_container.content").style.display="block";
     }
     if (!enabled && $("tasks.split.detail_container.loading").style.display != "none") {
         $("tasks.split.detail_container.loading").style.display="none";
@@ -1004,13 +1017,13 @@ var aStatusTask = new Array("Not started","In progress","Done","Waiting","Deferr
 function updateTaskSplit(object) {
     if (!object || activemodule != "tasks") return;
     
-	// changing the selection jumps back to overview tab
-	if (currentpath2[1] == "split" && currentpath2[2] != "overview") { 
+    // changing the selection jumps back to overview tab
+    if (currentpath2[1] == "split" && currentpath2[2] != "overview") { 
         triggerEvent("OX_Switch_View", "tasks/split/overview");
     }
 
     if ($("tasks.split.due_today").style.display != "none") {
-    	$("tasks.split.due_today").style.display="none";
+        $("tasks.split.due_today").style.display="none";
     }
 
     aPrintDetailTask = [];
@@ -1087,7 +1100,7 @@ function updateTaskSplit(object) {
                                break;
                            default:
                                if (pastDays < -1) {
-                               	    text = format(_("Due in %s days."), Math.abs(pastDays));
+                                    text = format(_("Due in %s days."), Math.abs(pastDays));
                                } else {
                                     text = format(_("Overdue by %s days."), pastDays);
                                }
@@ -1101,7 +1114,7 @@ function updateTaskSplit(object) {
                   objTaskDetailParticipants.popArray();
                   objTaskDetailParticipants.oParticipantResources = clone(idvalue);  
                   objTaskDetailParticipants.writeCountParticipants();
-                  objTaskDetailParticipants.pushArray();	                  
+                  objTaskDetailParticipants.pushArray();                      
                   $("tasks.split.participants_count").firstChild.data = objTaskDetailParticipants.arrayLength();
                   internalCache.getUsers(objTaskDetailParticipants.idUserArr,fnSetTaskUserColumn);
                   break;
@@ -1109,8 +1122,8 @@ function updateTaskSplit(object) {
                   // trigger confirmation                      
                   for (var i=0; idvalue && i < idvalue.length; i++) {
                       if (idvalue[i].id == configGetKey("identifier")) { 
-                      	triggerEvent("Confirmation_Changed", 1); 
-                      	break; 
+                        triggerEvent("Confirmation_Changed", 1); 
+                        break; 
                       }
                   }
                   objTaskDetailParticipants.usersD = idvalue || "";
@@ -1481,9 +1494,14 @@ TaskDetailParticipantTab.prototype = {
     }
 }
 
+function tasks_HeaderUpdate(data) {
+    contactsFolderPath.additionalNode=document.createTextNode(" ("+ data.objects.length + ")");
+    contactsFolderPath.drawDOMNode(currentpath2[1] == "split" ? "taskofsplitview" : "taskoflistview", activefolder);
+}
+
 function fnSetTaskUserColumn(arg) {
     if (arg) {
-    	objTaskDetailParticipants.fnSetUserColumn(arg);
+        objTaskDetailParticipants.fnSetUserColumn(arg);
     }
 }
 
