@@ -200,6 +200,11 @@ function TreeNode(parent, hasChildren, closedIcon, openIcon, text, id, data,afte
 	this.state = new Object();
 	this.tree_id;	
 	this.tree;		
+	
+	/**
+	 * @private
+	 */
+	this.decoration = [];
 
 	var afterlabeltext = afterlabel;
 	/**
@@ -216,7 +221,7 @@ function TreeNode(parent, hasChildren, closedIcon, openIcon, text, id, data,afte
 				src: hasChildren ? getFullImgSrc("img/plus.gif") : getFullImgSrc("img/noplus.gif")})])
 																		]),
 													newnode("td",0,0,[
-		newnode("div",0,0,[this.icon = newnode("img", 0,
+		newnode("div", { position: "relative" },0,[this.icon = newnode("img", 0,
 				{className: "tree-icon", src: this.closedIcon})])]),
 													newnode("td",{paddingLeft:"0",width:"100%"},0,[				
 		this.text = newnode("div", 0, {className: "tree-text border-color-content-default"}, [
@@ -337,6 +342,32 @@ TreeNode.prototype = {
 		this.container.style.display = open ? "block" : "none";
 	},
 	
+	/**
+	 * Sets the decoration icons for this node.
+	 * @param {Array} decoration An array of image URLs which are displayed on
+	 * top of the icon. The order of array elements determines the z index.
+	 * The last element is displayed on top.
+	 */
+	setDecoration: function(decoration) {
+	    var min = Math.min(this.decoration.length, decoration.length);
+	    var max = Math.max(this.decoration.length, decoration.length);
+	    for (var i = 0; i < min; i++) {
+	        this.decoration[i].style.backgroundImage =
+	            "url(" + decoration[i] + ")";
+	    }
+	    for (var i = min; i < decoration.length; i++) {
+	        var div = newnode("div", {
+	            backgroundImage: "url(" + decoration[i] + ")",
+	            height: "16px"
+            }, { className: "tree-decoration" });
+	        this.decoration[i] = div;
+	        this.icon.parentNode.appendChild(div);
+	    }
+	    for (var i = decoration.length; i < max; i++) {
+	        this.icon.parentNode.removeChild(this.decoration[i]);
+	    }
+	    this.decoration.length = decoration.length;
+	},
 	
 	/**
 	 * @private
