@@ -2,15 +2,19 @@ var tab = new temporary.VTab(newnode("span", 0, 0, [
     addTranslated(_("Publications")),
     newnode("span", { background: "orange", marginLeft: "5px", padding: "2px",
                       MozBorderRadius: "2px", WebkitBorderRadius: "2px",
-                      color:"white" }, 0, [document.createTextNode(_("Beta"))])
+                      color:"white" }, 0, [ addTranslated("New") ])
 ]), 0.2);
 temporary.folderTabs.addTab(tab);
 
 var widgets = {
-    input: function(def) { return new ox.UI.Input(def.displayName); },
-    password: function(def) { return new ox.UI.Password(def.displayName); },
-    checkbox: function(def) { return new ox.UI.CheckBox(def.displayName); },
-    text: function(def) { return new ox.UI.Text(def.displayName); },
+    input: function(def) { return new ox.UI.Input(noI18n(def.displayName)); },
+    password: function(def) {
+        return new ox.UI.Password(noI18n(def.displayName));
+    },
+    checkbox: function(def) {
+        return new ox.UI.CheckBox(noI18n(def.displayName));
+    },
+    text: function(def) { return new ox.UI.Text(noI18n(def.displayName)); },
     link: function(def) {
         var link = new ox.UI.Widget();
         link.default_value = "";
@@ -31,40 +35,115 @@ var widgets = {
     }
 };
 
+// create plugin namespace
+var com_openexchange_publish = {};
+com_openexchange_publish.targets = {};
+com_openexchange_publish.modules = {};
+com_openexchange_publish.tab = tab;
+
+// get modules
+ox.JSON.get(AjaxRoot + "/publicationTargets/?action=all" +
+    "&columns=id,displayName,icon,module,formDescription&session=" + session, 
+    function(reply) {
+        for (var i in reply.data) {
+            var t = reply.data[i];
+            var target = { id: t[0], displayName: t[1], icon: t[2],
+                           module: t[3], formDescription: t[4] };
+            com_openexchange_publish.targets[target.id] = target;
+            var module = com_openexchange_publish.modules[target.module];
+            if (!module) {
+                module = com_openexchange_publish.modules[target.module] = {};
+            }
+            module[target.id] = target;
+        }
+    }
+);
+
+// is active?
+com_openexchange_publish.supportsFolder = function(folder) {
+    return Boolean(
+        com_openexchange_publish.modules && 
+        folder && folder.data &&
+        folder.data.module in com_openexchange_publish.modules && 
+        folder.data.own_rights & (1 << 28)
+    );
+};
+
+// add menu item
+com_openexchange_publish.folderMenuItem = new MenuItem("Publish" /*i18n*/, 
+    function() { 
+
+        // get current folder
+        var data = this.getContext().data;
+        
+        // already initialized?
+        if (temporary.folderTabs.initialized) {
+            // switch to folder properties
+            viewProperties(data, false);
+            // switch tab (the easy way)
+            temporary.folderTabs.showTab(com_openexchange_publish.tab);
+        } else {
+            // switch tab
+            // this is tricky: "afterInit" is called when the tab control widget
+            // finishes drawing. We register for the "Resized "event" and wait for
+            // two iterations of the resizing mechanism.
+            // ShowTab is called twice as well - don't ask.
+            var resizeCount = 0;
+            temporary.folderTabs.afterInit = function() {
+                var showTab = function() {
+                    resizeCount++;
+                    // change tabs
+                    temporary.folderTabs.showTab(com_openexchange_publish.tab);
+                    if (resizeCount >= 2) {
+                        // unregister event
+                        resizeEvents.unregister("Resized", showTab);
+                    }
+                };
+                // wait for "resized" event
+                resizeEvents.register("Resized", showTab);
+            };
+            // switch to folder properties
+            viewProperties(data, false);
+        }
+    }
+);
+
+// set its "onShow" handler
+com_openexchange_publish.folderMenuItem.onShow = function() {
+    // get folder
+    var folder = oMainFolderTree.get_folder_by_node_id(this.getContext().data.id);
+    // support for this folder?
+    this.setVisible(com_openexchange_publish.supportsFolder(folder.oxfolder));
+}
+extended_folder_menu.addItem(com_openexchange_publish.folderMenuItem);
+
 tab.init = function() {
+
     var targets, modules, onInit;
     
+    // copy
+    targets = com_openexchange_publish.targets;
+    modules = com_openexchange_publish.modules;
+    
+    // visible?
+    for (var t in targets) {
+        if (temporary.folderTabs.folder.module == targets[t].module) {
+            tab.setVisible(true);
+            break;
+        }
+    }
+        
     var old_enter = temporary.folderTabs.enter;
     temporary.folderTabs.enter = function() {
-        tab.setVisible(Boolean(modules && this.folder.module in modules &&
-                               this.folder.own_rights & (1 << 28)));
+        var pubActive = Boolean(
+            modules && this.folder.module in modules && this.folder.own_rights & (1 << 28)
+        );
+        tab.setVisible(pubActive);
         old_enter.call(this);
         if (targets) initSelect(); else onInit = initSelect;
     };
     
-    ox.JSON.get(AjaxRoot + "/publicationTargets/?action=all"
-        + "&columns=id,displayName,icon,module,formDescription&session="
-        + session, function(reply) {
-            targets = {};
-            modules = {};
-            for (var i in reply.data) {
-                var t = reply.data[i];
-                var target = { id: t[0], displayName: t[1], icon: t[2],
-                               module: t[3], formDescription: t[4] };
-                targets[target.id] = target;
-                var module = modules[target.module];
-                if (!module) {
-                    module = modules[target.module] = {};
-                    if (temporary.folderTabs.folder.module == target.module)
-                        tab.setVisible(true);
-                }
-                module[target.id] = target;
-            }
-            if (onInit) onInit();
-        });
-
     // Left panel
-    
     var selection = new Selection();
     var grid = new LiveGrid([{
         text: _("Name"),
@@ -155,16 +234,24 @@ tab.init = function() {
     function handleDelete() {
         var ids = selection.getSelected();
         ox.JSON.put(AjaxRoot + "/publications?action=delete&session=" + session,
-            ids, function(reply) { storage.removeIDs(ids); });
+            ids, function(reply) {
+                storage.removeIDs(ids);
+                oMainFolderTree.cache.updateFolders(
+                    [temporary.folderTabs.folder.id],
+                    function() {
+                        oMainFolderTree.load_view(
+                            oMainFolderTree.cache.folders.root,
+                            oMainFolderTree.tree, true, false);
+                    }); 
+            });
     }
 
     // Right panel
-    
     var select = new ox.UI.ComboBox(_("Target"));
     select.changed = function() { entry.updateSelect(); };
     if (targets) initSelect(); else onInit = initSelect;
     function initSelect() {
-        var module = tab.parent.folder.module;
+        var module = com_openexchange_publish.tab.parent.folder.module;
         var ids = [], names = [];
         for (var i in targets) {
             var m = targets[i].module;
@@ -175,6 +262,10 @@ tab.init = function() {
         }
         select.setEntries(ids, names);
         onInit = undefined;
+        // Done!
+//        if (com_openexchange_publish.tab.initSelectDone) {
+//            com_openexchange_publish.tab.initSelectDone();
+//        }
     }
     
     var entry = new ox.UI.Container();
@@ -245,5 +336,4 @@ tab.init = function() {
         ox.UI.Widget.prototype.addContent.apply(this, arguments);
     };
     tab.addWidget(privacy, ox.Configuration.Group.NoField);
-    
 };
\ No newline at end of file
