@@ -2,15 +2,19 @@ var tab = new temporary.VTab(newnode("span", 0, 0, [
     addTranslated(_("Subscriptions")),
     newnode("span", { background: "orange", marginLeft: "5px", padding: "2px",
                       MozBorderRadius: "2px", WebkitBorderRadius: "2px",
-                      color:"white" }, 0, [document.createTextNode(_("Beta"))])
+                      color:"white" }, 0, [ addTranslated("New") ])
 ]), 0.2);
 temporary.folderTabs.addTab(tab);
 
 var widgets = {
-    input: function(def) { return new ox.UI.Input(def.displayName); },
-    password: function(def) { return new ox.UI.Password(def.displayName); },
-    checkbox: function(def) { return new ox.UI.CheckBox(def.displayName); },
-    text: function(def) { return new ox.UI.Text(def.displayName); },
+    input: function(def) { return new ox.UI.Input(noI18n(def.displayName)); },
+    password: function(def) {
+        return new ox.UI.Password(noI18n(def.displayName));
+    },
+    checkbox: function(def) {
+        return new ox.UI.CheckBox(noI18n(def.displayName));
+    },
+    text: function(def) { return new ox.UI.Text(noI18n(def.displayName)); },
     link: function(def) {
         var link = new ox.UI.Widget();
         link.default_value = "";
@@ -31,9 +35,101 @@ var widgets = {
     }
 };
 
+//create plugin namespace
+var com_openexchange_subscribe = {};
+com_openexchange_subscribe.sources = {};
+com_openexchange_subscribe.modules = {};
+com_openexchange_subscribe.tab = tab;
+
+// get modules
+ox.JSON.get(AjaxRoot + "/subscriptionSources/?action=all"
+    + "&columns=id,displayName,icon,module,formDescription&session=" + session,
+    function(reply) {
+        for (var i in reply.data) {
+            var s = reply.data[i];
+            var source = { id: s[0], displayName: s[1], icon: s[2],
+                           module: s[3], formDescription: s[4] };
+            com_openexchange_subscribe.sources[source.id] = source;
+            var module = com_openexchange_subscribe.modules[source.module];
+            if (!module) {
+                module = com_openexchange_subscribe.modules[source.module] = {};
+            }
+            module[source.id] = source;
+        }
+});
+
+//is active?
+com_openexchange_subscribe.supportsFolder = function(folder) {
+    return Boolean(
+        com_openexchange_subscribe.modules && 
+        folder && folder.data &&
+        folder.data.module in com_openexchange_subscribe.modules && 
+        folder.data.own_rights & (127 << 14)
+    );
+};
+
+//add menu item
+com_openexchange_subscribe.folderMenuItem = new MenuItem("Subscribe" /*i18n*/, 
+     function() {
+        // get current folder
+        var data = this.getContext().data;
+        
+        // already initialized?
+        if (temporary.folderTabs.initialized) {
+            // switch to folder properties
+            viewProperties(data, false);
+            // switch tab (the easy way)
+            temporary.folderTabs.showTab(com_openexchange_subscribe.tab);
+        } else {
+            // switch tab
+            // this is tricky: "afterInit" is called when the tab control widget
+            // finishes drawing. We register for the "Resized "event" and wait for
+            // two iterations of the resizing mechanism.
+            // ShowTab is called twice as well - don't ask.
+            var resizeCount = 0;
+            temporary.folderTabs.afterInit = function() {
+                var showTab = function() {
+                    resizeCount++;
+                    // change tabs
+                    temporary.folderTabs.showTab(com_openexchange_subscribe.tab);
+                    if (resizeCount >= 2) {
+                        // unregister event
+                        resizeEvents.unregister("Resized", showTab);
+                    }
+                };
+                // wait for "resized" event
+                resizeEvents.register("Resized", showTab);
+            };
+            // switch to folder properties
+            viewProperties(data, false);
+        }
+    }
+);
+
+//set its "onShow" handler
+com_openexchange_subscribe.folderMenuItem.onShow = function() {
+    // get folder
+    var folder = oMainFolderTree.get_folder_by_node_id(this.getContext().data.id);
+    // support for this folder?
+    this.setVisible(com_openexchange_subscribe.supportsFolder(folder.oxfolder));
+}
+extended_folder_menu.addItem(com_openexchange_subscribe.folderMenuItem);
+
 tab.init = function() {
     var sources, modules, onInit;
     
+    // copy
+    sources = com_openexchange_subscribe.sources;
+    modules = com_openexchange_subscribe.modules;
+    
+    // visible?
+    for (var s in sources) {
+        if (temporary.folderTabs.folder.module == sources[s].module) {
+            tab.setVisible(true);
+            break;
+        }
+    }
+    
     var old_enter = temporary.folderTabs.enter;
     temporary.folderTabs.enter = function() {
         tab.setVisible(Boolean(modules && this.folder.module in modules &&
@@ -42,29 +138,7 @@ tab.init = function() {
         if (sources) initSelect(); else onInit = initSelect;
     };
     
-    ox.JSON.get(AjaxRoot + "/subscriptionSources/?action=all"
-        + "&columns=id,displayName,icon,module,formDescription&session="
-        + session, function(reply) {
-            sources = {};
-            modules = {};
-            for (var i in reply.data) {
-                var s = reply.data[i];
-                var source = { id: s[0], displayName: s[1], icon: s[2],
-                               module: s[3], formDescription: s[4] };
-                sources[source.id] = source;
-                var module = modules[source.module];
-                if (!module) {
-                    module = modules[source.module] = {};
-                    if (temporary.folderTabs.folder.module == source.module)
-                        tab.setVisible(true);
-                }
-                module[source.id] = source;
-            }
-            if (onInit) onInit();
-        });
-
     // Left panel
-    
     var selection = new Selection();
     var grid = new LiveGrid([{
         text: _("Name"),
@@ -178,7 +252,6 @@ tab.init = function() {
     }
 
     // Right panel
-    
     var select = new ox.UI.ComboBox(_("Source"));
     select.changed = function() { entry.updateSelect(); };
     if (sources) initSelect(); else onInit = initSelect;
